@@ -872,7 +872,9 @@ class Bake:
                 elif (module._source.attribute('dependency_test').value is not None):
                     dependencyExists = module._source._check_dependency_expression(env,
                       module._source.attribute('dependency_test').value)
-
+                elif (module._source.attribute('import_test').value is not None):
+                    dependencyExists = module._source._check_import(
+                      module._source.attribute('import_test').value)
                 
                 # if the dependency exists there is nothing else to do
                 if (dependencyExists) :
@@ -1106,21 +1108,24 @@ class Bake:
         """Handles the check command line option."""
         
         checkPrograms = [['python', 'Python'],
-                         ['g++', 'GNU C++ compiler'],
                          ['hg', 'Mercurial'],
-                         ['cvs', 'CVS'],
-                         ['git', 'GIT'],
-                         ['bzr', 'Bazaar'],
+                         # ['cvs', 'CVS'],
+                         ['git', 'Git'],
+                         # ['bzr', 'Bazaar'],
                          ['tar', 'Tar tool'],
                          ['unzip', 'Unzip tool'],
-                         ['unrar', 'Unrar tool'],
-                         ['7z', '7z  data compression utility'],
-                         ['unxz', 'XZ data compression utility'],
+                         # ['unrar', 'Unrar tool'],
+                         # ['7z', '7z  data compression utility'],
+                         # ['unxz', 'XZ data compression utility'],
                          ['make', 'Make'],
                          ['cmake', 'cMake'],
                          ['patch', 'patch tool'],
-                         ['autoreconf', 'autoreconf tool']
+                         # ['autoreconf', 'autoreconf tool']
                          ]
+        if sys.platform == 'darwin':
+            checkPrograms.insert(1,['clang++', 'Clang C++ compiler'])
+        else:
+            checkPrograms.insert(1,['g++', 'GNU C++ compiler'])
         parser = self._option_parser('build')
         (options, args_left) = parser.parse_args(args)
         def _do_env_check(configuration, module, env):
@@ -1310,6 +1315,9 @@ class Bake:
             elif (sysDep.attribute('dependency_test').value is not None):
                 dependencyExists = sysDep._check_dependency_expression(env, 
                   sysDep.attribute('dependency_test').value)
+            elif (sysDep.attribute('import_test').value is not None):
+                dependencyExists = sysDep._check_import(
+                  sysDep.attribute('import_test').value)
 
             if not dependencyExists:
                 sys.stdout.write(" > " + this_key + " - ")
@@ -1324,8 +1332,9 @@ class Bake:
                     if(not installerName):
                         installerName = this_key
                       
-                    print('   >> Try: "sudo ' + command + ' ' + 
-                          installerName + '", if you have sudo rights.')
+                    if (sysDep.attribute('import_test').value is None):
+                        print('   >> Try: "sudo ' + command + ' ' + 
+                              installerName + '", if you have sudo rights.')
 
                 missing = True
             else:
