@@ -1,5 +1,5 @@
 
-NSNAM_CODE_BASE_URL = "http://code.nsnam.org/"
+NSNAM_CODE_BASE_URL = "https://gitlab.com/nsnam/ns-3-dev.git"
 PYBINDGEN_BRANCH = 'https://github.com/gjcarneiro/pybindgen.git'
 LOCAL_PYBINDGEN_PATH = 'pybindgen'
 
@@ -17,4 +17,4 @@ NETANIM_RELEASE_URL = "http://www.nsnam.org/tools/netanim"
 LOCAL_NETANIM_PATH = "netanim"
 
 # bake
-BAKE_REPO = "http://code.nsnam.org/bake"
+BAKE_REPO = "https://gitlab.com/nsnam/bake.git"
