@@ -213,7 +213,7 @@ else
 
     conf=$DIR/doxygen.conf
 
-    sed -i.bak -E '/^(EXTRACT_ALL|HAVE_DOT|CLASS_DIAGRAMS|WARNINGS|SOURCE_BROWSER) /s/YES/no/;/^HTML_OUTPUT /s/html/html-warn/' $conf
+    sed -i.bak -E '/^(EXTRACT_ALL|HAVE_DOT|CLASS_DIAGRAMS|WARNINGS|SOURCE_BROWSER) /s/(YES|yes)/no/;/^HTML_OUTPUT /s/html/html-warn/' $conf
 
     verbose -n "Rebuilding doxygen (v$(doxygen --version)) docs with full errors..."
     (cd "$ROOT" && ./waf --doxygen-no-build >&6 2>&6 )
@@ -263,6 +263,9 @@ REappend filter_blacklistRE "Schedule(Time"
 REappend filter_blacklistRE "ScheduleWithContext(uint32_t"
 REappend filter_blacklistRE "Schedule\\(Now\\|Destroy\\)(\\(MEM\\|void\\)"
 
+#   ATTRIBUTE_HELPER_CPP( and _HEADER(
+REappend filter_blacklistRE "ATTRIBUTE_HELPER_\\(CPP\\|HEADER\\)("
+
 filter_outRE=""
 if [ $filter_blacklist -eq 1 ]; then
     echo "Filtering out blacklist: \"$filter_blacklistRE\""
@@ -280,6 +283,8 @@ if [ "$filter_out" != "" ] ; then
 fi
 
 #  Show the resulting filters
+echo
+echo "Net result of all filters:"
 if [ "${filter_inRE:-}" != "" ] ; then
     echo "Filtering in \"$filter_inRE\""
 fi
