@@ -79,9 +79,9 @@ DevicePacketsInQueueTrace (uint32_t oldValue, uint32_t newValue)
 }
 
 void
-SojournTimeTrace (Time oldValue, Time newValue)
+SojournTimeTrace (Time sojournTime)
 {
-  std::cout << "Sojourn time " << newValue.ToDouble (Time::MS) << "ms" << std::endl;
+  std::cout << "Sojourn time " << sojournTime.ToDouble (Time::MS) << "ms" << std::endl;
 }
 
 int
@@ -202,7 +202,7 @@ main (int argc, char *argv[])
   auto dscpVec = classifier->GetDscpCounts (1);
   for (auto p : dscpVec)
     {
-      std::cout << "  DSCP value:   0x" << std::hex << static_cast<uint32_t>(p.first) << std::dec
+      std::cout << "  DSCP value:   0x" << std::hex << static_cast<uint32_t> (p.first) << std::dec
                 << "  count:   "<< p.second << std::endl;
     }
 
@@ -210,7 +210,7 @@ main (int argc, char *argv[])
 
   std::cout << std::endl << "*** Application statistics ***" << std::endl;
   double thr = 0;
-  uint32_t totalPacketsThr = DynamicCast<PacketSink> (sinkApp.Get (0))->GetTotalRx ();
+  uint64_t totalPacketsThr = DynamicCast<PacketSink> (sinkApp.Get (0))->GetTotalRx ();
   thr = totalPacketsThr * 8 / (simulationTime * 1000000.0); //Mbit/s
   std::cout << "  Rx Bytes: " << totalPacketsThr << std::endl;
   std::cout << "  Average Goodput: " << thr << " Mbit/s" << std::endl;
