@@ -36,6 +36,7 @@
 #include "ns3/wifi-mac.h"
 #include "ns3/packet-sink-helper.h"
 #include "ns3/packet-sink.h"
+#include "ns3/ht-configuration.h"
 
 // This example shows how to configure mixed networks (i.e. mixed b/g and HT/non-HT) and how are performance in several scenarios.
 //
@@ -191,14 +192,10 @@ Experiment::Run (Parameters params)
   wifi.SetStandard (WIFI_PHY_STANDARD_80211n_2_4GHZ);
   NetDeviceContainer nNGFStaDevice, nGFStaDevice;
   mac.SetType ("ns3::StaWifiMac",
-               "RifsSupported", BooleanValue (params.rifsSupported),
                "Ssid", SsidValue (ssid),
-               "BE_MaxAmpduSize", UintegerValue (0),
                "BE_BlockAckThreshold", UintegerValue (2),
                "ShortSlotTimeSupported", BooleanValue (params.enableShortSlotTime));
-  phy.Set ("GreenfieldEnabled", BooleanValue (false));
   nNGFStaDevice = wifi.Install (phy, mac, wifiNNGFStaNodes);
-  phy.Set ("GreenfieldEnabled", BooleanValue (true));
   nGFStaDevice = wifi.Install (phy, mac, wifiNGFStaNodes);
 
   // AP
@@ -207,13 +204,10 @@ Experiment::Run (Parameters params)
   mac.SetType ("ns3::ApWifiMac",
                "Ssid", SsidValue (ssid),
                "EnableBeaconJitter", BooleanValue (false),
-               "BE_MaxAmpduSize", UintegerValue (0),
                "BE_BlockAckThreshold", UintegerValue (2),
-               "RifsSupported", BooleanValue (params.rifsSupported),
                "RifsMode", BooleanValue (params.rifsMode),
                "EnableNonErpProtection", BooleanValue (params.enableErpProtection),
                "ShortSlotTimeSupported", BooleanValue (params.enableShortSlotTime));
-  phy.Set ("GreenfieldEnabled", BooleanValue (params.apSupportsGreenfield));
   apDevice = wifi.Install (phy, mac, wifiApNode);
 
   // Set TXOP limit
@@ -221,6 +215,9 @@ Experiment::Run (Parameters params)
     {
       Ptr<NetDevice> dev = wifiApNode.Get (0)->GetDevice (0);
       Ptr<WifiNetDevice> wifi_dev = DynamicCast<WifiNetDevice> (dev);
+      Ptr<HtConfiguration> htConfiguration = wifi_dev->GetHtConfiguration ();
+      htConfiguration->SetGreenfieldSupported (params.apSupportsGreenfield);
+      htConfiguration->SetRifsSupported (params.rifsSupported);
       Ptr<WifiMac> wifi_mac = wifi_dev->GetMac ();
       PointerValue ptr;
       wifi_mac->GetAttribute ("BE_Txop", ptr);
@@ -231,6 +228,8 @@ Experiment::Run (Parameters params)
     {
       Ptr<NetDevice> dev = wifiNNGFStaNodes.Get (0)->GetDevice (0);
       Ptr<WifiNetDevice> wifi_dev = DynamicCast<WifiNetDevice> (dev);
+      Ptr<HtConfiguration> htConfiguration = wifi_dev->GetHtConfiguration ();
+      htConfiguration->SetRifsSupported (params.rifsSupported);
       Ptr<WifiMac> wifi_mac = wifi_dev->GetMac ();
       PointerValue ptr;
       wifi_mac->GetAttribute ("BE_Txop", ptr);
@@ -241,6 +240,9 @@ Experiment::Run (Parameters params)
     {
       Ptr<NetDevice> dev = wifiNGFStaNodes.Get (0)->GetDevice (0);
       Ptr<WifiNetDevice> wifi_dev = DynamicCast<WifiNetDevice> (dev);
+      Ptr<HtConfiguration> htConfiguration = wifi_dev->GetHtConfiguration ();
+      htConfiguration->SetGreenfieldSupported (true);
+      htConfiguration->SetRifsSupported (params.rifsSupported);
       Ptr<WifiMac> wifi_mac = wifi_dev->GetMac ();
       PointerValue ptr;
       wifi_mac->GetAttribute ("BE_Txop", ptr);
@@ -248,6 +250,8 @@ Experiment::Run (Parameters params)
       edca->SetTxopLimit (MicroSeconds (3008));
     }
 
+  Config::Set ("/NodeList/*/DeviceList/*/$ns3::WifiNetDevice/Mac/BE_MaxAmpduSize", UintegerValue (0)); //Disable A-MPDU
+
   // Define mobility model
   MobilityHelper mobility;
   Ptr<ListPositionAllocator> positionAlloc = CreateObject<ListPositionAllocator> ();
