@@ -23,18 +23,21 @@
 // It outputs plots of the Frame Success Rate versus the Signal-to-noise ratio for
 // both NIST and YANS error rate models and for every OFDM mode.
 
-#include "ns3/core-module.h"
+#include <fstream>
+#include <cmath>
+#include "ns3/gnuplot.h"
+#include "ns3/command-line.h"
 #include "ns3/yans-error-rate-model.h"
 #include "ns3/nist-error-rate-model.h"
-#include "ns3/gnuplot.h"
+#include "ns3/wifi-tx-vector.h"
 
 using namespace ns3;
 
 int main (int argc, char *argv[])
 {
   uint32_t FrameSize = 1500; //bytes
-  std::ofstream yansfile ("yans-frame-success-rate.plt");
-  std::ofstream nistfile ("nist-frame-success-rate.plt");
+  std::ofstream yansfile ("yans-frame-success-rate-ofdm.plt");
+  std::ofstream nistfile ("nist-frame-success-rate-ofdm.plt");
   std::vector <std::string> modes;
 
   modes.push_back ("OfdmRate6Mbps");
@@ -50,8 +53,8 @@ int main (int argc, char *argv[])
   cmd.AddValue ("FrameSize", "The frame size in bytes", FrameSize);
   cmd.Parse (argc, argv);
 
-  Gnuplot yansplot = Gnuplot ("yans-frame-success-rate.eps");
-  Gnuplot nistplot = Gnuplot ("nist-frame-success-rate.eps");
+  Gnuplot yansplot = Gnuplot ("yans-frame-success-rate-ofdm.eps");
+  Gnuplot nistplot = Gnuplot ("nist-frame-success-rate-ofdm.eps");
 
   Ptr <YansErrorRateModel> yans = CreateObject<YansErrorRateModel> ();
   Ptr <NistErrorRateModel> nist = CreateObject<NistErrorRateModel> ();
@@ -67,17 +70,18 @@ int main (int argc, char *argv[])
       for (double snr = -5.0; snr <= 30.0; snr += 0.1)
         {
           double ps = yans->GetChunkSuccessRate (WifiMode (modes[i]), txVector, std::pow (10.0,snr / 10.0), FrameSize * 8);
-          yansdataset.Add (snr, ps);
-          if (ps < 0 || ps > 1)
+          if (ps < 0.0 || ps > 1.0)
             {
               //error
-              return 0;
+              exit (1);
             }
+          yansdataset.Add (snr, ps);
+
           ps = nist->GetChunkSuccessRate (WifiMode (modes[i]), txVector, std::pow (10.0,snr / 10.0), FrameSize * 8);
-          if (ps < 0 || ps > 1)
+          if (ps < 0.0 || ps > 1.0)
             {
               //error
-              return 0;
+              exit (1);
             }
           nistdataset.Add (snr, ps);
         }
