@@ -117,7 +117,7 @@ class NodeStatistics
 public:
   NodeStatistics (NetDeviceContainer aps, NetDeviceContainer stas);
 
-  void PhyCallback (std::string path, Ptr<const Packet> packet);
+  void PhyCallback (std::string path, Ptr<const Packet> packet, double powerW);
   void RxCallback (std::string path, Ptr<const Packet> packet, const Address &from);
   void PowerCallback (std::string path, double oldPower, double newPower, Mac48Address dest);
   void RateCallback (std::string path, DataRate oldRate, DataRate newRate, Mac48Address dest);
@@ -203,7 +203,7 @@ NodeStatistics::GetCalcTxTime (DataRate rate)
 }
 
 void
-NodeStatistics::PhyCallback (std::string path, Ptr<const Packet> packet)
+NodeStatistics::PhyCallback (std::string path, Ptr<const Packet> packet, double powerW)
 {
   WifiMacHeader head;
   packet->PeekHeader (head);
