@@ -41,14 +41,20 @@
 //               | AP Node |              | AP Node |
 //               +---------+              +---------+
 
-#include "ns3/core-module.h"
-#include "ns3/mobility-module.h"
-#include "ns3/applications-module.h"
-#include "ns3/wifi-module.h"
-#include "ns3/network-module.h"
-#include "ns3/csma-module.h"
-#include "ns3/internet-module.h"
+#include "ns3/command-line.h"
+#include "ns3/double.h"
+#include "ns3/string.h"
+#include "ns3/yans-wifi-helper.h"
+#include "ns3/ssid.h"
+#include "ns3/mobility-helper.h"
+#include "ns3/internet-stack-helper.h"
+#include "ns3/ipv4-address-helper.h"
+#include "ns3/on-off-helper.h"
+#include "ns3/yans-wifi-channel.h"
+#include "ns3/csma-helper.h"
+#include "ns3/animation-interface.h"
 #include "ns3/bridge-helper.h"
+#include "ns3/packet-socket-address.h"
 
 using namespace ns3;
 
