@@ -22,7 +22,7 @@
 
 #include <string>
 #include <sstream>
-#include <list>
+#include <vector>
 
 #include "callback.h"
 
@@ -52,8 +52,9 @@ namespace ns3 {
  * Instances of this class can be used to parse command-line 
  * arguments.  Programs can register a general usage message with
  * CommandLine::Usage, and arguments with CommandLine::AddValue.
- * POD argument variables will be set directly; more general arguments
- * can be processed via a Callback.
+ * Argument variable types with input streamers (`operator>>`)
+ * can be set directly; more complex argument parsing 
+ * can be accomplished by providing a Callback.
  *
  * CommandLine also provides handlers for these standard arguments:
  * \verbatim
@@ -67,13 +68,19 @@ namespace ns3 {
  * The more common \c --help is a synonym for \c --PrintHelp; an example
  * is given below.
  *
+ * CommandLine can also handle non-option arguments
+ * (often called simply "positional" parameters: arguments which don't begin
+ * with "-" or "--").  These can be parsed directly in to variables,
+ * by registering arguments with AddNonOption in the order expected.
+ * Additional non-option arguments encountered will be captured as strings.
+ *
  * Finally, CommandLine processes Attribute and GlobalValue arguments.
- * Default values for chosen attributes can be set using a shorthand
+ * Default values for specific attributes can be set using a shorthand
  * argument name.
  *
  * In use, arguments are given in the form
  * \verbatim
-   --arg=value --toggle \endverbatim
+   --arg=value --toggle first-non-option\endverbatim
  * Most arguments expect a value, as in the first form, \c --arg=value.
  * Toggles, corresponding to boolean arguments, can be given in any of
  * the forms
@@ -82,8 +89,11 @@ namespace ns3 {
  * The first form changes the state of toggle1 from its default; 
  * all the rest set the corresponding boolean variable to true.
  * \c 0, \c f and \c false are accepted to set the variable to false.
+ * Option arguments can appear in any order on the command line,
+ * even intermixed with non-option arguments.
+ * The order of non-option arguments is preserved.
  *
- * Arguments can be repeated on the command line; the last value given
+ * Option arguments can be repeated on the command line; the last value given
  * will be the final value used.  For example,
  * \verbatim
    --arg=one --toggle=f --arg=another --toggle \endverbatim
@@ -93,7 +103,7 @@ namespace ns3 {
  * Because arguments can be repeated it can be hard to decipher what
  * value each variable ended up with, especially when using boolean toggles.
  * Suggested best practice is for scripts to report the values of all items
- * settable throught CommandLine, as done by the example below.
+ * settable through CommandLine, as done by the example below.
  * 
  *
  * CommandLine can set the initial value of every attribute in the system
@@ -114,7 +124,9 @@ namespace ns3 {
  * \verbatim
    --SchedulerType=HeapScheduler \endverbatim
  *
- * A simple example is in `src/core/example/``command-line-example.cc`
+ * A simple example of CommandLine is in `src/core/example/``command-line-example.cc`
+ * See that file for an example of handling non-option arguments.
+ *
  * The heart of that example is this code:
  *
  * \code
@@ -197,10 +209,6 @@ namespace ns3 {
  *       exit (-1);
  *     }
  * \endcode
- *
- * \bugid{2461} Treat non-option arguments like traditional \c getopt(), by
- * permuting non-option arguments to the end and providing a query function
- * for the equivalent of \c optind.
  */
 class CommandLine
 {
@@ -267,6 +275,41 @@ public:
    */
   void AddValue (const std::string &name,
                  const std::string &attributePath);
+  
+  /**
+   * Add a non-option argument, assigning to POD
+   *
+   * \param [in] name The name of the program-supplied argument
+   * \param [in] help The help text used by \c \-\-PrintHelp
+   * \param [out] value A reference to the variable where the
+   *        value parsed will be stored (if no value
+   *        is parsed, this variable is not modified).
+   */
+  template <typename T>
+  void AddNonOption (const std::string name, const std::string help, T & value);
+
+  /**
+   * Get extra non-option arguments by index.
+   * This allows CommandLine to accept more non-option arguments than
+   * have been configured explicitly with AddNonOption().
+   *
+   * This is only valid after calling Parse().
+   *
+   * \param [in] i The index of the non-option argument to return.
+   * \return The i'th non-option argument, as a string.
+   */
+  std::string GetExtraNonOption (std::size_t i) const;
+  
+  /**
+   * Get the total number of non-option arguments found,
+   * including those configured with AddNonOption() and extra non-option
+   * arguments.
+   *
+   * This is only valid after calling Parse().
+   *
+   * \returns the number of non-option arguments found.
+   */
+  std::size_t GetNExtraNonOptions (void) const;
 
   /**
    * Parse the program arguments
@@ -284,6 +327,17 @@ public:
    */
   void Parse (int argc, char *argv[]);
 
+  /**
+   * Parse the program arguments.
+   *
+   * This version may be convenient when synthesizing arguments
+   * programmatically.  Other than the type of argument this behaves
+   * identically to Parse(int, char *)
+   *
+   * \param [in] args The vector of arguments.
+   */
+  void Parse (std::vector<std::string> args);
+
   /**
    * Get the program name
    *
@@ -313,7 +367,7 @@ private:
 
   /**
    * \ingroup commandline
-   * \brief The argument base class
+   * \brief The argument abstract base class
    */
   class Item 
   {
@@ -329,14 +383,14 @@ private:
      */
     virtual bool Parse (const std::string value) = 0;
     /**
-     * \return \c true if this item have a default value?
+     * \return \c true if this item has a default value.
      */
     virtual bool HasDefault () const;
     /**
      * \return The default value
      */
     virtual std::string GetDefault () const;
-  };
+  };  // class Item
 
   /**
    * \ingroup commandline
@@ -346,20 +400,25 @@ private:
   class UserItem : public Item
   {
   public:
-    /**
-     * Parse from a string.
-     *
-     * \param [in] value The string representation
-     * \return \c true if parsing the value succeeded
-     */
+    // Inherited
     virtual bool Parse (const std::string value);
-
     bool HasDefault () const;
     std::string GetDefault () const;
       
     T *m_valuePtr;            /**< Pointer to the POD location */
     std::string m_default;    /**< String representation of default value */
-  };
+  };  // class UserItem
+
+  class StringItem : public Item
+  {
+  public:
+    // Inherited
+    bool Parse (const std::string value);
+    bool HasDefault (void) const;
+    std::string GetDefault (void) const;
+    
+    std::string m_value;     /**< The argument value. */
+  };  // class StringItem
 
   /**
    * \ingroup commandline
@@ -376,8 +435,25 @@ private:
      */
     virtual bool Parse (const std::string value);
     Callback<bool, std::string> m_callback;  /**< The Callback */
-  };
+  };  // class CallbackItem
 
+
+  /**
+   * Handle an option in the form \c param=value.
+   *
+   * \param [in] param The option string. 
+   * \returns \c true if this was really an option.
+   */
+  bool HandleOption (const std::string & param) const;
+  
+  /**
+   * Handle a non-option
+   *
+   * \param [in] value The command line non-option value.
+   * \return \c true if \c value could be parsed correctly.
+   */
+  bool HandleNonOption (const std::string &value);
+  
   /**
    * Match name against the program or general arguments,
    * and dispatch to the appropriate handler.
@@ -435,10 +511,14 @@ private:
   /** Remove all arguments, Usage(), name */
   void Clear (void);
 
-  typedef std::list<Item *> Items;      /**< Argument list container */
-  Items m_items;                        /**< The list of arguments */
+  typedef std::vector<Item *> Items;    /**< Argument list container */
+  Items m_options;                      /**< The list of option arguments */
+  Items m_nonOptions;                   /**< The list of non-option arguments */
+  std::size_t m_NNonOptions;            /**< The expected number of non-option arguments */
+  std::size_t m_nonOptionCount;         /**< The number of actual non-option arguments seen so far. */
   std::string m_usage;                  /**< The Usage string */
   std::string m_name;                   /**< The program name */
+
 };  // class CommandLine
 
 
@@ -508,9 +588,27 @@ CommandLine::AddValue (const std::string &name,
   ss << value;
   ss >> item->m_default;
     
-  m_items.push_back (item);
+  m_options.push_back (item);
 }
 
+template <typename T>
+void
+CommandLine::AddNonOption (const std::string name,
+                           const std::string help,
+                           T & value)
+{
+  UserItem<T> *item = new UserItem<T> ();
+  item->m_name = name;
+  item->m_help = help;
+  item->m_valuePtr = &value;
+  
+  std::stringstream ss;
+  ss << value;
+  ss >> item->m_default;
+  m_nonOptions.push_back (item);
+  ++m_NNonOptions;
+    
+}
 
 template <typename T>
 bool
