@@ -75,8 +75,9 @@ public:
   virtual Time GetDelayLeft (const EventId &id) const;
   virtual Time GetMaximumSimulationTime (void) const;
   virtual void SetScheduler (ObjectFactory schedulerFactory);
-  virtual uint32_t GetSystemId (void) const; 
+  virtual uint32_t GetSystemId (void) const;
   virtual uint32_t GetContext (void) const;
+  virtual uint64_t GetEventCount (void) const;
 
 private:
   virtual void DoDispose (void);
@@ -124,6 +125,8 @@ private:
   uint64_t m_currentTs;
   /** Execution context of the current event. */
   uint32_t m_currentContext;
+  /** The event count. */
+  uint64_t m_eventCount;
   /**
    * Number of events that have been inserted but not yet scheduled,
    *  not counting the Destroy events; this is used for validation
