@@ -81,53 +81,53 @@ private:
    * \param [in] id The child index.
    * \return The index of the parent of \p id.
    */
-  inline uint32_t Parent (uint32_t id) const;
+  inline std::size_t Parent (std::size_t id) const;
   /**
    * Get the next sibling of a given entry.
    *
    * \param [in] id The starting index.
    * \returns The next sibling of \p id.
    */
-  uint32_t Sibling (uint32_t id) const;
+  std::size_t Sibling (std::size_t id) const;
   /**
    * Get the left child of a given entry.
    *
    * \param [in] id The parent index.
    * \returns The index of the left (first) child.
    */
-  inline uint32_t LeftChild (uint32_t id) const;
+  inline std::size_t LeftChild (std::size_t id) const;
   /**
    * Get the right child index of a given entry.
    *
    * \param [in] id The parent index.
    * \returns The index of the right (second) child.
    */
-  inline uint32_t RightChild (uint32_t id) const;
+  inline std::size_t RightChild (std::size_t id) const;
   /**
    * Get the root index of the heap.
    *
    * \returns The root index.
    */
-  inline uint32_t Root (void) const;
+  inline std::size_t Root (void) const;
   /**
    * Return the index of the last element.
    * \returns The last index.
    */
-  uint32_t Last (void) const;
+  std::size_t Last (void) const;
   /**
    * Test if an index is the root.
    *
    * \param [in] id The index to test.
    * \returns \c true if the \p id is the root.
    */
-  inline bool IsRoot (uint32_t id) const;
+  inline bool IsRoot (std::size_t id) const;
   /**
    * Test if an index is at the bottom of the heap.
    *
    * \param [in] id The index to test.
    * \returns \c true if the index is at the bottom.
    */
-  inline bool IsBottom (uint32_t id) const;
+  inline bool IsBottom (std::size_t id) const;
   /**
    * Compare (less than) two items.
    *
@@ -135,7 +135,7 @@ private:
    * \param [in] b The second item.
    * \returns \c true if \c a < \c b
    */
-  inline bool IsLessStrictly (uint32_t a, uint32_t b) const;
+  inline bool IsLessStrictly (std::size_t a, std::size_t b) const;
   /**
    * Minimum of two items.
    *
@@ -143,14 +143,14 @@ private:
    * \param [in] b The second item.
    * \returns The smaller of the two items.
    */
-  inline uint32_t Smallest (uint32_t a, uint32_t b) const;
+  inline std::size_t Smallest (std::size_t a, std::size_t b) const;
   /**
    * Swap two items.
    *
    * \param [in] a The first item.
    * \param [in] b The second item.
    */
-  inline void Exch (uint32_t a, uint32_t b);
+  inline void Exch (std::size_t a, std::size_t b);
   /** Percolate a newly inserted Last item to its proper position. */ 
   void BottomUp (void);
   /**
@@ -158,7 +158,7 @@ private:
    *
    * \param [in] start Starting entry.
    */
-  void TopDown (uint32_t start);
+  void TopDown (std::size_t start);
 
   /** The event list. */
   BinaryHeap m_heap;
