@@ -18,9 +18,18 @@
  * Authors: Mathieu Lacage <mathieu.lacage@sophia.inria.fr>
  */
 #include "trace-source-accessor.h"
+#include "log.h"
+
+/**
+ * \file
+ * \ingroup tracing
+ * ns3::TraceSourceAccessor implementation (constructor and destructor).
+ */
 
 namespace ns3 {
 
+NS_LOG_COMPONENT_DEFINE ("TraceSourceAccessor");
+
 TraceSourceAccessor::TraceSourceAccessor ()
 {
 }
