@@ -39,7 +39,6 @@ namespace ns3 {
 template <typename Item> class Queue;
 class CsmaChannel;
 class ErrorModel;
-class NetDeviceQueueInterface;
 
 /** 
  * \defgroup csma CSMA Network Device
@@ -357,9 +356,6 @@ protected:
    */
   void AddHeader (Ptr<Packet> p, Mac48Address source, Mac48Address dest, uint16_t protocolNumber);
 
-  virtual void DoInitialize (void);
-  virtual void NotifyNewAggregate (void);
-
 private:
 
   /**
@@ -687,11 +683,6 @@ private:
    */
   Ptr<Node> m_node;
 
-  /**
-   * NetDevice queue interface.
-   */
-  Ptr<NetDeviceQueueInterface> m_queueInterface;
-
   /**
    * The MAC address which has been assigned to this device.
    */
