@@ -29,15 +29,15 @@
  * US Department of Defense (DoD), and ITTC at The University of Kansas.
  */
 
+#include <sstream>
 #include "ns3/core-module.h"
 #include "ns3/network-module.h"
 #include "ns3/applications-module.h"
 #include "ns3/mobility-module.h"
 #include "ns3/config-store-module.h"
-#include "ns3/wifi-module.h"
 #include "ns3/internet-module.h"
 #include "ns3/dsr-module.h"
-#include <sstream>
+#include "ns3/yans-wifi-helper.h"
 
 using namespace ns3;
 
