@@ -31,6 +31,7 @@
 #include "ns3/ipv6-address-generator.h"
 #include "ns3/traffic-control-helper.h"
 #include "ns3/traffic-control-layer.h"
+#include "ns3/net-device-queue-interface.h"
 
 #include "ipv6-address-helper.h"
 
@@ -243,9 +244,19 @@ Ipv6InterfaceContainer Ipv6AddressHelper::Assign (const NetDeviceContainer &c)
       Ptr<TrafficControlLayer> tc = node->GetObject<TrafficControlLayer> ();
       if (tc && DynamicCast<LoopbackNetDevice> (device) == 0 && tc->GetRootQueueDiscOnDevice (device) == 0)
         {
-          NS_LOG_LOGIC ("Installing default traffic control configuration");
-          TrafficControlHelper tcHelper = TrafficControlHelper::Default ();
-          tcHelper.Install (device);
+          Ptr<NetDeviceQueueInterface> ndqi = device->GetObject<NetDeviceQueueInterface> ();
+          // It is useless to install a queue disc if the device has no
+          // NetDeviceQueueInterface attached: the device queue is never
+          // stopped and every packet enqueued in the queue disc is
+          // immediately dequeued, hence there will never be backlog
+          if (ndqi)
+            {
+              std::size_t nTxQueues = ndqi->GetNTxQueues ();
+              NS_LOG_LOGIC ("Installing default traffic control configuration ("
+                            << nTxQueues << " device queue(s))");
+              TrafficControlHelper tcHelper = TrafficControlHelper::Default (nTxQueues);
+              tcHelper.Install (device);
+            }
         }
     }
   return retval;
@@ -290,9 +301,19 @@ Ipv6InterfaceContainer Ipv6AddressHelper::Assign (const NetDeviceContainer &c, s
       Ptr<TrafficControlLayer> tc = node->GetObject<TrafficControlLayer> ();
       if (tc && DynamicCast<LoopbackNetDevice> (device) == 0 && tc->GetRootQueueDiscOnDevice (device) == 0)
         {
-          NS_LOG_LOGIC ("Installing default traffic control configuration");
-          TrafficControlHelper tcHelper = TrafficControlHelper::Default ();
-          tcHelper.Install (device);
+          Ptr<NetDeviceQueueInterface> ndqi = device->GetObject<NetDeviceQueueInterface> ();
+          // It is useless to install a queue disc if the device has no
+          // NetDeviceQueueInterface attached: the device queue is never
+          // stopped and every packet enqueued in the queue disc is
+          // immediately dequeued, hence there will never be backlog
+          if (ndqi)
+            {
+              std::size_t nTxQueues = ndqi->GetNTxQueues ();
+              NS_LOG_LOGIC ("Installing default traffic control configuration ("
+                            << nTxQueues << " device queue(s))");
+              TrafficControlHelper tcHelper = TrafficControlHelper::Default (nTxQueues);
+              tcHelper.Install (device);
+            }
         }
     }
   return retval;
