@@ -199,6 +199,9 @@ TcpBytesInFlightTest::Rx (const Ptr<const Packet> p, const TcpHeader &h, SocketW
                 {
                   // Partial ACK: Update the dupAck received count
                   m_dupAckRecv -= diff / GetSegSize (SENDER);
+                  // During fast recovery the TCP data sender respond to a partial acknowledgment
+                  // by inferring that the next in-sequence packet has been lost (RFC5681)
+                  m_guessedBytesInFlight -= GetSegSize (SENDER);
                 }
             }
 
@@ -224,6 +227,7 @@ TcpBytesInFlightTest::Rx (const Ptr<const Packet> p, const TcpHeader &h, SocketW
           if (m_dupAckRecv == 3)
             {
               NS_LOG_DEBUG ("Loss of a segment detected");
+              m_guessedBytesInFlight -= GetSegSize (SENDER);
             }
           NS_LOG_DEBUG ("Dupack received, Update m_guessedBytesInFlight to " <<
                         m_guessedBytesInFlight);
