@@ -534,6 +534,14 @@ protected:
    */
   Ptr<TcpRxBuffer> GetRxBuffer (SocketWho who);
 
+  /**
+   * \brief Get the Tx buffer from selected socket
+   *
+   * \param who socket where get the TCB
+   * \return the tx buffer
+   */
+  Ptr<TcpTxBuffer> GetTxBuffer (SocketWho who);
+
   /**
    * \brief Get the rWnd of the selected socket
    *
