@@ -1,6 +1,6 @@
 /* -*-  Mode: C++; c-file-style: "gnu"; indent-tabs-mode:nil; -*- */
 /*
- * Copyright (c) 2012 Centre Tecnologic de Telecomunicacions de Catalunya (CTTC)
+ * Copyright (c) 2012-2018 Centre Tecnologic de Telecomunicacions de Catalunya (CTTC)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
@@ -138,8 +138,10 @@ main (int argc, char *argv[])
   uint16_t numberOfUes = 1;
   uint16_t numberOfEnbs = 2;
   uint16_t numBearersPerUe = 2;
-  double simTime = 0.300;
+  Time simTime = MilliSeconds (490);
   double distance = 100.0;
+  bool disableDl = false;
+  bool disableUl = false;
 
   // change some default attributes so that they are reasonable for
   // this scenario, but do this before processing command line
@@ -152,7 +154,9 @@ main (int argc, char *argv[])
   CommandLine cmd;
   cmd.AddValue ("numberOfUes", "Number of UEs", numberOfUes);
   cmd.AddValue ("numberOfEnbs", "Number of eNodeBs", numberOfEnbs);
-  cmd.AddValue ("simTime", "Total duration of the simulation (in seconds)", simTime);
+  cmd.AddValue ("simTime", "Total duration of the simulation", simTime);
+  cmd.AddValue ("disableDl", "Disable downlink data flows", disableDl);
+  cmd.AddValue ("disableUl", "Disable uplink data flows", disableUl);
   cmd.Parse (argc, argv);
 
 
@@ -237,8 +241,8 @@ main (int argc, char *argv[])
   // (e.g., buffer overflows due to packet transmissions happening
   // exactly at the same time)
   Ptr<UniformRandomVariable> startTimeSeconds = CreateObject<UniformRandomVariable> ();
-  startTimeSeconds->SetAttribute ("Min", DoubleValue (0));
-  startTimeSeconds->SetAttribute ("Max", DoubleValue (0.010));
+  startTimeSeconds->SetAttribute ("Min", DoubleValue (0.05));
+  startTimeSeconds->SetAttribute ("Max", DoubleValue (0.06));
 
   for (uint32_t u = 0; u < numberOfUes; ++u)
     {
@@ -249,41 +253,51 @@ main (int argc, char *argv[])
 
       for (uint32_t b = 0; b < numBearersPerUe; ++b)
         {
-          ++dlPort;
-          ++ulPort;
-
           ApplicationContainer clientApps;
           ApplicationContainer serverApps;
-
-          NS_LOG_LOGIC ("installing UDP DL app for UE " << u);
-          UdpClientHelper dlClientHelper (ueIpIfaces.GetAddress (u), dlPort);
-          clientApps.Add (dlClientHelper.Install (remoteHost));
-          PacketSinkHelper dlPacketSinkHelper ("ns3::UdpSocketFactory",
-                                               InetSocketAddress (Ipv4Address::GetAny (), dlPort));
-          serverApps.Add (dlPacketSinkHelper.Install (ue));
-
-          NS_LOG_LOGIC ("installing UDP UL app for UE " << u);
-          UdpClientHelper ulClientHelper (remoteHostAddr, ulPort);
-          clientApps.Add (ulClientHelper.Install (ue));
-          PacketSinkHelper ulPacketSinkHelper ("ns3::UdpSocketFactory",
-                                               InetSocketAddress (Ipv4Address::GetAny (), ulPort));
-          serverApps.Add (ulPacketSinkHelper.Install (remoteHost));
-
           Ptr<EpcTft> tft = Create<EpcTft> ();
-          EpcTft::PacketFilter dlpf;
-          dlpf.localPortStart = dlPort;
-          dlpf.localPortEnd = dlPort;
-          tft->Add (dlpf);
-          EpcTft::PacketFilter ulpf;
-          ulpf.remotePortStart = ulPort;
-          ulpf.remotePortEnd = ulPort;
-          tft->Add (ulpf);
+
+          if (!disableDl)
+            {
+              ++dlPort;
+
+              NS_LOG_LOGIC ("installing UDP DL app for UE " << u);
+              UdpClientHelper dlClientHelper (ueIpIfaces.GetAddress (u), dlPort);
+              clientApps.Add (dlClientHelper.Install (remoteHost));
+              PacketSinkHelper dlPacketSinkHelper ("ns3::UdpSocketFactory",
+                                                   InetSocketAddress (Ipv4Address::GetAny (), dlPort));
+              serverApps.Add (dlPacketSinkHelper.Install (ue));
+
+              EpcTft::PacketFilter dlpf;
+              dlpf.localPortStart = dlPort;
+              dlpf.localPortEnd = dlPort;
+              tft->Add (dlpf);
+            }
+
+          if (!disableUl)
+            {
+              ++ulPort;
+
+              NS_LOG_LOGIC ("installing UDP UL app for UE " << u);
+              UdpClientHelper ulClientHelper (remoteHostAddr, ulPort);
+              clientApps.Add (ulClientHelper.Install (ue));
+              PacketSinkHelper ulPacketSinkHelper ("ns3::UdpSocketFactory",
+                                                   InetSocketAddress (Ipv4Address::GetAny (), ulPort));
+              serverApps.Add (ulPacketSinkHelper.Install (remoteHost));
+
+              EpcTft::PacketFilter ulpf;
+              ulpf.remotePortStart = ulPort;
+              ulpf.remotePortEnd = ulPort;
+              tft->Add (ulpf);
+            }
+
           EpsBearer bearer (EpsBearer::NGBR_VIDEO_TCP_DEFAULT);
           lteHelper->ActivateDedicatedEpsBearer (ueLteDevs.Get (u), bearer, tft);
 
           Time startTime = Seconds (startTimeSeconds->GetValue ());
           serverApps.Start (startTime);
           clientApps.Start (startTime);
+          clientApps.Stop (simTime);
 
         } // end for b
     }
@@ -293,7 +307,7 @@ main (int argc, char *argv[])
   lteHelper->AddX2Interface (enbNodes);
 
   // X2-based Handover
-  lteHelper->HandoverRequest (Seconds (0.100), ueLteDevs.Get (0), enbLteDevs.Get (0), enbLteDevs.Get (1));
+  lteHelper->HandoverRequest (MilliSeconds (300), ueLteDevs.Get (0), enbLteDevs.Get (0), enbLteDevs.Get (1));
 
   // Uncomment to enable PCAP tracing
   //p2ph.EnablePcapAll("lena-x2-handover");
@@ -323,7 +337,7 @@ main (int argc, char *argv[])
                    MakeCallback (&NotifyHandoverEndOkUe));
 
 
-  Simulator::Stop (Seconds (simTime));
+  Simulator::Stop (simTime + MilliSeconds (20));
   Simulator::Run ();
 
   // GtkConfigStore config;
@@ -331,5 +345,4 @@ main (int argc, char *argv[])
 
   Simulator::Destroy ();
   return 0;
-
 }
