@@ -1,6 +1,7 @@
 /* -*-  Mode: C++; c-file-style: "gnu"; indent-tabs-mode:nil; -*- */
 /*
  * Copyright (c) 2011, 2012 Centre Tecnologic de Telecomunicacions de Catalunya (CTTC)
+ * Copyright (c) 2018 Fraunhofer ESK : RLF extensions
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
@@ -21,6 +22,7 @@
  * Modified by:
  *          Danilo Abrignani <danilo.abrignani@unibo.it> (Carrier Aggregation - GSoC 2015)
  *          Biljana Bojovic <biljana.bojovic@cttc.es> (Carrier Aggregation)
+ *          Vignesh Babu <ns3-dev@esk.fraunhofer.de> (RLF extensions)
  */
 
 #ifndef LTE_ENB_RRC_H
@@ -86,6 +88,7 @@ public:
     INITIAL_RANDOM_ACCESS = 0,
     CONNECTION_SETUP,
     CONNECTION_REJECTED,
+    ATTACH_REQUEST,
     CONNECTED_NORMALLY,
     CONNECTION_RECONFIGURATION,
     CONNECTION_REESTABLISHMENT,
@@ -139,6 +142,12 @@ public:
    */
   void SetImsi (uint64_t imsi);
 
+  /**
+   * Process Initial context setup request message from the MME.
+   * It triggers RRC connection reconfiguration.
+   */
+  void InitialContextSetupRequest ();
+
   /** 
    * Setup a new data radio bearer, including both the configuration
    * within the eNB and the necessary RRC signaling with the UE
@@ -211,9 +220,14 @@ public:
    */
   LteRrcSap::RrcConnectionReconfiguration GetRrcConnectionReconfigurationForHandover ();
 
-  /** 
-   * Send a data packet over the appropriate Data Radio Bearer
-   * 
+  /**
+   * Send a data packet over the appropriate Data Radio Bearer.
+   * If state is HANDOVER_JOINING (i.e. target eNB has received the
+   * Handover Request), the packet is buffered.
+   * If state is HANDOVER_LEAVING (i.e. source eNB has received the
+   * RRC Connection Reconfiguration, the packet is sent through the
+   * X2 interface.
+   *
    * \param bid the corresponding EPS Bearer ID
    * \param p the packet
    */
@@ -291,6 +305,12 @@ public:
    * \param msg the measrurement report
    */
   void RecvMeasurementReport (LteRrcSap::MeasurementReport msg);
+  /**
+   * Implement the LteEnbRrcSapProvider::RecvIdealUeContextRemoveRequest interface.
+   *
+   * \param rnti the C-RNTI identifying the user
+   */
+  void RecvIdealUeContextRemoveRequest (uint16_t rnti);
 
 
   // METHODS FORWARDED FROM ENB CMAC SAP //////////////////////////////////////
@@ -355,6 +375,12 @@ public:
    */
   void SetPdschConfigDedicated (LteRrcSap::PdschConfigDedicated pdschConfigDedicated);
 
+  /**
+   * Cancel all timers which are running for the UE
+   *
+   */
+  void CancelPendingEvents ();
+
   /**
    * TracedCallback signature for state transition events.
    *
@@ -462,6 +488,17 @@ private:
    */
   uint8_t Bid2Drbid (uint8_t bid);
 
+  /**
+   * Send a data packet over the appropriate Data Radio Bearer.
+   * It is called by SendData if the UE is in a connected state
+   * or when the RRC Connection Reconfiguration Complete message
+   * is received and the packets are debuffered.
+   *
+   * \param bid the corresponding EPS Bearer ID
+   * \param p the packet
+   */
+  void SendPacket (uint8_t bid, Ptr<Packet> p);
+
   /** 
    * Switch the UeManager to the given state
    * 
@@ -519,7 +556,15 @@ private:
    */
   TracedCallback<uint64_t, uint16_t, uint16_t, State, State> m_stateTransitionTrace;
 
+  /**
+   * The `DrbCreated` trace source. Fired when DRB is created, i.e.
+   * the RLC and PDCP entities are created for one logical channel.
+   * Exporting IMSI, cell ID, RNTI, and LCID
+   */
+  TracedCallback<uint64_t, uint16_t, uint16_t, uint8_t> m_drbCreatedTrace;
+
   uint16_t m_sourceX2apId; ///< source X2 ap ID
+  uint16_t m_targetX2apId; ///< target X2 ap ID
   uint16_t m_sourceCellId; ///< source cell ID
   uint16_t m_targetCellId; ///< target cell ID
   std::list<uint8_t> m_drbsToBeStarted; ///< DRBS to be started
@@ -565,6 +610,18 @@ private:
   /// Pending start data radio bearers
   bool m_pendingStartDataRadioBearers;
 
+
+  /**
+   * Packet buffer for when UE is doing the handover.
+   * The packets are stored with the bid (bearer ID).
+   *
+   * Source eNB starts forwarding data to target eNB through the X2 interface
+   * when it sends RRC Connection Reconfiguration to the UE.
+   * Target eNB buffers data until it receives RRC Connection Reconfiguration
+   * Complete from the UE.
+   */
+  std::list<std::pair<uint8_t, Ptr<Packet> > > m_packetBuffer;
+
 }; // end of `class UeManager`
 
 
@@ -856,13 +913,13 @@ public:
    *
    * \param ccPhyConf the component carrier configuration
    */
-  void ConfigureCell (std::map<uint8_t, Ptr<ComponentCarrierEnb>> ccPhyConf);
+  void ConfigureCell (std::map<uint8_t, Ptr<ComponentCarrierBaseStation> > ccPhyConf);
 
   /**
    * \brief Configure carriers.
    * \param ccPhyConf the component carrier configuration
    */
-  void ConfigureCarriers (std::map<uint8_t, Ptr<ComponentCarrierEnb>> ccPhyConf);
+  void ConfigureCarriers (std::map<uint8_t, Ptr<ComponentCarrierBaseStation>> ccPhyConf);
 
   /** 
    * set the cell id of this eNB
@@ -1030,6 +1087,19 @@ public:
     (const uint64_t imsi, const uint16_t cellId, const uint16_t rnti,
      const LteRrcSap::MeasurementReport report);
 
+  /**
+   * TracedCallback signature for timer expiry events
+   *
+   * \param [in] imsi
+   * \param [in] rnti
+   * \param [in] cellId
+   * \param [in] cause
+   */
+  typedef void (*TimerExpiryTracedCallback)
+      (const uint64_t imsi, const uint16_t rnti, const uint16_t cellId,
+       const std::string cause);
+
+
 private:
 
 
@@ -1083,9 +1153,26 @@ private:
    * \param msg the LteRrcSap::MeasurementReport
    */
   void DoRecvMeasurementReport (uint16_t rnti, LteRrcSap::MeasurementReport msg);
+  /**
+   * \brief Part of the RRC protocol. Forwarding LteEnbRrcSapProvider::RecvIdealUeContextRemoveRequest interface to UeManager::RecvIdealUeContextRemoveRequest.
+   *
+   * Remove the UE context at eNodeB and also remove the bearers established
+   * at SGW/PGW node. Bearer info at MME is not deleted since they are added at
+   * MME only at the beginning of simulation and if they are removed,
+   * the bearers cannot be activated again.
+   *
+   * \param rnti the C-RNTI identifying the user
+   */
+  void DoRecvIdealUeContextRemoveRequest (uint16_t rnti);
 
   // S1 SAP methods
 
+  /**
+   * Initial context setup request function
+   *
+   * \param params EpcEnbS1SapUser::InitialContextSetupRequestParameters
+   */
+  void DoInitialContextSetupRequest (EpcEnbS1SapUser::InitialContextSetupRequestParameters params);
   /**
    * Data radio beaerer setup request function
    *
@@ -1190,6 +1277,12 @@ private:
    * \returns measure ID
    */
   uint8_t DoAddUeMeasReportConfigForComponentCarrier (LteRrcSap::ReportConfigEutra reportConfig);
+  /**
+   * \brief Set number of component carriers
+   * \param numberOfComponentCarriers the number of component carriers
+   */
+  void DoSetNumberOfComponentCarriers (uint16_t numberOfComponentCarriers);
+
 
   /**
    * Trigger handover function
@@ -1261,6 +1354,20 @@ private:
    */
   TypeId GetRlcType (EpsBearer bearer);
 
+  /**
+   * \brief Is random access completed function
+   *
+   * This method is executed to decide if the non contention based
+   * preamble has to reused or not upon preamble expiry. If the random access
+   * in connected mode is completed, then the preamble can be reused by other UEs.
+   * If not, the same UE retains the preamble and other available preambles is
+   * assigned to the required UEs.
+   *
+   * \param rnti the C-RNTI identifying the user
+   * \return true if the random access in connected mode is completed
+   */
+  bool IsRandomAccessCompleted (uint16_t rnti);
+
 
 
 public:
@@ -1305,12 +1412,6 @@ public:
    */
   void SetCsgId (uint32_t csgId, bool csgIndication);
 
-  /**
-   * \brief Set number of component carriers
-   * \param numberOfComponentCarriers the number of component carriers
-   */
-  void SetNumberOfComponentCarriers (uint16_t numberOfComponentCarriers);
-
 private:
 
   /** 
@@ -1573,12 +1674,24 @@ private:
    * received. Exporting IMSI, cell ID, and RNTI.
    */
   TracedCallback<uint64_t, uint16_t, uint16_t, LteRrcSap::MeasurementReport> m_recvMeasurementReportTrace;
+  /**
+   * The `NotifyConnectionRelease` trace source. Fired when an UE leaves the eNB.
+   * Exporting IMSI, cell ID, RNTI.
+   *
+   */
+  TracedCallback<uint64_t, uint16_t, uint16_t> m_connectionReleaseTrace;
+  /**
+   * The 'TimerExpiry' Trace source. Fired when any of the RRC timers maintained
+   * at eNB expires. Exporting IMSI, cell ID, and RNTI and name of timer
+   * which expired.
+   */
+  TracedCallback<uint64_t, uint16_t, uint16_t, std::string> m_rrcTimeoutTrace;
 
   uint16_t m_numberOfComponentCarriers; ///< number of component carriers
 
   bool m_carriersConfigured; ///< are carriers configured
 
-  std::map<uint8_t, Ptr<ComponentCarrierEnb>> m_componentCarrierPhyConf; ///< component carrier phy configuration
+  std::map<uint8_t, Ptr<ComponentCarrierBaseStation>> m_componentCarrierPhyConf; ///< component carrier phy configuration
 
 }; // end of `class LteEnbRrc`
 
