@@ -67,6 +67,8 @@ public:
   virtual void AddLc (uint8_t lcId, LteUeCmacSapProvider::LogicalChannelConfig lcConfig, LteMacSapUser* msu);
   virtual void RemoveLc (uint8_t lcId);
   virtual void Reset ();
+  virtual void NotifyConnectionSuccessful ();
+  virtual void SetImsi (uint64_t imsi);
 
 private:
   LteUeMac* m_mac; ///< the UE MAC
@@ -120,6 +122,19 @@ UeMemberLteUeCmacSapProvider::Reset ()
   m_mac->DoReset ();
 }
 
+void
+UeMemberLteUeCmacSapProvider::NotifyConnectionSuccessful ()
+{
+  m_mac->DoNotifyConnectionSuccessful ();
+}
+
+void
+ UeMemberLteUeCmacSapProvider::SetImsi (uint64_t imsi)
+ {
+   m_mac->DoSetImsi (imsi);
+ }
+
+
 /// UeMemberLteMacSapProvider class
 class UeMemberLteMacSapProvider : public LteMacSapProvider
 {
@@ -220,7 +235,13 @@ LteUeMac::GetTypeId (void)
   static TypeId tid = TypeId ("ns3::LteUeMac")
     .SetParent<Object> ()
     .SetGroupName("Lte")
-    .AddConstructor<LteUeMac> ();
+    .AddConstructor<LteUeMac> ()
+    .AddTraceSource ("RaResponseTimeout",
+                     "trace fired upon RA response timeout",
+                     MakeTraceSourceAccessor (&LteUeMac::m_raResponseTimeoutTrace),
+                     "ns3::LteUeMac::RaResponseTimeoutTracedCallback")
+
+    ;
   return tid;
 }
 
@@ -231,6 +252,7 @@ LteUeMac::LteUeMac ()
      m_freshUlBsr (false),
      m_harqProcessId (0),
      m_rnti (0),
+     m_imsi (0),
      m_rachConfigured (false),
      m_waitingForRaResponse (false)
   
@@ -463,7 +485,14 @@ LteUeMac::RecvRaResponse (BuildRarListElement_s raResponse)
         {
           NS_FATAL_ERROR ("Function called on wrong componentCarrier");
         }
-      lc0InfoIt->second.macSapUser->NotifyTxOpportunity (raResponse.m_grant.m_tbSize, 0, 0, m_componentCarrierId, m_rnti, lc0Lcid); 
+      LteMacSapUser::TxOpportunityParameters txOpParams;
+      txOpParams.bytes = raResponse.m_grant.m_tbSize;
+      txOpParams.layer = 0;
+      txOpParams.harqId = 0;
+      txOpParams.componentCarrierId = m_componentCarrierId;
+      txOpParams.rnti = m_rnti;
+      txOpParams.lcid = lc0Lcid;
+      lc0InfoIt->second.macSapUser->NotifyTxOpportunity (txOpParams);
       lc0BsrIt->second.txQueueSize = 0;
     }
 }
@@ -475,6 +504,9 @@ LteUeMac::RaResponseTimeout (bool contention)
   m_waitingForRaResponse = false;
   // 3GPP 36.321 5.1.4
   ++m_preambleTransmissionCounter;
+  //fire RA response timeout trace
+  m_raResponseTimeoutTrace (m_imsi, contention, m_preambleTransmissionCounter,
+                            m_rachConfig.preambleTransMax + 1);
   if (m_preambleTransmissionCounter == m_rachConfig.preambleTransMax + 1)
     {
       NS_LOG_INFO ("RAR timeout, preambleTransMax reached => giving up");
@@ -521,14 +553,22 @@ LteUeMac::DoSetRnti (uint16_t rnti)
   m_rnti = rnti;
 }
 
+void
+LteUeMac::DoSetImsi (uint64_t imsi)
+{
+  NS_LOG_FUNCTION (this);
+  m_imsi = imsi;
+}
+
 
 void 
 LteUeMac::DoStartNonContentionBasedRandomAccessProcedure (uint16_t rnti, uint8_t preambleId, uint8_t prachMask)
 {
-  NS_LOG_FUNCTION (this << " rnti" << rnti);
+  NS_LOG_FUNCTION (this << rnti << (uint16_t) preambleId << (uint16_t) prachMask);
   NS_ASSERT_MSG (prachMask == 0, "requested PRACH MASK = " << (uint32_t) prachMask << ", but only PRACH MASK = 0 is supported");
   m_rnti = rnti;
   m_raPreambleId = preambleId;
+  m_preambleTransmissionCounter = 0;
   bool contention = false;
   SendRaPreamble (contention);
 }
@@ -537,7 +577,7 @@ void
 LteUeMac::DoAddLc (uint8_t lcId,  LteUeCmacSapProvider::LogicalChannelConfig lcConfig, LteMacSapUser* msu)
 {
   NS_LOG_FUNCTION (this << " lcId" << (uint32_t) lcId);
-  NS_ASSERT_MSG (m_lcInfoMap.find (lcId) == m_lcInfoMap.end (), "cannot add channel because LCID " << lcId << " is already present");
+  NS_ASSERT_MSG (m_lcInfoMap.find (lcId) == m_lcInfoMap.end (), "cannot add channel because LCID " << (uint16_t)lcId << " is already present");
   
   LcInfo lcInfo;
   lcInfo.lcConfig = lcConfig;
@@ -571,13 +611,21 @@ LteUeMac::DoReset ()
           m_lcInfoMap.erase (it++);
         }
     }
-
+  // note: rnti will be assigned by the eNB using RA response message
+  m_rnti = 0;
   m_noRaResponseReceivedEvent.Cancel ();
   m_rachConfigured = false;
   m_freshUlBsr = false;
   m_ulBsrReceived.clear ();
 }
 
+void
+LteUeMac::DoNotifyConnectionSuccessful ()
+{
+  NS_LOG_FUNCTION (this);
+  m_uePhySapProvider->NotifyConnectionSuccessful ();
+}
+
 void
 LteUeMac::DoReceivePhyPdu (Ptr<Packet> p)
 {
@@ -589,7 +637,11 @@ LteUeMac::DoReceivePhyPdu (Ptr<Packet> p)
       std::map <uint8_t, LcInfo>::const_iterator it = m_lcInfoMap.find (tag.GetLcid ());
       if (it != m_lcInfoMap.end ())
         {
-          it->second.macSapUser->ReceivePdu (p, m_rnti, tag.GetLcid ());
+          LteMacSapUser::ReceivePduParameters rxPduParams;
+          rxPduParams.p = p;
+          rxPduParams.rnti = m_rnti;
+          rxPduParams.lcid = tag.GetLcid ();
+          it->second.macSapUser->ReceivePdu (rxPduParams);
         }
       else
         {
@@ -650,6 +702,9 @@ LteUeMac::DoReceiveLteControlMessage (Ptr<LteControlMessage> msg)
                 }
             }
           NS_LOG_LOGIC (this << " UE " << m_rnti << ": UL-CQI notified TxOpportunity of " << dci.m_tbSize << " => " << bytesPerActiveLc << " bytes per active LC" << " statusPduMinSize " << statusPduMinSize);
+
+          LteMacSapUser::TxOpportunityParameters txOpParams;
+
           for (it = m_lcInfoMap.begin (); it != m_lcInfoMap.end (); it++)
             {
               itBsr = m_ulBsrReceived.find ((*it).first);
@@ -661,7 +716,13 @@ LteUeMac::DoReceiveLteControlMessage (Ptr<LteControlMessage> msg)
                 {
                   if ((statusPduPriority) && ((*itBsr).second.statusPduSize == statusPduMinSize))
                     {
-                      (*it).second.macSapUser->NotifyTxOpportunity ((*itBsr).second.statusPduSize, 0, 0, m_componentCarrierId, m_rnti, (*it).first);
+                      txOpParams.bytes = (*itBsr).second.statusPduSize;
+                      txOpParams.layer = 0;
+                      txOpParams.harqId = 0;
+                      txOpParams.componentCarrierId = m_componentCarrierId;
+                      txOpParams.rnti = m_rnti;
+                      txOpParams.lcid = (*it).first;
+                      (*it).second.macSapUser->NotifyTxOpportunity (txOpParams);
                       NS_LOG_LOGIC (this << "\t" << bytesPerActiveLc << " send  " << (*itBsr).second.statusPduSize << " status bytes to LC " << (uint32_t)(*it).first << " statusQueue " << (*itBsr).second.statusPduSize << " retxQueue" << (*itBsr).second.retxQueueSize << " txQueue" <<  (*itBsr).second.txQueueSize);
                       (*itBsr).second.statusPduSize = 0;
                       break;
@@ -672,7 +733,13 @@ LteUeMac::DoReceiveLteControlMessage (Ptr<LteControlMessage> msg)
                       NS_LOG_LOGIC (this << "\t" << bytesPerActiveLc << " bytes to LC " << (uint32_t)(*it).first << " statusQueue " << (*itBsr).second.statusPduSize << " retxQueue" << (*itBsr).second.retxQueueSize << " txQueue" <<  (*itBsr).second.txQueueSize);
                       if (((*itBsr).second.statusPduSize > 0) && (bytesForThisLc > (*itBsr).second.statusPduSize))
                         {
-                          (*it).second.macSapUser->NotifyTxOpportunity ((*itBsr).second.statusPduSize, 0, 0, m_componentCarrierId, m_rnti, (*it).first);
+                          txOpParams.bytes = (*itBsr).second.statusPduSize;
+                          txOpParams.layer = 0;
+                          txOpParams.harqId = 0;
+                          txOpParams.componentCarrierId = m_componentCarrierId;
+                          txOpParams.rnti = m_rnti;
+                          txOpParams.lcid = (*it).first;
+                          (*it).second.macSapUser->NotifyTxOpportunity (txOpParams);
                           bytesForThisLc -= (*itBsr).second.statusPduSize;
                           NS_LOG_DEBUG (this << " serve STATUS " << (*itBsr).second.statusPduSize);
                           (*itBsr).second.statusPduSize = 0;
@@ -692,7 +759,13 @@ LteUeMac::DoReceiveLteControlMessage (Ptr<LteControlMessage> msg)
                           if ((*itBsr).second.retxQueueSize > 0)
                             {
                               NS_LOG_DEBUG (this << " serve retx DATA, bytes " << bytesForThisLc);
-                              (*it).second.macSapUser->NotifyTxOpportunity (bytesForThisLc, 0, 0, m_componentCarrierId, m_rnti, (*it).first);
+                              txOpParams.bytes = bytesForThisLc;
+                              txOpParams.layer = 0;
+                              txOpParams.harqId = 0;
+                              txOpParams.componentCarrierId = m_componentCarrierId;
+                              txOpParams.rnti = m_rnti;
+                              txOpParams.lcid = (*it).first;
+                              (*it).second.macSapUser->NotifyTxOpportunity (txOpParams);
                               if ((*itBsr).second.retxQueueSize >= bytesForThisLc)
                                 {
                                   (*itBsr).second.retxQueueSize -= bytesForThisLc;
@@ -712,7 +785,7 @@ LteUeMac::DoReceiveLteControlMessage (Ptr<LteControlMessage> msg)
                                   // overestimate RLC overhead rather than
                                   // underestimate it and risk unneeded
                                   // segmentation which increases delay 
-                                  rlcOverhead = 4;                                  
+                                  rlcOverhead = 4;
                                 }
                               else
                                 {
@@ -720,7 +793,13 @@ LteUeMac::DoReceiveLteControlMessage (Ptr<LteControlMessage> msg)
                                   rlcOverhead = 2;
                                 }
                               NS_LOG_DEBUG (this << " serve tx DATA, bytes " << bytesForThisLc << ", RLC overhead " << rlcOverhead);
-                              (*it).second.macSapUser->NotifyTxOpportunity (bytesForThisLc, 0, 0, m_componentCarrierId, m_rnti, (*it).first);
+                              txOpParams.bytes = bytesForThisLc;
+                              txOpParams.layer = 0;
+                              txOpParams.harqId = 0;
+                              txOpParams.componentCarrierId = m_componentCarrierId;
+                              txOpParams.rnti = m_rnti;
+                              txOpParams.lcid = (*it).first;
+                              (*it).second.macSapUser->NotifyTxOpportunity (txOpParams);
                               if ((*itBsr).second.txQueueSize >= bytesForThisLc - rlcOverhead)
                                 {
                                   (*itBsr).second.txQueueSize -= bytesForThisLc - rlcOverhead;
@@ -823,7 +902,11 @@ LteUeMac::DoSubframeIndication (uint32_t frameNo, uint32_t subframeNo)
   RefreshHarqProcessesPacketBuffer ();
   if ((Simulator::Now () >= m_bsrLast + m_bsrPeriodicity) && (m_freshUlBsr == true))
     {
-      SendReportBufferStatus ();
+      if (m_componentCarrierId == 0)
+        {
+          //Send BSR through primary carrier
+          SendReportBufferStatus ();
+        }
       m_bsrLast = Simulator::Now ();
       m_freshUlBsr = false;
     }
