@@ -1,6 +1,7 @@
 /* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
 /*
  * Copyright (c) 2010 TELEMATICS LAB, DEE - Politecnico di Bari
+ * Copyright (c) 2018 Fraunhofer ESK : RLF extensions
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
@@ -18,6 +19,8 @@
  * Author: Giuseppe Piro  <g.piro@poliba.it>
  *         Marco Miozzo <marco.miozzo@cttc.es>
  *         Nicola Baldo <nbaldo@cttc.es>
+ * Modified by:
+ *          Vignesh Babu <ns3-dev@esk.fraunhofer.de> (RLF extensions)
  */
 
 #include <ns3/object-factory.h>
@@ -85,6 +88,7 @@ public:
   virtual void SendMacPdu (Ptr<Packet> p);
   virtual void SendLteControlMessage (Ptr<LteControlMessage> msg);
   virtual void SendRachPreamble (uint32_t prachId, uint32_t raRnti);
+  virtual void NotifyConnectionSuccessful ();
 
 private:
   LteUePhy* m_phy; ///< the Phy
@@ -113,6 +117,12 @@ UeMemberLteUePhySapProvider::SendRachPreamble (uint32_t prachId, uint32_t raRnti
   m_phy->DoSendRachPreamble (prachId, raRnti);
 }
 
+void
+UeMemberLteUePhySapProvider::NotifyConnectionSuccessful ()
+{
+  m_phy->DoNotifyConnectionSuccessful ();
+}
+
 
 ////////////////////////////////////////
 // LteUePhy methods
@@ -146,8 +156,6 @@ LteUePhy::LteUePhy ()
 
 LteUePhy::LteUePhy (Ptr<LteSpectrumPhy> dlPhy, Ptr<LteSpectrumPhy> ulPhy)
   : LtePhy (dlPhy, ulPhy),
-    m_p10CqiPeriodicity (MilliSeconds (1)),  // ideal behavior
-    m_a30CqiPeriodicity (MilliSeconds (1)),  // ideal behavior
     m_uePhySapUser (0),
     m_ueCphySapUser (0),
     m_state (CELL_SEARCH),
@@ -158,7 +166,8 @@ LteUePhy::LteUePhy (Ptr<LteSpectrumPhy> dlPhy, Ptr<LteSpectrumPhy> ulPhy)
     m_pssReceived (false),
     m_ueMeasurementsFilterPeriod (MilliSeconds (200)),
     m_ueMeasurementsFilterLast (MilliSeconds (0)),
-    m_rsrpSinrSampleCounter (0)
+    m_rsrpSinrSampleCounter (0),
+    m_imsi (0)
 {
   m_amc = CreateObject <LteAmc> ();
   m_powerControl = CreateObject <LteUePowerControl> ();
@@ -286,6 +295,12 @@ LteUePhy::GetTypeId (void)
                    TimeValue (MilliSeconds (200)),
                    MakeTimeAccessor (&LteUePhy::m_ueMeasurementsFilterPeriod),
                    MakeTimeChecker ())
+    .AddAttribute ("DownlinkCqiPeriodicity",
+                   "Periodicity in milliseconds for reporting the"
+                   "wideband and subband downlink CQIs to the eNB",
+                   TimeValue (MilliSeconds (1)),
+                   MakeTimeAccessor (&LteUePhy::SetDownlinkCqiPeriodicity),
+                   MakeTimeChecker ())
     .AddTraceSource ("ReportUeMeasurements",
                      "Report UE measurements RSRP (dBm) and RSRQ (dB).",
                      MakeTraceSourceAccessor (&LteUePhy::m_reportUeMeasurements),
@@ -299,6 +314,39 @@ LteUePhy::GetTypeId (void)
                    BooleanValue (true),
                    MakeBooleanAccessor (&LteUePhy::m_enableUplinkPowerControl),
                    MakeBooleanChecker ())
+    .AddAttribute ("Qout",
+                   "corresponds to 10% block error rate of a hypothetical PDCCH transmission"
+                   "taking into account the PCFICH errors with transmission parameters."
+                   "see 3GPP TS 36.213 4.2.1 and TS 36.133 7.6",
+                   DoubleValue (-5),
+                   MakeDoubleAccessor (&LteUePhy::m_qOut),
+                   MakeDoubleChecker<double> ())
+    .AddAttribute ("Qin",
+                   "corresponds to 2% block error rate of a hypothetical PDCCH transmission"
+                   "taking into account the PCFICH errors with transmission parameters."
+                   "see 3GPP TS 36.213 4.2.1 and TS 36.133 7.6",
+                   DoubleValue (-3.9),
+                   MakeDoubleAccessor (&LteUePhy::m_qIn),
+                   MakeDoubleChecker<double> ())
+    .AddAttribute ("NumQoutEvalSf",
+                   "This specifies the total number of consecutive subframes"
+                   "which corresponds to the Qout evaluation period",
+                   UintegerValue (200), //see 3GPP 3GPP TS 36.133 7.6.2.1
+                   MakeUintegerAccessor (&LteUePhy::SetNumQoutEvalSf,
+                                         &LteUePhy::GetNumQoutEvalSf),
+                   MakeUintegerChecker<uint16_t> ())
+    .AddAttribute ("NumQinEvalSf",
+                   "This specifies the total number of consecutive subframes"
+                   "which corresponds to the Qin evaluation period",
+                   UintegerValue (100), //see 3GPP 3GPP TS 36.133 7.6.2.1
+                   MakeUintegerAccessor (&LteUePhy::SetNumQinEvalSf,
+                                         &LteUePhy::GetNumQinEvalSf),
+                   MakeUintegerChecker<uint16_t> ())
+    .AddAttribute ("EnableRlfDetection",
+                   "If true, RLF detection will be enabled.",
+                   BooleanValue (true),
+                   MakeBooleanAccessor (&LteUePhy::m_enableRlfDetection),
+                   MakeBooleanChecker ())
   ;
   return tid;
 }
@@ -307,25 +355,17 @@ void
 LteUePhy::DoInitialize ()
 {
   NS_LOG_FUNCTION (this);
-  bool haveNodeId = false;
-  uint32_t nodeId = 0;
-  if (m_netDevice != 0)
-    {
-      Ptr<Node> node = m_netDevice->GetNode ();
-      if (node != 0)
-        {
-          nodeId = node->GetId ();
-          haveNodeId = true;
-        }
-    }
-  if (haveNodeId)
-    {
-      Simulator::ScheduleWithContext (nodeId, Seconds (0), &LteUePhy::SubframeIndication, this, 1, 1);
-    }
-  else
-    {
-      Simulator::ScheduleNow (&LteUePhy::SubframeIndication, this, 1, 1);
-    }  
+
+  NS_ABORT_MSG_IF (m_netDevice == nullptr, "LteNetDevice is not available in LteUePhy");
+  Ptr<Node> node = m_netDevice->GetNode ();
+  NS_ABORT_MSG_IF (node == nullptr, "Node is not available in the LteNetDevice of LteUePhy");
+  uint32_t nodeId = node->GetId ();
+
+  //ScheduleWithContext() is needed here to set context for logs,
+  //because Initialize() is called outside of Node::AddDevice().
+
+  Simulator::ScheduleWithContext (nodeId, Seconds (0), &LteUePhy::SubframeIndication, this, 1, 1);
+
   LtePhy::DoInitialize ();
 }
 
@@ -412,6 +452,38 @@ LteUePhy::GetUlSpectrumPhy () const
   return m_uplinkSpectrumPhy;
 }
 
+void
+LteUePhy::SetNumQoutEvalSf (uint16_t numSubframes)
+{
+  NS_LOG_FUNCTION (this << numSubframes);
+  NS_ABORT_MSG_IF (numSubframes % 10 != 0, "Number of subframes used for Qout "
+                                           "evaluation must be multiple of 10");
+  m_numOfQoutEvalSf = numSubframes;
+}
+
+void
+LteUePhy::SetNumQinEvalSf (uint16_t numSubframes)
+{
+  NS_LOG_FUNCTION (this << numSubframes);
+  NS_ABORT_MSG_IF (numSubframes % 10 != 0, "Number of subframes used for Qin "
+                                           "evaluation must be multiple of 10");
+  m_numOfQinEvalSf = numSubframes;
+}
+
+uint16_t
+LteUePhy::GetNumQoutEvalSf (void) const
+{
+  NS_LOG_FUNCTION (this);
+  return m_numOfQoutEvalSf;
+}
+
+uint16_t
+LteUePhy::GetNumQinEvalSf (void) const
+{
+  NS_LOG_FUNCTION (this);
+  return m_numOfQinEvalSf;
+}
+
 void
 LteUePhy::DoSendMacPdu (Ptr<Packet> p)
 {
@@ -468,7 +540,7 @@ LteUePhy::CreateTxPowerSpectralDensity ()
 {
   NS_LOG_FUNCTION (this);
   LteSpectrumValueHelper psdHelper;
-  Ptr<SpectrumValue> psd = psdHelper.CreateTxPowerSpectralDensity (m_ulEarfcn, m_ulBandwidth, m_txPower, GetSubChannelsForTransmission ());
+  Ptr<SpectrumValue> psd = psdHelper.CreateUlTxPowerSpectralDensity (m_ulEarfcn, m_ulBandwidth, m_txPower, GetSubChannelsForTransmission ());
 
   return psd;
 }
@@ -477,7 +549,20 @@ void
 LteUePhy::GenerateCtrlCqiReport (const SpectrumValue& sinr)
 {
   NS_LOG_FUNCTION (this);
-  
+  /**
+   * We do not generate the CQI report
+   * when the UE is not synchronized to any cell.
+   *
+   * Also, the RLF is detected after the DL CTRL
+   * is received by the UE,therefore, we do not need
+   * to generate the CQI reports and the UE measurements
+   * for a CTRL for which the RLF has been detected.
+   */
+  if (m_cellId == 0)
+    {
+      return;
+    }
+  m_ctrlSinrForRlf = sinr;
   GenerateCqiRsrpRsrq (sinr);
 }
 
@@ -494,6 +579,8 @@ LteUePhy::GenerateCqiRsrpRsrq (const SpectrumValue& sinr)
       // check periodic wideband CQI
       if (Simulator::Now () > m_p10CqiLast + m_p10CqiPeriodicity)
         {
+          NS_LOG_DEBUG("Reporting P10 CQI at : " << Simulator::Now().GetMilliSeconds()
+                       << " ms. Last reported at : " << m_p10CqiLast.GetMilliSeconds() << " ms");
           Ptr<LteUeNetDevice> thisDevice = GetDevice ()->GetObject<LteUeNetDevice> ();
           Ptr<DlCqiLteControlMessage> msg = CreateDlCqiFeedbackMessage (sinr);
           if (msg)
@@ -505,6 +592,8 @@ LteUePhy::GenerateCqiRsrpRsrq (const SpectrumValue& sinr)
       // check aperiodic high-layer configured subband CQI
       if  (Simulator::Now () > m_a30CqiLast + m_a30CqiPeriodicity)
         {
+          NS_LOG_DEBUG("Reporting A30 CQI at : " << Simulator::Now().GetMilliSeconds()
+                       << " ms. Last reported at : " << m_a30CqiLast.GetMilliSeconds() << " ms");
           Ptr<LteUeNetDevice> thisDevice = GetDevice ()->GetObject<LteUeNetDevice> ();
           Ptr<DlCqiLteControlMessage> msg = CreateDlCqiFeedbackMessage (sinr);
           if (msg)
@@ -535,15 +624,16 @@ LteUePhy::GenerateCqiRsrpRsrq (const SpectrumValue& sinr)
         }
       double rsrp = (rbNum > 0) ? (sum / rbNum) : DBL_MAX;
       // averaged SINR among RBs
-      sum = 0.0;
-      rbNum = 0;
-      for (it = sinr.ConstValuesBegin (); it != sinr.ConstValuesEnd (); it++)
-        {
-          sum += (*it);
-          rbNum++;
-        }
-      double avSinr = (rbNum > 0) ? (sum / rbNum) : DBL_MAX;
+      double avSinr = ComputeAvgSinr (sinr);
+
       NS_LOG_INFO (this << " cellId " << m_cellId << " rnti " << m_rnti << " RSRP " << rsrp << " SINR " << avSinr << " ComponentCarrierId " << (uint16_t) m_componentCarrierId);
+      //trigger RLF detection only when UE has an active RRC connection
+      //and RLF detection attribute is set to true
+      if (m_isConnected && m_enableRlfDetection)
+        {
+          double avrgSinrForRlf = ComputeAvgSinr (m_ctrlSinrForRlf);
+          RlfDetection (10 * log10 (avrgSinrForRlf));
+        }
 
       m_reportCurrentCellRsrpSinrTrace (m_cellId, m_rnti, rsrp, avSinr, (uint16_t) m_componentCarrierId);
       m_rsrpSinrSampleCounter = 0;
@@ -604,6 +694,27 @@ LteUePhy::GenerateCqiRsrpRsrq (const SpectrumValue& sinr)
 
 } // end of void LteUePhy::GenerateCtrlCqiReport (const SpectrumValue& sinr)
 
+double
+LteUePhy::ComputeAvgSinr (const SpectrumValue& sinr)
+{
+  NS_LOG_FUNCTION (this);
+
+  // averaged SINR among RBs
+  double sum = 0.0;
+  uint8_t rbNum = 0;
+  Values::const_iterator it;
+
+  for (it = sinr.ConstValuesBegin (); it != sinr.ConstValuesEnd (); it++)
+    {
+      sum += (*it);
+      rbNum++;
+    }
+
+  double avrgSinr = (rbNum > 0) ? (sum / rbNum) : DBL_MAX;
+
+  return avrgSinr;
+}
+
 void
 LteUePhy::GenerateDataCqiReport (const SpectrumValue& sinr)
 {
@@ -615,8 +726,26 @@ LteUePhy::GenerateMixedCqiReport (const SpectrumValue& sinr)
 {
   NS_LOG_FUNCTION (this);
 
+  /**
+   * We do not generate the CQI report
+   * when the UE is not synchronized to any cell.
+   *
+   * Also, the RLF is detected after the DL CTRL
+   * is received by the UE,therefore, we do not need
+   * to generate the CQI reports and the UE measurements
+   * for a CTRL for which the RLF has been detected.
+   */
+  if (m_cellId == 0)
+    {
+      return;
+    }
+
   NS_ASSERT (m_state != CELL_SEARCH);
-  NS_ASSERT (m_cellId > 0);
+  //NOTE: The SINR received by this method is
+  //based on CTRL, which is not used to compute
+  //PDSCH (i.e., data) based SINR. It is used
+  //for RLF detection.
+  m_ctrlSinrForRlf = sinr;
 
   SpectrumValue mixedSinr = (m_rsReceivedPower * m_paLinear);
   if (m_dataInterferencePowerUpdated)
@@ -843,6 +972,14 @@ LteUePhy::ReportUeMeasurements ()
   Simulator::Schedule (m_ueMeasurementsFilterPeriod, &LteUePhy::ReportUeMeasurements, this);
 }
 
+void
+LteUePhy::SetDownlinkCqiPeriodicity (Time cqiPeriodicity)
+{
+  NS_LOG_FUNCTION (this << cqiPeriodicity);
+  m_a30CqiPeriodicity = cqiPeriodicity;
+  m_p10CqiPeriodicity = cqiPeriodicity;
+}
+
 void
 LteUePhy::DoSendLteControlMessage (Ptr<LteControlMessage> msg)
 {
@@ -864,6 +1001,23 @@ LteUePhy::DoSendRachPreamble (uint32_t raPreambleId, uint32_t raRnti)
   m_controlMessagesQueue.at (0).push_back (msg);
 }
 
+void
+LteUePhy::DoNotifyConnectionSuccessful ()
+{
+  /**
+   * Radio link failure detection should take place only on the
+   * primary carrier to avoid errors due to multiple calls to the
+   * same methods at the RRC layer
+   */
+  if (m_componentCarrierId == 0)
+    {
+      m_isConnected = true;
+      // Initialize the parameters for radio link failure detection
+      InitializeRlfParams ();
+    }
+}
+
+
 
 void
 LteUePhy::ReceiveLteControlMessageList (std::list<Ptr<LteControlMessage> > msgList)
@@ -1199,6 +1353,8 @@ LteUePhy::DoReset ()
   NS_LOG_FUNCTION (this);
 
   m_rnti = 0;
+  m_cellId = 0;
+  m_isConnected = false;
   m_transmissionMode = 0;
   m_srsPeriodicity = 0;
   m_srsConfigured = false;
@@ -1227,6 +1383,13 @@ LteUePhy::DoReset ()
   m_sendSrsEvent.Cancel ();
   m_downlinkSpectrumPhy->Reset ();
   m_uplinkSpectrumPhy->Reset ();
+  m_pssList.clear ();
+  /**
+   * Call the EndRx() method of the interference model for DL control and data
+   * to cancel any ongoing downlink reception of control and data info.
+   */
+  m_downlinkSpectrumPhy->m_interferenceCtrl->EndRx ();
+  m_downlinkSpectrumPhy->m_interferenceData->EndRx ();
 
 } // end of void LteUePhy::DoReset ()
 
@@ -1356,6 +1519,146 @@ LteUePhy::DoSetPa (double pa)
 }
 
 void 
+LteUePhy::DoSetRsrpFilterCoefficient (uint8_t rsrpFilterCoefficient)
+{
+  NS_LOG_FUNCTION (this << (uint16_t) (rsrpFilterCoefficient));
+  m_powerControl->SetRsrpFilterCoefficient (rsrpFilterCoefficient);
+}
+
+void
+LteUePhy::DoResetPhyAfterRlf ()
+{
+  NS_LOG_FUNCTION (this);
+  m_downlinkSpectrumPhy->m_harqPhyModule->ClearDlHarqBuffer (m_rnti); //flush HARQ buffers
+  m_dataInterferencePowerUpdated = false;
+  m_rsInterferencePowerUpdated = false;
+  m_pssReceived = false;
+  DoReset ();
+}
+
+void
+LteUePhy::DoResetRlfParams ()
+{
+  NS_LOG_FUNCTION (this);
+
+  InitializeRlfParams ();
+}
+
+void
+LteUePhy::DoStartInSnycDetection ()
+{
+  NS_LOG_FUNCTION (this);
+  // indicates that the downlink radio link quality has to be monitored for in-sync indications
+  m_downlinkInSync = false;
+}
+
+void
+LteUePhy::DoSetImsi (uint64_t imsi)
+{
+  NS_LOG_FUNCTION (this);
+  m_imsi = imsi;
+}
+
+void
+LteUePhy::InitializeRlfParams ()
+{
+  NS_LOG_FUNCTION (this);
+  m_numOfSubframes = 0;
+  m_sinrDbFrame = 0;
+  m_numOfFrames = 0;
+  m_downlinkInSync = true;
+}
+
+void
+LteUePhy::RlfDetection (double sinrDb)
+{
+  NS_LOG_FUNCTION (this << sinrDb);
+  m_sinrDbFrame += sinrDb;
+  m_numOfSubframes++;
+  NS_LOG_LOGIC ("No of Subframes: " << m_numOfSubframes << " UE synchronized: " << m_downlinkInSync);
+  //check for out_of_snyc indications first when UE is both DL and UL synchronized
+  //m_downlinkInSync=true indicates that the evaluation is for out-of-sync indications
+  if (m_downlinkInSync && m_numOfSubframes == 10)
+    {
+      /**
+       * For every frame, if the downlink radio link quality(avg SINR)
+       * is less than the threshold Qout, then the frame cannot be decoded
+       */
+      if ((m_sinrDbFrame / m_numOfSubframes) < m_qOut)
+        {
+          m_numOfFrames++; //increment the counter if a frame cannot be decoded
+          NS_LOG_LOGIC ("No of Frames which cannot be decoded: " << m_numOfFrames);
+        }
+      else
+        {
+          /**
+           * If the downlink radio link quality(avg SINR) is greater
+           * than the threshold Qout, then the frame counter is reset
+           * since only consecutive frames should be considered.
+           */
+          NS_LOG_INFO ("Resetting frame counter at phy. Current value = " << m_numOfFrames);
+          m_numOfFrames = 0;
+          // Also reset the sync indicator counter at RRC
+          m_ueCphySapUser->ResetSyncIndicationCounter ();
+        }
+      m_numOfSubframes = 0;
+      m_sinrDbFrame = 0;
+    }
+  /**
+   * Once the number of consecutive frames which cannot be decoded equals
+   * the Qout evaluation period (i.e 200ms), then an out-of-sync indication
+   * is sent to the RRC layer
+   */
+  if (m_downlinkInSync && (m_numOfFrames * 10) == m_numOfQoutEvalSf)
+    {
+      NS_LOG_LOGIC ("At " << Simulator::Now ().GetMilliSeconds()
+               << " ms UE PHY sending out of snyc indication to UE RRC layer");
+      m_ueCphySapUser->NotifyOutOfSync ();
+      m_numOfFrames = 0;
+    }
+  //check for in_snyc indications when T310 timer is started
+  //m_downlinkInSync=false indicates that the evaluation is for in-sync indications
+  if (!m_downlinkInSync && m_numOfSubframes == 10)
+    {
+      /**
+       * For every frame, if the downlink radio link quality(avg SINR)
+       * is greater than the threshold Qin, then the frame can be
+       * successfully decoded.
+       */
+      if ((m_sinrDbFrame / m_numOfSubframes) > m_qIn)
+        {
+          m_numOfFrames++; //increment the counter if a frame can be decoded
+          NS_LOG_LOGIC ("No of Frames successfully decoded: " << m_numOfFrames);
+        }
+      else
+        {
+          /**
+           * If the downlink radio link quality(avg SINR) is less
+           * than the threshold Qin, then the frame counter is reset
+           * since only consecutive frames should be considered
+           */
+          m_numOfFrames = 0;
+          // Also reset the sync indicator counter at RRC
+          m_ueCphySapUser->ResetSyncIndicationCounter ();
+        }
+      m_numOfSubframes = 0;
+      m_sinrDbFrame = 0;
+    }
+  /**
+   * Once the number of consecutive frames which can be decoded equals the Qin evaluation period (i.e 100ms),
+   * then an in-sync indication is sent to the RRC layer
+   */
+  if (!m_downlinkInSync && (m_numOfFrames * 10) == m_numOfQinEvalSf)
+    {
+      NS_LOG_LOGIC ("At " << Simulator::Now ().GetMilliSeconds()
+                   << " ms UE PHY sending in snyc indication to UE RRC layer");
+      m_ueCphySapUser->NotifyInSync ();
+      m_numOfFrames = 0;
+    }
+}
+
+
+void
 LteUePhy::SetTxMode1Gain (double gain)
 {
   SetTxModeGain (1, gain);
