@@ -1,6 +1,7 @@
 /* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
 /*
  * Copyright (c) 2010 TELEMATICS LAB, DEE - Politecnico di Bari
+ * Copyright (c) 2018 Fraunhofer ESK : RLF extensions
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
@@ -17,6 +18,8 @@
  *
  * Author: Giuseppe Piro  <g.piro@poliba.it>
  * Author: Marco Miozzo <mmiozzo@cttc.es>
+ * Modified by:
+ *          Vignesh Babu <ns3-dev@esk.fraunhofer.de> (RLF extensions)
  */
 
 #ifndef LTE_UE_PHY_H
@@ -92,103 +95,129 @@ public:
 
   /**
    * \brief Get the PHY SAP provider
+   *
    * \return a pointer to the SAP Provider 
    */
   LteUePhySapProvider* GetLteUePhySapProvider ();
 
   /**
-  * \brief Set the PHY SAP User
-  * \param s a pointer to the SAP user
-  */
+   * \brief Set the PHY SAP User
+   *
+   * \param s a pointer to the SAP user
+   */
   void SetLteUePhySapUser (LteUePhySapUser* s);
 
   /**
    * \brief Get the CPHY SAP provider
+   *
    * \return a pointer to the SAP Provider
    */
   LteUeCphySapProvider* GetLteUeCphySapProvider ();
 
   /**
-  * \brief Set the CPHY SAP User
-  * \param s a pointer to the SAP user
-  */
+   * \brief Set the CPHY SAP User
+   *
+   * \param s a pointer to the SAP user
+   */
   void SetLteUeCphySapUser (LteUeCphySapUser* s);
 
 
   /**
+   * \brief Set transmit power
+   *
    * \param pow the transmission power in dBm
    */
   void SetTxPower (double pow);
 
   /**
+   * \brief Get transmit power
+   *
    * \return the transmission power in dBm
    */
   double GetTxPower () const;
 
   /**
+   * \brief Get Uplink power control
+   *
    * \return ptr to UE Uplink Power Control entity
    */
   Ptr<LteUePowerControl> GetUplinkPowerControl () const;
 
   /**
+   * \brief Set noise figure
+   *
    * \param nf the noise figure in dB
    */
   void SetNoiseFigure (double nf);
 
   /**
+   * \brief Get noise figure
+   *
    * \return the noise figure in dB
    */
   double GetNoiseFigure () const;
 
   /**
+   * \brief Get MAC to Channel delay
+   *
    * \returns the TTI delay between MAC and channel
    */
   uint8_t GetMacChDelay (void) const;
 
   /**
+   * \brief Get Downlink spectrum phy
+   *
    * \return a pointer to the LteSpectrumPhy instance relative to the downlink
    */
   Ptr<LteSpectrumPhy> GetDlSpectrumPhy () const;
 
   /**
+   * \brief Get Uplink spectrum phy
+   *
    * \return a pointer to the LteSpectrumPhy instance relative to the uplink
    */
   Ptr<LteSpectrumPhy> GetUlSpectrumPhy () const;
 
   /**
    * \brief Create the PSD for the TX
+   *
    * \return the pointer to the PSD
    */
   virtual Ptr<SpectrumValue> CreateTxPowerSpectralDensity ();
 
   /**
    * \brief Set a list of sub channels to use in TX
+   *
    * \param mask a list of sub channels
    */
   void SetSubChannelsForTransmission (std::vector <int> mask);
   /**
    * \brief Get a list of sub channels to use in RX
+   *
    * \return a list of sub channels
    */
   std::vector <int> GetSubChannelsForTransmission (void);
 
   /**
    * \brief Get a list of sub channels to use in RX
+   *
    * \param mask list of sub channels
    */
   void SetSubChannelsForReception (std::vector <int> mask);
   /**
    * \brief Get a list of sub channels to use in RX
+   *
    * \return a list of sub channels
    */
   std::vector <int> GetSubChannelsForReception (void);
 
   /**
-  * \brief Create the DL CQI feedback from SINR values perceived at
-  * the physical layer with the signal received from eNB
-  * \param sinr SINR values vector
-  * \return a DL CQI control message containing the CQI feedback
-  */
+   * \brief Create the DL CQI feedback from SINR values perceived at
+   * the physical layer with the signal received from eNB
+   *
+   * \param sinr SINR values vector
+   * \return a DL CQI control message containing the CQI feedback
+   */
   Ptr<DlCqiLteControlMessage> CreateDlCqiFeedbackMessage (const SpectrumValue& sinr);
 
 
@@ -197,49 +226,50 @@ public:
   virtual void GenerateCtrlCqiReport (const SpectrumValue& sinr);
   virtual void GenerateDataCqiReport (const SpectrumValue& sinr);
   /**
-  * \brief Create the mixed CQI report
-  *
-  * \param sinr SINR values vector
-  */
+   * \brief Create the mixed CQI report
+   *
+   * \param sinr SINR values vector
+   */
   virtual void GenerateMixedCqiReport (const SpectrumValue& sinr);
   virtual void ReportInterference (const SpectrumValue& interf);
   /**
-  * \brief Create the mixed CQI report
-  *
-  * \param interf interference values vector
-  */
+   * \brief Create the mixed CQI report
+   *
+   * \param interf interference values vector
+   */
   virtual void ReportDataInterference (const SpectrumValue& interf);
   virtual void ReportRsReceivedPower (const SpectrumValue& power);
 
   // callbacks for LteSpectrumPhy
   /**
-  * \brief Receive LTE control message list function
-  *
-  * \param msgList LTE control message list
-  */
+   * \brief Receive LTE control message list function
+   *
+   * \param msgList LTE control message list
+   */
   virtual void ReceiveLteControlMessageList (std::list<Ptr<LteControlMessage> > msgList);
   /**
-  * \brief Receive PSS function
-  *
-  * \param cellId the cell ID
-  * \param p PSS list
-  */
+   * \brief Receive PSS function
+   *
+   * \param cellId the cell ID
+   * \param p PSS list
+   */
   virtual void ReceivePss (uint16_t cellId, Ptr<SpectrumValue> p);
 
 
   /**
    * \brief PhySpectrum received a new PHY-PDU
+   *
    * \param p the packet received
    */
   void PhyPduReceived (Ptr<Packet> p);
 
 
   /**
-  * \brief trigger from eNB the start from a new frame
-  *
-  * \param frameNo frame number
-  * \param subframeNo subframe number
-  */
+   * \brief trigger from eNB the start from a new frame
+   *
+   * \param frameNo frame number
+   * \param subframeNo subframe number
+   */
   void SubframeIndication (uint32_t frameNo, uint32_t subframeNo);
 
 
@@ -250,17 +280,21 @@ public:
 
   /**
    * \brief PhySpectrum generated a new DL HARQ feedback
+   *
    * \param mes the DlInfoListElement_s
    */
   virtual void ReceiveLteDlHarqFeedback (DlInfoListElement_s mes);
 
   /**
    * \brief Set the HARQ PHY module
+   *
    * \param harq the HARQ PHY module
    */
   void SetHarqPhyModule (Ptr<LteHarqPhy> harq);
 
   /**
+   * \brief Get state of the UE physical layer
+   *
    * \return The current state
    */
   State GetState () const;
@@ -306,7 +340,7 @@ public:
 private:
 
   /**
-   * Set transmit mode 1 gain function
+   * \brief Set transmit mode 1 gain function
    *
    * \param [in] gain
    */
@@ -318,60 +352,57 @@ private:
    */
   void SetTxMode2Gain (double gain);
   /**
-   * Set transmit mode 3 gain function
+   * \brief Set transmit mode 3 gain function
    *
    * \param [in] gain
    */
   void SetTxMode3Gain (double gain);
   /**
-   * Set transmit mode 4 gain function
+   * \brief Set transmit mode 4 gain function
    *
    * \param [in] gain
    */
   void SetTxMode4Gain (double gain);
   /**
-   * Set transmit mode 5 gain function
+   * \brief Set transmit mode 5 gain function
    *
    * \param [in] gain
    */
   void SetTxMode5Gain (double gain);
   /**
-   * Set transmit mode 6 gain function
+   * \brief Set transmit mode 6 gain function
    *
    * \param [in] gain
    */
   void SetTxMode6Gain (double gain);
   /**
-   * Set transmit mode 7 gain function
+   * \brief Set transmit mode 7 gain function
    *
    * \param [in] gain
    */
   void SetTxMode7Gain (double gain);
   /**
-   * Set transmit mode gain function
+   * \brief Set transmit mode gain function
    *
    * \param [in] txMode
    * \param [in] gain
    */
   void SetTxModeGain (uint8_t txMode, double gain);
-
   /**
-   * queue subchannels for transmission function
+   * \brief Queue subchannels for transmission function
    *
    * \param [in] rbMap
    */
   void QueueSubChannelsForTransmission (std::vector <int> rbMap);
-
-
   /** 
+   * \brief Get CQI, RSRP, and RSRQ
+   *
    * internal method that takes care of generating CQI reports,
    * calculating the RSRP and RSRQ metrics, and generating RSRP+SINR traces
    * 
    * \param sinr 
    */
   void GenerateCqiRsrpRsrq (const SpectrumValue& sinr);
-
-
   /**
    * \brief Layer-1 filtering of RSRP and RSRQ measurements and reporting to
    *        the RRC entity.
@@ -380,82 +411,226 @@ private:
    * periodicity as indicated by the *UeMeasurementsFilterPeriod* attribute.
    */
   void ReportUeMeasurements ();
-
   /**
-   * Switch the UE PHY to the given state.
+   * \brief Set the periodicty for the downlink periodic
+   * wideband and aperiodic subband CQI reporting.
+   *
+   * \param cqiPeriodicity The downlink CQI reporting periodicity in milliseconds
+   */
+  void SetDownlinkCqiPeriodicity (Time cqiPeriodicity);
+  /**
+   * \brief Switch the UE PHY to the given state.
    * \param s the destination state
    */
   void SwitchToState (State s);
+  /**
+   * \brief Set number of Qout evaluation subframes
+   *
+   * The number passed to this method should be multiple
+   * of 10. This number specifies the total number of consecutive
+   * subframes, which corresponds to the Qout evaluation period.
+   *
+   * \param numSubframes the number of subframes
+   */
+  void SetNumQoutEvalSf (uint16_t numSubframes);
+  /**
+   * \brief Set number of Qin evaluation subframes
+   *
+   * The number passed to this method should be multiple
+   * of 10. This number specifies the total number of consecutive
+   * subframes, which corresponds to the Qin evaluation period.
+   *
+   * \param numSubframes the number of subframes
+   */
+  void SetNumQinEvalSf (uint16_t numSubframes);
+  /**
+   * \brief Get number of Qout evaluation subframes
+   *
+   * The number returned by this method specifies the
+   * total number of consecutive subframes, which corresponds
+   * to the Qout evaluation period.
+   *
+   * \return the number of consecutive subframes used for Qout evaluation
+   */
+  uint16_t GetNumQoutEvalSf () const;
+  /**
+   * \brief Get number of Qin evaluation subframes
+   *
+   * The number returned by this method specifies the
+   * total number of consecutive subframes, which corresponds
+   * to the Qin evaluation period.
+   *
+   * \return the number of consecutive subframes used for Qin evaluation
+   */
+  uint16_t GetNumQinEvalSf () const;
 
   // UE CPHY SAP methods
-  /// Reset function
+  /**
+   * \brief Do Reset function
+   */
   void DoReset ();
   /**
-   * Start the cell search function
+   * \brief Start the cell search function
+   *
    * \param dlEarfcn the DL EARFCN
    */
   void DoStartCellSearch (uint32_t dlEarfcn);
   /**
-   * Synchronize with ENB function
+   * \brief Synchronize with ENB function
+   *
    * \param cellId the cell ID
    */
   void DoSynchronizeWithEnb (uint16_t cellId);
   /**
-   * Synchronize with ENB function
+   * \brief Synchronize with ENB function
+   *
    * \param cellId the cell ID
    * \param dlEarfcn the DL EARFCN
    */
   void DoSynchronizeWithEnb (uint16_t cellId, uint32_t dlEarfcn);
   /**
-   * Set DL bandwidth function
+   * \brief Set DL bandwidth function
+   *
    * \param dlBandwidth the DL bandwidth
    */
   void DoSetDlBandwidth (uint8_t dlBandwidth);
   /**
-   * Configure UL uplink function
+   * \brief Configure UL uplink function
+   *
    * \param ulEarfcn UL EARFCN
    * \param ulBandwidth the UL bandwidth
    */
   void DoConfigureUplink (uint32_t ulEarfcn, uint8_t ulBandwidth);
   /**
-   * Configure reference signal power function
-   * \param referenceSignalPower reference signal power
+   * \brief Configure reference signal power function
+   *
+   * \param referenceSignalPower reference signal power in dBm
    */
   void DoConfigureReferenceSignalPower (int8_t referenceSignalPower);
   /**
-   * Set RNTI function
+   * \brief Set RNTI function
+   *
    * \param rnti the RNTI
    */
   void DoSetRnti (uint16_t rnti);
   /**
-   * Set transmission mode function
+   * \brief Set transmission mode function
+   *
    * \param txMode the transmission mode
    */
   void DoSetTransmissionMode (uint8_t txMode);
   /**
-   * Set SRS configuration index function
+   * \brief Set SRS configuration index function
+   *
    * \param srcCi the SRS configuration index
    */
   void DoSetSrsConfigurationIndex (uint16_t srcCi);
   /**
-   * Set PA function
+   * \brief Set PA function
+   *
    * \param pa the PA value
    */
   void DoSetPa (double pa);
+  /**
+   * \brief Reset Phy after radio link failure function
+   *
+   * It resets the physical layer parameters of the
+   * UE after RLF.
+   *
+   */
+  void DoResetPhyAfterRlf ();
+  /**
+   * \brief Reset radio link failure parameters
+   *
+   * Upon receiving N311 in Sync indications from the UE
+   * PHY, the UE RRC instructs the UE PHY to reset the
+   * RLF parameters so, it can start RLF detection again.
+   *
+   */
+  void DoResetRlfParams ();
+
+  /**
+   * \brief Start in Snyc detection function
+   *
+   * When T310 timer is started, it indicates that physical layer
+   * problems are detected at the UE and the recovery process is
+   * started by checking if the radio frames are in-sync for N311
+   * consecutive times.
+   *
+   */
+  void DoStartInSnycDetection ();
+
+  /**
+   * \brief Radio link failure detection function
+   *
+   * Radio link monitoring is started to detect downlink radio link
+   * quality when the UE is both uplink and downlink synchronized
+   * (UE in CONNECTED_NORMALLY state).
+   * Upon detection of radio link failure, RRC connection is released
+   * and the UE starts the cell selection again. The procedure is implemented
+   * as per 3GPP TS 36.213 4.2.1 and TS 36.133 7.6. When the downlink
+   * radio link quality estimated over the last 200 ms period becomes worse than
+   * the threshold Qout, an out-of-sync indication is sent to RRC. When the
+   * downlink radio link quality estimated over the last 100 ms period becomes
+   * better than the threshold Qin, an in-sync indication is sent to RRC.
+   *
+   * \param sinrdB the average SINR value in dB measured across
+   * all resource blocks
+   *
+   */
+  void RlfDetection (double sinrdB);
+  /**
+   * \brief Initialize radio link failure parameters
+   *
+   * Upon receiving the notification about the successful RRC connection
+   * establishment, the UE phy initialize the RLF parameters to be
+   * ready for RLF detection.
+   *
+   */
+  void InitializeRlfParams ();
+  /**
+   * Set IMSI
+   *
+   * \param imsi the IMSI of the UE
+   */
+  void DoSetImsi (uint64_t imsi);
+  /**
+   * \brief Do set RSRP filter coefficient
+   *
+   * \param rsrpFilterCoefficient value. Determines the strength of
+   * smoothing effect induced by layer 3 filtering of RSRP
+   * used for uplink power control in all attached UE.
+   * If equals to 0, no layer 3 filtering is applicable.
+   */
+  void DoSetRsrpFilterCoefficient (uint8_t rsrpFilterCoefficient);
+  /**
+   * \brief Compute average SINR among the RBs
+   *
+   * \param sinr
+   * \return the average SINR value
+   */
+  double ComputeAvgSinr (const SpectrumValue& sinr);
 
   // UE PHY SAP methods 
   virtual void DoSendMacPdu (Ptr<Packet> p);
   /**
-   * Send LTE control message function
+   * \brief Send LTE control message function
+   *
    * \param msg the LTE control message
    */
   virtual void DoSendLteControlMessage (Ptr<LteControlMessage> msg);
   /**
-   * Send RACH preamble function
+   * \brief Send RACH preamble function
+   *
    * \param prachId the RACH preamble ID
    * \param raRnti the rnti
    */
   virtual void DoSendRachPreamble (uint32_t prachId, uint32_t raRnti);
+  /**
+   * \brief Notify PHY about the successful RRC connection
+   * establishment.
+   */
+  virtual void DoNotifyConnectionSuccessful ();
 
   /// A list of sub channels to use in TX.
   std::vector <int> m_subChannelsForTransmission;
@@ -569,7 +744,7 @@ private:
   Ptr<LteHarqPhy> m_harqPhyModule; ///< HARQ phy module
 
   uint32_t m_raPreambleId; ///< RA preamble ID
-  uint32_t m_raRnti; ///< RA rnti
+  uint32_t m_raRnti; ///< RA RNTI
 
   /**
    * The `ReportCurrentCellRsrpSinr` trace source. Trace information regarding
@@ -607,7 +782,33 @@ private:
 
   
   Ptr<SpectrumValue> m_noisePsd; ///< Noise power spectral density for
-                                 ///the configured bandwidth 
+                                 ///the configured bandwidth
+
+  bool m_isConnected; ///< set when UE RRC is in CONNECTED_NORMALLY state
+  /**
+   * The 'Qin' attribute.
+   * corresponds to 2% block error rate of a hypothetical PDCCH transmission
+   * taking into account the PCFICH errors.
+   */
+  double m_qIn;
+
+  /**
+   * The 'Qout' attribute.
+   * corresponds to 2% block error rate of a hypothetical PDCCH transmission
+   * taking into account the PCFICH errors.
+   */
+  double m_qOut;
+
+  uint16_t m_numOfQoutEvalSf; ///< the downlink radio link quality is estimated over this period for detecting out-of-syncs
+  uint16_t m_numOfQinEvalSf; ///< the downlink radio link quality is estimated over this period for detecting in-syncs
+
+  bool m_downlinkInSync; ///< when set, DL SINR evaluation for out-of-sync indications is conducted.
+  uint16_t m_numOfSubframes; ///< count the number of subframes for which the downlink radio link quality is estimated
+  uint16_t m_numOfFrames; ///< count the number of frames for which the downlink radio link quality is estimated
+  double m_sinrDbFrame; ///< the average SINR per radio frame
+  SpectrumValue m_ctrlSinrForRlf; ///< the CTRL SINR used for RLF detection
+  uint64_t m_imsi; ///< the IMSI of the UE
+  bool m_enableRlfDetection; ///< Flag to enable/disable RLF detection
 
 }; // end of `class LteUePhy`
 
