@@ -446,6 +446,11 @@ public:
 private:
 
   // S1 SAP methods
+  /**
+   * Initial context setup request
+   * \param params EpcEnbS1SapUser::InitialContextSetupRequestParameters
+   */
+  void DoInitialContextSetupRequest (EpcEnbS1SapUser::InitialContextSetupRequestParameters params);
   /**
    * Data radio bearer setup request
    * \param params EpcEnbS1SapUser::DataRadioBearerSetupRequestParameters
