@@ -49,17 +49,35 @@
 #include "ns3/config.h"
 #include "ns3/ns2-mobility-helper.h"
 
-namespace ns3 {
+using namespace ns3;
+
+NS_LOG_COMPONENT_DEFINE ("ns2-mobility-helper-test-suite");
 
 // -----------------------------------------------------------------------------
 // Testing
 // -----------------------------------------------------------------------------
-bool operator== (Vector const & a, Vector const & b)
+bool AreVectorsEqual (Vector const & actual, Vector const & limit, double tol)
 {
-  return (a.x == b.x && a.y == b.y && a.z == b.z);
+  if (actual.x > limit.x + tol || actual.x < limit.x - tol)
+    {
+      return false;
+    }
+  if (actual.y > limit.y + tol || actual.y < limit.y - tol)
+    {
+      return false;
+    }
+  if (actual.z > limit.z + tol || actual.z < limit.z - tol)
+    {
+      return false;
+    }
+  return true;
 }
+
 /**
- * Every test case is supposed to:
+ * \ingroup mobility-test
+ * \ingroup tests
+ *
+ * \brief Every test case is supposed to:
  *  1. Generate short mobility trace file
  *  2. Read it back using Ns2MobilityHelper
  *  3. Check initial node positions and speeds.
@@ -76,6 +94,14 @@ public:
     Vector pos;             ///< reference position
     Vector vel;             ///< reference velocity
 
+    /**
+     * Constructor
+     *
+     * \param id reference ID
+     * \param t time
+     * \param p position
+     * \param v velocity
+     */
     ReferencePoint (std::string const & id, Time t, Vector const & p, Vector const & v)
       : node (id),
         time (t),
@@ -93,6 +119,7 @@ public:
    * Create new test case. To make it useful SetTrace () and AddReferencePoint () must be called
    *
    * \param name        Short description
+   * \param timeLimit   Test time limit
    * \param nodes       Number of nodes used in the test trace, 1 by default
    */
   Ns2MobilityHelperTest (std::string const & name, Time timeLimit, uint32_t nodes = 1)
@@ -106,7 +133,7 @@ public:
   virtual ~Ns2MobilityHelperTest ()
   {
   }
-  /// Set NS-2 trace to read as single large string (don't forget to add \n and quote ")
+  /// Set NS-2 trace to read as single large string (don't forget to add \\n and quote \"'s)
   void SetTrace (std::string const & trace)
   {
     m_trace = trace;
@@ -171,8 +198,9 @@ private:
         Ptr<MobilityModel> mob = node->GetObject<MobilityModel> ();
         NS_TEST_ASSERT_MSG_NE_RETURNS_BOOL (mob, 0, "Can't find mobility for node " << rp.node);
 
-        NS_TEST_EXPECT_MSG_EQ (rp.pos, mob->GetPosition (), "Initial position mismatch for node " << rp.node);
-        NS_TEST_EXPECT_MSG_EQ (rp.vel, mob->GetVelocity (), "Initial velocity mismatch for node " << rp.node);
+        double tol = 0.001;
+        NS_TEST_EXPECT_MSG_EQ (AreVectorsEqual (mob->GetPosition (), rp.pos, tol), true, "Initial position mismatch for node " << rp.node);
+        NS_TEST_EXPECT_MSG_EQ (AreVectorsEqual (mob->GetVelocity (), rp.vel, tol), true, "Initial velocity mismatch for node " << rp.node);
 
         m_nextRefPoint++;
       }
@@ -198,8 +226,10 @@ private:
     ReferencePoint const & ref = m_reference [m_nextRefPoint++];
     NS_TEST_EXPECT_MSG_EQ (time, ref.time, "Time mismatch");
     NS_TEST_EXPECT_MSG_EQ (id, ref.node, "Node ID mismatch at time " << time.GetSeconds () << " s");
-    NS_TEST_EXPECT_MSG_EQ (pos, ref.pos, "Position mismatch at time " << time.GetSeconds () << " s for node " << id);
-    NS_TEST_EXPECT_MSG_EQ (vel, ref.vel, "Velocity mismatch at time " << time.GetSeconds () << " s for node " << id);
+
+    double tol = 0.001;
+    NS_TEST_EXPECT_MSG_EQ (AreVectorsEqual (pos, ref.pos, tol), true, "Position mismatch at time " << time.GetSeconds () << " s for node " << id);
+    NS_TEST_EXPECT_MSG_EQ (AreVectorsEqual (vel, ref.vel, tol), true, "Velocity mismatch at time " << time.GetSeconds () << " s for node " << id);
   }
 
   void DoSetup ()
@@ -210,7 +240,6 @@ private:
   void DoTeardown ()
   {
     Names::Clear ();
-    std::remove (m_traceFile.c_str ());
     Simulator::Destroy ();
   }
 
@@ -237,7 +266,12 @@ private:
   }
 };
 
-/// The test suite
+/**
+ * \ingroup mobility-test
+ * \ingroup tests
+ *
+ * \brief The test suite
+ */
 class Ns2MobilityHelperTestSuite : public TestSuite
 {
 public:
@@ -256,7 +290,7 @@ public:
                  "$node_(0) set Z_ 3.0\n"
                  );
     t->AddReferencePoint ("0", 0, Vector (1, 2, 3), Vector (0, 0, 0));
-    AddTestCase (t);
+    AddTestCase (t, TestCase::QUICK);
 
     // Check parsing comments, empty lines and no EOF at the end of file
     t = new Ns2MobilityHelperTest ("comments", Seconds (1));
@@ -268,7 +302,7 @@ public:
                  "#$node_(0) set Z_ 100 #"
                  );
     t->AddReferencePoint ("0", 0, Vector (1, 2, 3), Vector (0, 0, 0));
-    AddTestCase (t);
+    AddTestCase (t, TestCase::QUICK);
 
     // Simple setdest. Arguments are interpreted as x, y, speed by default
     t = new Ns2MobilityHelperTest ("simple setdest", Seconds (10));
@@ -277,7 +311,7 @@ public:
     t->AddReferencePoint ("0", 0, Vector (0, 0, 0), Vector (0, 0, 0));
     t->AddReferencePoint ("0", 1, Vector (0, 0, 0), Vector (5, 0, 0));
     t->AddReferencePoint ("0", 6, Vector (25, 0, 0), Vector (0, 0, 0));
-    AddTestCase (t);
+    AddTestCase (t, TestCase::QUICK);
 
     // Several set and setdest. Arguments are interpreted as x, y, speed by default
     t = new Ns2MobilityHelperTest ("square setdest", Seconds (6));
@@ -298,7 +332,31 @@ public:
     t->AddReferencePoint ("0", 4, Vector (0, 5, 0), Vector (0, 0, 0));
     t->AddReferencePoint ("0", 4, Vector (0, 5, 0), Vector (0, -5, 0));
     t->AddReferencePoint ("0", 5, Vector (0, 0, 0), Vector (0,  0, 0));
-    AddTestCase (t);
+    AddTestCase (t, TestCase::QUICK);
+
+    // Copy of previous test case but with the initial positions at
+    // the end of the trace rather than at the beginning.
+    //
+    // Several set and setdest. Arguments are interpreted as x, y, speed by default
+    t = new Ns2MobilityHelperTest ("square setdest (initial positions at end)", Seconds (6));
+    t->SetTrace ("$ns_ at 1.0 \"$node_(0) setdest 15  10  5\"\n"
+                 "$ns_ at 2.0 \"$node_(0) setdest 15  15  5\"\n"
+                 "$ns_ at 3.0 \"$node_(0) setdest 10  15  5\"\n"
+                 "$ns_ at 4.0 \"$node_(0) setdest 10  10  5\"\n"
+                 "$node_(0) set X_ 10.0\n"
+                 "$node_(0) set Y_ 10.0\n"
+                 );
+    //                     id  t  position         velocity
+    t->AddReferencePoint ("0", 0, Vector (10, 10, 0), Vector (0,  0, 0));
+    t->AddReferencePoint ("0", 1, Vector (10, 10, 0), Vector (5,  0, 0));
+    t->AddReferencePoint ("0", 2, Vector (15, 10, 0), Vector (0,  0, 0));
+    t->AddReferencePoint ("0", 2, Vector (15, 10, 0), Vector (0,  5, 0));
+    t->AddReferencePoint ("0", 3, Vector (15, 15, 0), Vector (0,  0, 0));
+    t->AddReferencePoint ("0", 3, Vector (15, 15, 0), Vector (-5, 0, 0));
+    t->AddReferencePoint ("0", 4, Vector (10, 15, 0), Vector (0, 0, 0));
+    t->AddReferencePoint ("0", 4, Vector (10, 15, 0), Vector (0, -5, 0));
+    t->AddReferencePoint ("0", 5, Vector (10, 10, 0), Vector (0,  0, 0));
+    AddTestCase (t, TestCase::QUICK);
 
     // Scheduled set position
     t = new Ns2MobilityHelperTest ("scheduled set position", Seconds (2));
@@ -309,7 +367,7 @@ public:
     t->AddReferencePoint ("0", 1, Vector (10, 0, 0), Vector (0, 0, 0));
     t->AddReferencePoint ("0", 1, Vector (10, 0, 10), Vector (0, 0, 0));
     t->AddReferencePoint ("0", 1, Vector (10, 10, 10), Vector (0, 0, 0));
-    AddTestCase (t);
+    AddTestCase (t, TestCase::QUICK);
 
     // Malformed lines
     t = new Ns2MobilityHelperTest ("malformed lines", Seconds (2));
@@ -325,7 +383,7 @@ public:
     t->AddReferencePoint ("0", 0, Vector (1, 2, 3), Vector (0, 0, 0));
     t->AddReferencePoint ("0", 1, Vector (1, 2, 3), Vector (1, 0, 0));
     t->AddReferencePoint ("0", 2, Vector (2, 2, 3), Vector (0, 0, 0));
-    AddTestCase (t);
+    AddTestCase (t, TestCase::QUICK);
 
     // Non possible values
     t = new Ns2MobilityHelperTest ("non possible values", Seconds (2));
@@ -345,7 +403,7 @@ public:
     t->AddReferencePoint ("0", 0, Vector (1, 2, 3), Vector (0, 0, 0));
     t->AddReferencePoint ("0", 1, Vector (1, 2, 3), Vector (1, 0, 0));
     t->AddReferencePoint ("0", 2, Vector (2, 2, 3), Vector (0, 0, 0));
-    AddTestCase (t);
+    AddTestCase (t, TestCase::QUICK);
 
     // More than one node
     t = new Ns2MobilityHelperTest ("few nodes, combinations of set and setdest", Seconds (10), 3);
@@ -373,7 +431,7 @@ public:
     t->AddReferencePoint ("2", 4, Vector (0, 5, 0), Vector (0, 0, 0));
     t->AddReferencePoint ("2", 4, Vector (0, 5, 0), Vector (0, -5, 0));
     t->AddReferencePoint ("2", 5, Vector (0, 0, 0), Vector (0,  0, 0));
-    AddTestCase (t);
+    AddTestCase (t, TestCase::QUICK);
 
     // Test for Speed == 0, that acts as stop the node.
     t = new Ns2MobilityHelperTest ("setdest with speed cero", Seconds (10));
@@ -384,7 +442,7 @@ public:
     t->AddReferencePoint ("0", 1, Vector (0, 0, 0), Vector (5, 0, 0));
     t->AddReferencePoint ("0", 6, Vector (25, 0, 0), Vector (0, 0, 0));
     t->AddReferencePoint ("0", 7, Vector (25, 0, 0), Vector (0, 0, 0));
-    AddTestCase (t);
+    AddTestCase (t, TestCase::QUICK);
 
 
     // Test negative positions
@@ -399,7 +457,7 @@ public:
     t->AddReferencePoint ("0", 2, Vector (0, 0, 0), Vector (0, 0, 0));
     t->AddReferencePoint ("0", 2, Vector (0, 0, 0), Vector (0, -1, 0));
     t->AddReferencePoint ("0", 3, Vector (0, -1, 0), Vector (0, 0, 0));
-    AddTestCase (t);
+    AddTestCase (t, TestCase::QUICK);
 
     // Sqare setdest with values in the form 1.0e+2
     t = new Ns2MobilityHelperTest ("Foalt numbers in 1.0e+2 format", Seconds (6));
@@ -419,7 +477,7 @@ public:
     t->AddReferencePoint ("0", 4, Vector (0, 100, 0), Vector (0, 0, 0));
     t->AddReferencePoint ("0", 4, Vector (0, 100, 0), Vector (0, -100, 0));
     t->AddReferencePoint ("0", 5, Vector (0, 0, 0), Vector (0,  0, 0));
-    AddTestCase (t);
+    AddTestCase (t, TestCase::QUICK);
     t = new Ns2MobilityHelperTest ("Bug 1219 testcase", Seconds (16));
     t->SetTrace ("$node_(0) set X_ 0.0\n"
                  "$node_(0) set Y_ 0.0\n"
@@ -431,14 +489,14 @@ public:
     t->AddReferencePoint ("0", 1, Vector (0, 0, 0), Vector (0,  1, 0));
     t->AddReferencePoint ("0", 6, Vector (0, 5, 0), Vector (0,  -1, 0));
     t->AddReferencePoint ("0", 16, Vector (0, -10, 0), Vector (0, 0, 0));
-    AddTestCase (t);
+    AddTestCase (t, TestCase::QUICK);
     t = new Ns2MobilityHelperTest ("Bug 1059 testcase", Seconds (16));
     t->SetTrace ("$node_(0) set X_ 10.0\r\n"
                  "$node_(0) set Y_ 0.0\r\n"
                  );
     //                     id  t  position         velocity
     t->AddReferencePoint ("0", 0, Vector (10, 0, 0), Vector (0,  0, 0));
-    AddTestCase (t);
+    AddTestCase (t, TestCase::QUICK);
     t = new Ns2MobilityHelperTest ("Bug 1301 testcase", Seconds (16));
     t->SetTrace ("$node_(0) set X_ 10.0\n"
                  "$node_(0) set Y_ 0.0\n"
@@ -448,11 +506,31 @@ public:
     // Moving to the current position must change nothing. No NaN
     // speed must be.
     t->AddReferencePoint ("0", 0, Vector (10, 0, 0), Vector (0,  0, 0));
-    AddTestCase (t);
+    AddTestCase (t, TestCase::QUICK);
 
+    t = new Ns2MobilityHelperTest ("Bug 1316 testcase", Seconds (1000));
+    t->SetTrace ("$node_(0) set X_ 350.00000000000000\n"
+                 "$node_(0) set Y_ 50.00000000000000\n"
+                 "$ns_ at 50.00000000000000  \"$node_(0) setdest 400.00000000000000 50.00000000000000 1.00000000000000\"\n"
+                 "$ns_ at 150.00000000000000 \"$node_(0) setdest 400.00000000000000 150.00000000000000 4.00000000000000\"\n"
+                 "$ns_ at 300.00000000000000 \"$node_(0) setdest 250.00000000000000 150.00000000000000 3.00000000000000\"\n"
+                 "$ns_ at 350.00000000000000 \"$node_(0) setdest 250.00000000000000 50.00000000000000 1.00000000000000\"\n"
+                 "$ns_ at 600.00000000000000 \"$node_(0) setdest 250.00000000000000 1050.00000000000000 2.00000000000000\"\n"
+                 "$ns_ at 900.00000000000000 \"$node_(0) setdest 300.00000000000000 650.00000000000000 2.50000000000000\"\n"
+                 );
+    t->AddReferencePoint ("0", 0.000, Vector (350.000, 50.000, 0.000), Vector (0.000, 0.000, 0.000));
+    t->AddReferencePoint ("0", 50.000, Vector (350.000, 50.000, 0.000), Vector (1.000, 0.000, 0.000));
+    t->AddReferencePoint ("0", 100.000, Vector (400.000, 50.000, 0.000), Vector (0.000, 0.000, 0.000));
+    t->AddReferencePoint ("0", 150.000, Vector (400.000, 50.000, 0.000), Vector (0.000, 4.000, 0.000));
+    t->AddReferencePoint ("0", 175.000, Vector (400.000, 150.000, 0.000), Vector (0.000, 0.000, 0.000));
+    t->AddReferencePoint ("0", 300.000, Vector (400.000, 150.000, 0.000), Vector (-3.000, 0.000, 0.000));
+    t->AddReferencePoint ("0", 350.000, Vector (250.000, 150.000, 0.000), Vector (0.000, 0.000, 0.000));
+    t->AddReferencePoint ("0", 350.000, Vector (250.000, 150.000, 0.000), Vector (0.000, -1.000, 0.000));
+    t->AddReferencePoint ("0", 450.000, Vector (250.000,  50.000, 0.000), Vector (0.000, 0.000, 0.000));
+    t->AddReferencePoint ("0", 600.000, Vector (250.000,  50.000, 0.000), Vector (0.000, 2.000, 0.000));
+    t->AddReferencePoint ("0", 900.000, Vector (250.000,  650.000, 0.000), Vector (2.500, 0.000, 0.000));
+    t->AddReferencePoint ("0", 920.000, Vector (300.000,  650.000, 0.000), Vector (0.000, 0.000, 0.000));
+    AddTestCase (t, TestCase::QUICK);
 
   }
-} g_ns2TransmobilityHelperTestSuite;
-
-
-} // namespace ns3
+} g_ns2TransmobilityHelperTestSuite; ///< the test suite
