@@ -84,6 +84,7 @@ NullMessageSimulatorImpl::NullMessageSimulatorImpl ()
   m_currentTs = 0;
   m_currentContext = Simulator::NO_CONTEXT;
   m_unscheduledEvents = 0;
+  m_eventCount = 0;
   m_events = 0;
 
   m_safeTime = Seconds (0);
@@ -235,6 +236,7 @@ NullMessageSimulatorImpl::ProcessOneEvent (void)
 
   NS_ASSERT (next.key.m_ts >= m_currentTs);
   m_unscheduledEvents--;
+  m_eventCount++;
 
   NS_LOG_LOGIC ("handle " << next.key.m_ts);
   m_currentTs = next.key.m_ts;
@@ -575,6 +577,12 @@ NullMessageSimulatorImpl::GetContext (void) const
   return m_currentContext;
 }
 
+uint64_t
+NullMessageSimulatorImpl::GetEventCount (void) const
+{
+  return m_eventCount;
+}
+
 Time NullMessageSimulatorImpl::CalculateGuaranteeTime (uint32_t nodeSysId)
 {
   Ptr<RemoteChannelBundle> bundle = RemoteChannelBundleManager::Find (nodeSysId);
