@@ -40,6 +40,7 @@
 #include "ns3/lte-ue-net-device.h"
 #include "ns3/lte-enb-net-device.h"
 #include "ns3/uan-phy-gen.h"
+#include "ns3/wifi-phy.h"
 #include "ns3/rectangle.h"
 #include "ns3/ipv4.h"
 #include "ns3/ipv4-l3-protocol.h"
@@ -998,8 +999,9 @@ private:
    * wifi Phy receive drop trace function
    * \param context the context
    * \param p the packet
+   * \param reason the reason
    */
-  void WifiPhyRxDropTrace (std::string context, Ptr<const Packet> p);
+  void WifiPhyRxDropTrace (std::string context, Ptr<const Packet> p, WifiPhyRxfailureReason reason);
   /**
    * LR-WPAN MAC transmit trace function
    * \param context the context
@@ -1047,8 +1049,9 @@ private:
    * wifi Phy transmit begin trace function
    * \param context the context
    * \param p the packet
+   * \param txPowerW the tx power
    */
-  void WifiPhyTxBeginTrace (std::string context, Ptr<const Packet> p);
+  void WifiPhyTxBeginTrace (std::string context, Ptr<const Packet> p, double txPowerW);
   /**
    * wifi Phy receive begin trace function
    *
