@@ -571,6 +571,27 @@ public:
    * packet).
    */
   void AddByteTag (const Tag &tag) const;
+
+  /**
+   * \brief Tag the indicated byte range of this packet with a new byte tag.
+   *
+   * As parameters for this method, we do not use indexes, but byte position.
+   * Moreover, as there is no 0-th position, the first position is 1.
+   *
+   * As example, if you want to tag the first 10 bytes, you have to call
+   * the method in this way:
+   *
+   * \code{.cpp}
+       Ptr<Packet> p = ... ;
+       SomeTag tag;
+       p->AddByteTag (tag, 1, 10);
+     \endcode
+   *
+   * \param tag the new tag to add to this packet
+   * \param start the position of the first byte tagged by this tag
+   * \param end the position of the last byte tagged by this tag
+   */
+  void AddByteTag (const Tag &tag, uint32_t start, uint32_t end) const;
   /**
    * \brief Returns an iterator over the set of byte tags included in this packet
    *
