@@ -52,8 +52,8 @@ public:
   virtual Ptr<const Item> Peek (void) const;
 
 private:
-  using Queue<Item>::Head;
-  using Queue<Item>::Tail;
+  using Queue<Item>::begin;
+  using Queue<Item>::end;
   using Queue<Item>::DoEnqueue;
   using Queue<Item>::DoDequeue;
   using Queue<Item>::DoRemove;
@@ -99,7 +99,7 @@ DropTailQueue<Item>::Enqueue (Ptr<Item> item)
 {
   NS_LOG_FUNCTION (this << item);
 
-  return DoEnqueue (Tail (), item);
+  return DoEnqueue (end (), item);
 }
 
 template <typename Item>
@@ -108,7 +108,7 @@ DropTailQueue<Item>::Dequeue (void)
 {
   NS_LOG_FUNCTION (this);
 
-  Ptr<Item> item = DoDequeue (Head ());
+  Ptr<Item> item = DoDequeue (begin ());
 
   NS_LOG_LOGIC ("Popped " << item);
 
@@ -121,7 +121,7 @@ DropTailQueue<Item>::Remove (void)
 {
   NS_LOG_FUNCTION (this);
 
-  Ptr<Item> item = DoRemove (Head ());
+  Ptr<Item> item = DoRemove (begin ());
 
   NS_LOG_LOGIC ("Removed " << item);
 
@@ -134,9 +134,19 @@ DropTailQueue<Item>::Peek (void) const
 {
   NS_LOG_FUNCTION (this);
 
-  return DoPeek (Head ());
+  return DoPeek (begin ());
 }
 
+// The following explicit template instantiation declarations prevent all the
+// translation units including this header file to implicitly instantiate the
+// DropTailQueue<Packet> class and the DropTailQueue<QueueDiscItem> class. The
+// unique instances of these classes are explicitly created through the macros
+// NS_OBJECT_TEMPLATE_CLASS_DEFINE (DropTailQueue,Packet) and
+// NS_OBJECT_TEMPLATE_CLASS_DEFINE (DropTailQueue,QueueDiscItem), which are included
+// in drop-tail-queue.cc
+extern template class DropTailQueue<Packet>;
+extern template class DropTailQueue<QueueDiscItem>;
+
 } // namespace ns3
 
 #endif /* DROPTAIL_H */
