@@ -22,7 +22,7 @@
 #include "ns3/assert.h"
 #include "ns3/log.h"
 #include "ns3/abort.h"
-#include "ns3/address-utils.h"
+#include "ns3/ipv6-header.h"
 #include "sixlowpan-header.h"
 
 
