@@ -24,8 +24,6 @@
 
 #include "ns3/header.h"
 #include "ns3/ipv6-address.h"
-#include "ns3/packet.h"
-#include "ns3/ipv6-header.h"
 
 namespace ns3 {
 
