@@ -31,6 +31,7 @@
 #include "ns3/inet-socket-address.h"
 #include "ns3/point-to-point-helper.h"
 #include "ns3/internet-stack-helper.h"
+#include "ns3/traffic-control-helper.h"
 #include "ns3/ipv4-global-routing-helper.h"
 #include "ns3/ipv4-address-helper.h"
 #include "ns3/packet-sink-helper.h"
@@ -342,6 +343,12 @@ Ns3TcpStateTestCase::DoRun (void)
   NetDeviceContainer dev0 = p2p.Install (n0n1);
   NetDeviceContainer dev1 = p2p.Install (n1n2);
 
+  // Use PfifoFast queue disc
+  TrafficControlHelper tch;
+  tch.SetRootQueueDisc ("ns3::PfifoFastQueueDisc");
+  tch.Install (dev0);
+  tch.Install (dev1);
+
   // Add IP addresses to each network interfaces
   Ipv4AddressHelper ipv4;
   ipv4.SetBase ("10.1.3.0", "255.255.255.0");
