@@ -75,101 +75,25 @@ TrafficControlLayer::DoDispose (void)
   Object::DoDispose ();
 }
 
-TrafficControlLayer::NetDeviceInfo::NetDeviceInfo (Ptr<QueueDisc> rootQueueDisc,
-                                                   Ptr<NetDeviceQueueInterface> ndqi,
-                                                   QueueDiscVector queueDiscsToWake,
-                                                   SelectQueueCallback selectQueueCallback)
-  : m_rootQueueDisc (rootQueueDisc),
-    m_ndqi (ndqi),
-    m_queueDiscsToWake (queueDiscsToWake),
-    m_selectQueueCallback (selectQueueCallback)
-{
-}
-
-TrafficControlLayer::NetDeviceInfo::~NetDeviceInfo ()
-{
-  NS_LOG_FUNCTION (this);
-}
-
 void
 TrafficControlLayer::DoInitialize (void)
 {
   NS_LOG_FUNCTION (this);
-  std::map<Ptr<NetDevice>, NetDeviceInfo>::iterator ndi;
-  for (ndi = m_netDevices.begin (); ndi != m_netDevices.end (); ndi++)
+
+  ScanDevices ();
+
+  // initialize the root queue discs
+  for (auto& ndi : m_netDevices)
     {
-      Ptr<NetDeviceQueueInterface> devQueueIface = ndi->second.m_ndqi;
-      NS_ASSERT (devQueueIface);
-
-      if (ndi->second.m_rootQueueDisc)
+      if (ndi.second.m_rootQueueDisc)
         {
-          // set the wake callbacks on netdevice queues
-           if (ndi->second.m_rootQueueDisc->GetWakeMode () == QueueDisc::WAKE_ROOT)
-            {
-              for (uint8_t i = 0; i < devQueueIface->GetNTxQueues (); i++)
-                {
-                  devQueueIface->GetTxQueue (i)->SetWakeCallback (MakeCallback (&QueueDisc::Run, ndi->second.m_rootQueueDisc));
-                  ndi->second.m_queueDiscsToWake.push_back (ndi->second.m_rootQueueDisc);
-                }
-            }
-          else if (ndi->second.m_rootQueueDisc->GetWakeMode () == QueueDisc::WAKE_CHILD)
-            {
-              NS_ASSERT_MSG (ndi->second.m_rootQueueDisc->GetNQueueDiscClasses () == devQueueIface->GetNTxQueues (),
-                             "The number of child queue discs does not match the number of netdevice queues");
-              for (uint8_t i = 0; i < devQueueIface->GetNTxQueues (); i++)
-                {
-                  devQueueIface->GetTxQueue (i)->SetWakeCallback (MakeCallback (&QueueDisc::Run,
-                                                                  ndi->second.m_rootQueueDisc->GetQueueDiscClass (i)->GetQueueDisc ()));
-                  ndi->second.m_queueDiscsToWake.push_back (ndi->second.m_rootQueueDisc->GetQueueDiscClass (i)->GetQueueDisc ());
-                }
-            }
-
-          // initialize the queue disc
-          ndi->second.m_rootQueueDisc->Initialize ();
+          ndi.second.m_rootQueueDisc->Initialize ();
         }
     }
+
   Object::DoInitialize ();
 }
 
-void
-TrafficControlLayer::SetupDevice (Ptr<NetDevice> device)
-{
-  NS_LOG_FUNCTION (this << device);
-
-  // ensure this setup is done just once. SetupDevice is called by Ipv4L3Protocol
-  // and Ipv6L3Protocol when they add an interface, thus it might be called twice
-  // in case of dual stack nodes. Also, SetupDevice might be called twice if the
-  // tc helper is invoked (to install a queue disc) before the creation of the
-  // Ipv{4,6}Interface, since SetRootQueueDiscOnDevice calls SetupDevice
-  if (device->GetObject<NetDeviceQueueInterface> ())
-    {
-      NS_LOG_DEBUG ("The setup for this device has been already done.");
-      return;
-    }
-
-  // create a NetDeviceQueueInterface object and aggregate it to the device
-  Ptr<NetDeviceQueueInterface> devQueueIface = CreateObject<NetDeviceQueueInterface> ();
-  device->AggregateObject (devQueueIface);
-
-  // Create the TX queues if the device has not done so and has not set the
-  // late TX queues creation flag in the NotifyNewAggregate method
-  if (devQueueIface->GetNTxQueues () == 0 && !devQueueIface->GetLateTxQueuesCreation ())
-    {
-      devQueueIface->CreateTxQueues ();
-    }
-
-  // devices can set a select queue callback in their NotifyNewAggregate method
-  SelectQueueCallback cb = devQueueIface->GetSelectQueueCallback ();
-
-  // create an entry in the m_netDevices map for this device
-  NS_ASSERT_MSG (m_netDevices.find (device) == m_netDevices.end (), "This is a bug,"
-                 << "  SetupDevice only can insert an entry in the m_netDevices map");
-
-  m_netDevices.emplace (std::piecewise_construct,
-                        std::forward_as_tuple (device),
-                        std::forward_as_tuple ((Ptr<QueueDisc>) 0, devQueueIface, QueueDiscVector (), cb));
-}
-
 void
 TrafficControlLayer::RegisterProtocolHandler (Node::ProtocolHandler handler,
                                               uint16_t protocolType, Ptr<NetDevice> device)
@@ -188,6 +112,85 @@ TrafficControlLayer::RegisterProtocolHandler (Node::ProtocolHandler handler,
                 protocolType << ".");
 }
 
+void
+TrafficControlLayer::ScanDevices (void)
+{
+  NS_LOG_FUNCTION (this);
+
+  NS_ASSERT_MSG (m_node, "Cannot run ScanDevices without an aggregated node");
+
+  for (uint32_t i = 0; i < m_node->GetNDevices (); i++)
+    {
+      Ptr<NetDevice> dev = m_node->GetDevice (i);
+
+      // note: there may be no NetDeviceQueueInterface aggregated to the device
+      Ptr<NetDeviceQueueInterface> ndqi = dev->GetObject<NetDeviceQueueInterface> ();
+
+      std::map<Ptr<NetDevice>, NetDeviceInfo>::iterator ndi = m_netDevices.find (dev);
+
+      if (ndi != m_netDevices.end ())
+        {
+          ndi->second.m_ndqi = ndqi;
+        }
+      else if (ndqi)
+      // if no entry for the device is found, it means that no queue disc has been
+      // installed. Nonetheless, create an entry for the device and store a pointer
+      // to the NetDeviceQueueInterface object if the latter is not null, because
+      // the Traffic Control layer checks whether the device queue is stopped even
+      // when there is no queue disc.
+        {
+          m_netDevices[dev] = {nullptr, ndqi, QueueDiscVector ()};
+          ndi = m_netDevices.find (dev);
+        }
+
+      // if a queue disc is installed, set the wake callbacks on netdevice queues
+      if (ndi != m_netDevices.end () && ndi->second.m_rootQueueDisc)
+        {
+          ndi->second.m_queueDiscsToWake.clear ();
+
+          if (ndqi)
+            {
+              for (uint16_t i = 0; i < ndqi->GetNTxQueues (); i++)
+                {
+                  Ptr<QueueDisc> qd;
+
+                  if (ndi->second.m_rootQueueDisc->GetWakeMode () == QueueDisc::WAKE_ROOT)
+                    {
+                      qd = ndi->second.m_rootQueueDisc;
+                    }
+                  else if (ndi->second.m_rootQueueDisc->GetWakeMode () == QueueDisc::WAKE_CHILD)
+                    {
+                      NS_ABORT_MSG_IF (ndi->second.m_rootQueueDisc->GetNQueueDiscClasses () != ndqi->GetNTxQueues (),
+                                      "The number of child queue discs does not match the number of netdevice queues");
+
+                      qd = ndi->second.m_rootQueueDisc->GetQueueDiscClass (i)->GetQueueDisc ();
+                    }
+                  else
+                    {
+                      NS_ABORT_MSG ("Invalid wake mode");
+                    }
+
+                  ndqi->GetTxQueue (i)->SetWakeCallback (MakeCallback (&QueueDisc::Run, qd));
+                  ndi->second.m_queueDiscsToWake.push_back (qd);
+                }
+            }
+          else
+            {
+              ndi->second.m_queueDiscsToWake.push_back (ndi->second.m_rootQueueDisc);
+            }
+
+          // set the NetDeviceQueueInterface object and the SendCallback on the queue discs
+          // into which packets are enqueued and dequeued by calling Run
+          for (auto& q : ndi->second.m_queueDiscsToWake)
+            {
+              q->SetNetDeviceQueueInterface (ndqi);
+              q->SetSendCallback ([dev] (Ptr<QueueDiscItem> item)
+                                  { dev->Send (item->GetPacket (), item->GetAddress (), item->GetProtocol ()); });
+            }
+        }
+    }
+}
+
 void
 TrafficControlLayer::SetRootQueueDiscOnDevice (Ptr<NetDevice> device, Ptr<QueueDisc> qDisc)
 {
@@ -197,18 +200,17 @@ TrafficControlLayer::SetRootQueueDiscOnDevice (Ptr<NetDevice> device, Ptr<QueueD
 
   if (ndi == m_netDevices.end ())
     {
-      // SetupDevice has not been called yet. This may happen when the tc helper is
-      // invoked (to install a queue disc) before the creation of the Ipv{4,6}Interface.
-      // Since queue discs require that a netdevice queue interface is aggregated
-      // to the device, call SetupDevice
-      SetupDevice (device);
-      ndi = m_netDevices.find (device);
-      NS_ASSERT (ndi != m_netDevices.end ());
+      // No entry found for this device. Create one.
+      m_netDevices[device] = {qDisc, nullptr, QueueDiscVector ()};
     }
+  else
+    {
+      NS_ABORT_MSG_IF (ndi->second.m_rootQueueDisc,
+                       "Cannot install a root queue disc on a device already having one. "
+                       "Delete the existing queue disc first.");
 
-  NS_ASSERT_MSG (ndi->second.m_rootQueueDisc == 0, "Cannot install a root queue disc on a "
-                  << "device already having one. Delete the existing queue disc first.");
-  ndi->second.m_rootQueueDisc = qDisc;
+      ndi->second.m_rootQueueDisc = qDisc;
+    }
 }
 
 Ptr<QueueDisc>
@@ -239,12 +241,32 @@ TrafficControlLayer::DeleteRootQueueDiscOnDevice (Ptr<NetDevice> device)
 
   std::map<Ptr<NetDevice>, NetDeviceInfo>::iterator ndi = m_netDevices.find (device);
 
-  NS_ASSERT_MSG (ndi != m_netDevices.end () && ndi->second.m_rootQueueDisc != 0, "No root queue disc"
-                 << " installed on device " << device);
+  NS_ASSERT_MSG (ndi != m_netDevices.end () && ndi->second.m_rootQueueDisc != 0,
+                 "No root queue disc installed on device " << device);
 
   // remove the root queue disc
   ndi->second.m_rootQueueDisc = 0;
+  for (auto& q : ndi->second.m_queueDiscsToWake)
+    {
+      q->SetNetDeviceQueueInterface (nullptr);
+      q->SetSendCallback (nullptr);
+    }
   ndi->second.m_queueDiscsToWake.clear ();
+
+  Ptr<NetDeviceQueueInterface> ndqi = ndi->second.m_ndqi;
+  if (ndqi)
+    {
+      // remove configured callbacks, if any
+      for (uint16_t i = 0; i < ndqi->GetNTxQueues (); i++)
+        {
+          ndqi->GetTxQueue (i)->SetWakeCallback (MakeNullCallback <void> ());
+        }
+    }
+  else
+    {
+      // remove the empty entry
+      m_netDevices.erase (ndi);
+    }
 }
 
 void
@@ -305,11 +327,8 @@ TrafficControlLayer::Receive (Ptr<NetDevice> device, Ptr<const Packet> p,
         }
     }
 
-  if (! found)
-    {
-      NS_FATAL_ERROR ("Handler for protocol " << p << " and device " << device <<
-                      " not found. It isn't forwarded up; it dies here.");
-    }
+  NS_ABORT_MSG_IF (!found, "Handler for protocol " << p << " and device " << device <<
+                           " not found. It isn't forwarded up; it dies here.");
 }
 
 void
@@ -320,19 +339,19 @@ TrafficControlLayer::Send (Ptr<NetDevice> device, Ptr<QueueDiscItem> item)
   NS_LOG_DEBUG ("Send packet to device " << device << " protocol number " <<
                 item->GetProtocol ());
 
+  Ptr<NetDeviceQueueInterface> devQueueIface;
   std::map<Ptr<NetDevice>, NetDeviceInfo>::iterator ndi = m_netDevices.find (device);
-  NS_ASSERT (ndi != m_netDevices.end ());
-  Ptr<NetDeviceQueueInterface> devQueueIface = ndi->second.m_ndqi;
-  NS_ASSERT (devQueueIface);
+
+  if (ndi != m_netDevices.end ())
+    {
+      devQueueIface = ndi->second.m_ndqi;
+    }
 
   // determine the transmission queue of the device where the packet will be enqueued
-  uint8_t txq = 0;
-  if (devQueueIface->GetNTxQueues () > 1)
+  std::size_t txq = 0;
+  if (devQueueIface && devQueueIface->GetNTxQueues () > 1)
     {
-      if (!ndi->second.m_selectQueueCallback.IsNull ())
-        {
-          txq = ndi->second.m_selectQueueCallback (item);
-        }
+      txq = devQueueIface->GetSelectQueueCallback () (item);
       // otherwise, Linux determines the queue index by using a hash function
       // and associates such index to the socket which the packet belongs to,
       // so that subsequent packets of the same socket will be mapped to the
@@ -341,17 +360,17 @@ TrafficControlLayer::Send (Ptr<NetDevice> device, Ptr<QueueDiscItem> item)
       // devices provide a select queue callback
     }
 
-  NS_ASSERT (txq < devQueueIface->GetNTxQueues ());
+  NS_ASSERT (!devQueueIface || txq < devQueueIface->GetNTxQueues ());
 
-  if (ndi->second.m_rootQueueDisc == 0)
+  if (ndi == m_netDevices.end () || ndi->second.m_rootQueueDisc == 0)
     {
       // The device has no attached queue disc, thus add the header to the packet and
       // send it directly to the device if the selected queue is not stopped
-      if (!devQueueIface->GetTxQueue (txq)->IsStopped ())
+      if (!devQueueIface || !devQueueIface->GetTxQueue (txq)->IsStopped ())
         {
           item->AddHeader ();
           // a single queue device makes no use of the priority tag
-          if (devQueueIface->GetNTxQueues () == 1)
+          if (!devQueueIface || devQueueIface->GetNTxQueues () == 1)
             {
               SocketPriorityTag priorityTag;
               item->GetPacket ()->RemovePacketTag (priorityTag);
