@@ -45,7 +45,7 @@ static uint16_t _codel_Newton_step (uint32_t count, uint16_t rec_inv_sqrt)
 
   val >>= 2; /* avoid overflow in following multiply */
   val = (val * invsqrt) >> (32 - 2 + 1);
-  return (val >> REC_INV_SQRT_SHIFT_ns3);
+  return static_cast<uint16_t>(val >> REC_INV_SQRT_SHIFT_ns3);
 }
 
 static uint32_t _reciprocal_scale (uint32_t val, uint32_t ep_ro)
@@ -67,9 +67,8 @@ public:
    *
    * \param p packet
    * \param addr address
-   * \param protocol
    */
-  CodelQueueDiscTestItem (Ptr<Packet> p, const Address & addr, uint16_t protocol);
+  CodelQueueDiscTestItem (Ptr<Packet> p, const Address & addr);
   virtual ~CodelQueueDiscTestItem ();
   virtual void AddHeader (void);
   virtual bool Mark(void);
@@ -89,8 +88,8 @@ private:
   CodelQueueDiscTestItem &operator = (const CodelQueueDiscTestItem &);
 };
 
-CodelQueueDiscTestItem::CodelQueueDiscTestItem (Ptr<Packet> p, const Address & addr, uint16_t protocol)
-  : QueueDiscItem (p, addr, protocol)
+CodelQueueDiscTestItem::CodelQueueDiscTestItem (Ptr<Packet> p, const Address & addr)
+  : QueueDiscItem (p, addr, 0)
 {
 }
 
@@ -123,37 +122,17 @@ public:
    *
    * \param mode the mode
    */
-  CoDelQueueDiscBasicEnqueueDequeue (std::string mode);
+  CoDelQueueDiscBasicEnqueueDequeue (QueueSizeUnit mode);
   virtual void DoRun (void);
 
-  /**
-   * Queue test size function
-   * \param queue the queue disc
-   * \param size the size
-   * \param error the error string
-   */
-  void QueueTestSize (Ptr<CoDelQueueDisc> queue, uint32_t size, std::string error)
-  {
-    if (queue->GetMode () == CoDelQueueDisc::QUEUE_DISC_MODE_BYTES)
-      {
-        NS_TEST_EXPECT_MSG_EQ (queue->GetNBytes (), size, error);
-      }
-    else if (queue->GetMode () == CoDelQueueDisc::QUEUE_DISC_MODE_PACKETS)
-      {
-        NS_TEST_EXPECT_MSG_EQ (queue->GetNPackets (), size, error);
-      }
-
-    NS_TEST_EXPECT_MSG_EQ (queue->GetQueueSize (), size, error);
-  }
-
 private:
-  StringValue m_mode; ///< mode
+  QueueSizeUnit m_mode; ///< mode
 };
 
-CoDelQueueDiscBasicEnqueueDequeue::CoDelQueueDiscBasicEnqueueDequeue (std::string mode)
-  : TestCase ("Basic enqueue and dequeue operations, and attribute setting for " + mode)
+CoDelQueueDiscBasicEnqueueDequeue::CoDelQueueDiscBasicEnqueueDequeue (QueueSizeUnit mode)
+  : TestCase ("Basic enqueue and dequeue operations, and attribute setting")
 {
-  m_mode = StringValue (mode);
+  m_mode = mode;
 }
 
 void
@@ -166,12 +145,6 @@ CoDelQueueDiscBasicEnqueueDequeue::DoRun (void)
   
   Address dest;
 
-  NS_TEST_EXPECT_MSG_EQ (queue->SetAttributeFailSafe ("Mode", m_mode), true,
-                         "Verify that we can actually set the attribute Mode");
-  NS_TEST_EXPECT_MSG_EQ (queue->SetAttributeFailSafe ("MaxPackets", UintegerValue (1500)), true,
-                         "Verify that we can actually set the attribute MaxPackets");
-  NS_TEST_EXPECT_MSG_EQ (queue->SetAttributeFailSafe ("MaxBytes", UintegerValue (pktSize * 1500)), true,
-                         "Verify that we can actually set the attribute MaxBytes");
   NS_TEST_EXPECT_MSG_EQ (queue->SetAttributeFailSafe ("MinBytes", UintegerValue (pktSize)), true,
                          "Verify that we can actually set the attribute MinBytes");
   NS_TEST_EXPECT_MSG_EQ (queue->SetAttributeFailSafe ("Interval", StringValue ("50ms")), true,
@@ -179,14 +152,16 @@ CoDelQueueDiscBasicEnqueueDequeue::DoRun (void)
   NS_TEST_EXPECT_MSG_EQ (queue->SetAttributeFailSafe ("Target", StringValue ("4ms")), true,
                          "Verify that we can actually set the attribute Target");
 
-  if (queue->GetMode () == CoDelQueueDisc::QUEUE_DISC_MODE_BYTES)
+  if (m_mode == QueueSizeUnit::BYTES)
     {
       modeSize = pktSize;
     }
-  else if (queue->GetMode () == CoDelQueueDisc::QUEUE_DISC_MODE_PACKETS)
+  else if (m_mode == QueueSizeUnit::PACKETS)
     {
       modeSize = 1;
     }
+  NS_TEST_EXPECT_MSG_EQ (queue->SetAttributeFailSafe ("MaxSize", QueueSizeValue (QueueSize (m_mode, modeSize * 1500))),
+                         true, "Verify that we can actually set the attribute MaxSize");
   queue->Initialize ();
 
   Ptr<Packet> p1, p2, p3, p4, p5, p6;
@@ -197,19 +172,19 @@ CoDelQueueDiscBasicEnqueueDequeue::DoRun (void)
   p5 = Create<Packet> (pktSize);
   p6 = Create<Packet> (pktSize);
 
-  QueueTestSize (queue, 0 * modeSize, "There should be no packets in queue");
-  queue->Enqueue (Create<CodelQueueDiscTestItem> (p1, dest, 0));
-  QueueTestSize (queue, 1 * modeSize, "There should be one packet in queue");
-  queue->Enqueue (Create<CodelQueueDiscTestItem> (p2, dest, 0));
-  QueueTestSize (queue, 2 * modeSize, "There should be two packets in queue");
-  queue->Enqueue (Create<CodelQueueDiscTestItem> (p3, dest, 0));
-  QueueTestSize (queue, 3 * modeSize, "There should be three packets in queue");
-  queue->Enqueue (Create<CodelQueueDiscTestItem> (p4, dest, 0));
-  QueueTestSize (queue, 4 * modeSize, "There should be four packets in queue");
-  queue->Enqueue (Create<CodelQueueDiscTestItem> (p5, dest, 0));
-  QueueTestSize (queue, 5 * modeSize, "There should be five packets in queue");
-  queue->Enqueue (Create<CodelQueueDiscTestItem> (p6, dest, 0));
-  QueueTestSize (queue, 6 * modeSize, "There should be six packets in queue");
+  NS_TEST_EXPECT_MSG_EQ (queue->GetCurrentSize().GetValue (), 0 * modeSize, "There should be no packets in queue");
+  queue->Enqueue (Create<CodelQueueDiscTestItem> (p1, dest));
+  NS_TEST_EXPECT_MSG_EQ (queue->GetCurrentSize().GetValue (), 1 * modeSize, "There should be one packet in queue");
+  queue->Enqueue (Create<CodelQueueDiscTestItem> (p2, dest));
+  NS_TEST_EXPECT_MSG_EQ (queue->GetCurrentSize().GetValue (), 2 * modeSize, "There should be two packets in queue");
+  queue->Enqueue (Create<CodelQueueDiscTestItem> (p3, dest));
+  NS_TEST_EXPECT_MSG_EQ (queue->GetCurrentSize().GetValue (), 3 * modeSize, "There should be three packets in queue");
+  queue->Enqueue (Create<CodelQueueDiscTestItem> (p4, dest));
+  NS_TEST_EXPECT_MSG_EQ (queue->GetCurrentSize().GetValue (), 4 * modeSize, "There should be four packets in queue");
+  queue->Enqueue (Create<CodelQueueDiscTestItem> (p5, dest));
+  NS_TEST_EXPECT_MSG_EQ (queue->GetCurrentSize().GetValue (), 5 * modeSize, "There should be five packets in queue");
+  queue->Enqueue (Create<CodelQueueDiscTestItem> (p6, dest));
+  NS_TEST_EXPECT_MSG_EQ (queue->GetCurrentSize().GetValue (), 6 * modeSize, "There should be six packets in queue");
 
   NS_TEST_EXPECT_MSG_EQ (queue->GetStats ().GetNDroppedPackets (CoDelQueueDisc::OVERLIMIT_DROP),
                          0, "There should be no packets being dropped due to full queue");
@@ -218,32 +193,32 @@ CoDelQueueDiscBasicEnqueueDequeue::DoRun (void)
 
   item = queue->Dequeue ();
   NS_TEST_EXPECT_MSG_EQ ((item != 0), true, "I want to remove the first packet");
-  QueueTestSize (queue, 5 * modeSize, "There should be five packets in queue");
+  NS_TEST_EXPECT_MSG_EQ (queue->GetCurrentSize().GetValue (), 5 * modeSize, "There should be five packets in queue");
   NS_TEST_EXPECT_MSG_EQ (item->GetPacket ()->GetUid (), p1->GetUid (), "was this the first packet ?");
 
   item = queue->Dequeue ();
   NS_TEST_EXPECT_MSG_EQ ((item != 0), true, "I want to remove the second packet");
-  QueueTestSize (queue, 4 * modeSize, "There should be four packets in queue");
+  NS_TEST_EXPECT_MSG_EQ (queue->GetCurrentSize().GetValue (), 4 * modeSize, "There should be four packets in queue");
   NS_TEST_EXPECT_MSG_EQ (item->GetPacket ()->GetUid (), p2->GetUid (), "Was this the second packet ?");
 
   item = queue->Dequeue ();
   NS_TEST_EXPECT_MSG_EQ ((item != 0), true, "I want to remove the third packet");
-  QueueTestSize (queue, 3 * modeSize, "There should be three packets in queue");
+  NS_TEST_EXPECT_MSG_EQ (queue->GetCurrentSize().GetValue (), 3 * modeSize, "There should be three packets in queue");
   NS_TEST_EXPECT_MSG_EQ (item->GetPacket ()->GetUid (), p3->GetUid (), "Was this the third packet ?");
 
   item = queue->Dequeue ();
   NS_TEST_EXPECT_MSG_EQ ((item != 0), true, "I want to remove the forth packet");
-  QueueTestSize (queue, 2 * modeSize, "There should be two packets in queue");
+  NS_TEST_EXPECT_MSG_EQ (queue->GetCurrentSize().GetValue (), 2 * modeSize, "There should be two packets in queue");
   NS_TEST_EXPECT_MSG_EQ (item->GetPacket ()->GetUid (), p4->GetUid (), "Was this the fourth packet ?");
 
   item = queue->Dequeue ();
   NS_TEST_EXPECT_MSG_EQ ((item != 0), true, "I want to remove the fifth packet");
-  QueueTestSize (queue, 1 * modeSize, "There should be one packet in queue");
+  NS_TEST_EXPECT_MSG_EQ (queue->GetCurrentSize().GetValue (), 1 * modeSize, "There should be one packet in queue");
   NS_TEST_EXPECT_MSG_EQ (item->GetPacket ()->GetUid (), p5->GetUid (), "Was this the fifth packet ?");
 
   item = queue->Dequeue ();
   NS_TEST_EXPECT_MSG_EQ ((item != 0), true, "I want to remove the last packet");
-  QueueTestSize (queue, 0 * modeSize, "There should be zero packet in queue");
+  NS_TEST_EXPECT_MSG_EQ (queue->GetCurrentSize().GetValue (), 0 * modeSize, "There should be zero packet in queue");
   NS_TEST_EXPECT_MSG_EQ (item->GetPacket ()->GetUid (), p6->GetUid (), "Was this the sixth packet ?");
 
   item = queue->Dequeue ();
@@ -267,29 +242,9 @@ public:
    *
    * \param mode the mode
    */
-  CoDelQueueDiscBasicOverflow (std::string mode);
+  CoDelQueueDiscBasicOverflow (QueueSizeUnit mode);
   virtual void DoRun (void);
 
-  /**
-   * Queue test size function
-   * \param queue the queue disc
-   * \param size the size
-   * \param error the error string
-   */
-  void QueueTestSize (Ptr<CoDelQueueDisc> queue, uint32_t size, std::string error)
-  {
-    if (queue->GetMode () == CoDelQueueDisc::QUEUE_DISC_MODE_BYTES)
-      {
-        NS_TEST_EXPECT_MSG_EQ (queue->GetNBytes (), size, error);
-      }
-    else if (queue->GetMode () == CoDelQueueDisc::QUEUE_DISC_MODE_PACKETS)
-      {
-        NS_TEST_EXPECT_MSG_EQ (queue->GetNPackets (), size, error);
-      }
-
-    NS_TEST_EXPECT_MSG_EQ (queue->GetQueueSize (), size, error);
-  }
-
 private:
   /**
    * Enqueue function
@@ -298,13 +253,13 @@ private:
    * \param nPkt the number of packets
    */
   void Enqueue (Ptr<CoDelQueueDisc> queue, uint32_t size, uint32_t nPkt);
-  StringValue m_mode; ///< mode
+  QueueSizeUnit m_mode; ///< mode
 };
 
-CoDelQueueDiscBasicOverflow::CoDelQueueDiscBasicOverflow (std::string mode)
-  : TestCase ("Basic overflow behavior for " + mode)
+CoDelQueueDiscBasicOverflow::CoDelQueueDiscBasicOverflow (QueueSizeUnit mode)
+  : TestCase ("Basic overflow behavior")
 {
-  m_mode = StringValue (mode);
+  m_mode = mode;
 }
 
 void
@@ -314,16 +269,13 @@ CoDelQueueDiscBasicOverflow::DoRun (void)
   uint32_t pktSize = 1000;
   uint32_t modeSize = 0;
 
-  NS_TEST_EXPECT_MSG_EQ (queue->SetAttributeFailSafe ("Mode", m_mode), true,
-                         "Verify that we can actually set the attribute Mode");
-
   Address dest;
 
-  if (queue->GetMode () == CoDelQueueDisc::QUEUE_DISC_MODE_BYTES)
+  if (m_mode == QueueSizeUnit::BYTES)
     {
       modeSize = pktSize;
     }
-  else if (queue->GetMode () == CoDelQueueDisc::QUEUE_DISC_MODE_PACKETS)
+  else if (m_mode == QueueSizeUnit::PACKETS)
     {
       modeSize = 1;
     }
@@ -333,21 +285,19 @@ CoDelQueueDiscBasicOverflow::DoRun (void)
   p2 = Create<Packet> (pktSize);
   p3 = Create<Packet> (pktSize);
 
-  NS_TEST_EXPECT_MSG_EQ (queue->SetAttributeFailSafe ("MaxPackets", UintegerValue (500)), true,
-                         "Verify that we can actually set the attribute MaxPackets");
-  NS_TEST_EXPECT_MSG_EQ (queue->SetAttributeFailSafe ("MaxBytes", UintegerValue (pktSize * 500)), true,
-                         "Verify that we can actually set the attribute MaxBytes");
+  NS_TEST_EXPECT_MSG_EQ (queue->SetAttributeFailSafe ("MaxSize", QueueSizeValue (QueueSize (m_mode, modeSize * 500))),
+                         true, "Verify that we can actually set the attribute MaxSize");
   NS_TEST_EXPECT_MSG_EQ (queue->SetAttributeFailSafe ("MinBytes", UintegerValue (pktSize)), true,
                          "Verify that we can actually set the attribute MinBytes");
 
   queue->Initialize ();
 
   Enqueue (queue, pktSize, 500);
-  queue->Enqueue (Create<CodelQueueDiscTestItem> (p1, dest, 0));
-  queue->Enqueue (Create<CodelQueueDiscTestItem> (p2, dest, 0));
-  queue->Enqueue (Create<CodelQueueDiscTestItem> (p3, dest, 0));
+  queue->Enqueue (Create<CodelQueueDiscTestItem> (p1, dest));
+  queue->Enqueue (Create<CodelQueueDiscTestItem> (p2, dest));
+  queue->Enqueue (Create<CodelQueueDiscTestItem> (p3, dest));
 
-  QueueTestSize (queue, 500 * modeSize, "There should be 500 packets in queue");
+  NS_TEST_EXPECT_MSG_EQ (queue->GetCurrentSize().GetValue (), 500 * modeSize, "There should be 500 packets in queue");
   NS_TEST_EXPECT_MSG_EQ (queue->GetStats ().GetNDroppedPackets (CoDelQueueDisc::OVERLIMIT_DROP),
                          3, "There should be three packets being dropped due to full queue");
 }
@@ -358,7 +308,7 @@ CoDelQueueDiscBasicOverflow::Enqueue (Ptr<CoDelQueueDisc> queue, uint32_t size,
   Address dest;
   for (uint32_t i = 0; i < nPkt; i++)
     {
-      queue->Enqueue (Create<CodelQueueDiscTestItem> (Create<Packet> (size), dest, 0));
+      queue->Enqueue (Create<CodelQueueDiscTestItem> (Create<Packet> (size), dest));
     }
 }
 
@@ -453,12 +403,10 @@ CoDelQueueDiscControlLawTest::DoRun (void)
 
   for (int i = 0; i < 4; ++i)
     {
-      uint32_t ns3Result = queue->ControlLaw (dropNextTestVals[i]);
-      uint32_t upperBound = ns3Result + 0.02 * ns3Result;
-      uint32_t lowerBound = ns3Result - 0.02 * ns3Result;
-      uint32_t linuxResult = _codel_control_law (queue, dropNextTestVals[i]);
-      NS_TEST_EXPECT_MSG_EQ ((lowerBound < linuxResult || linuxResult < upperBound), true,
-                             "Linux result should stay within 2% of ns-3 result");
+      uint32_t ns3Result = queue->ControlLaw(dropNextTestVals[i]); 
+      uint32_t linuxResult = _codel_control_law(queue, dropNextTestVals[i]); 
+      NS_TEST_EXPECT_MSG_EQ((0.98 * ns3Result < linuxResult && linuxResult < 1.02 * ns3Result), true, 
+        "Linux result should stay within 2% of ns-3 result"); 
     }
 }
 
@@ -476,29 +424,9 @@ public:
    *
    * \param mode the mode
    */
-  CoDelQueueDiscBasicDrop (std::string mode);
+  CoDelQueueDiscBasicDrop (QueueSizeUnit mode);
   virtual void DoRun (void);
 
-  /**
-   * Queue test size function
-   * \param queue the queue disc
-   * \param size the size
-   * \param error the error string
-   */
-  void QueueTestSize (Ptr<CoDelQueueDisc> queue, uint32_t size, std::string error)
-  {
-    if (queue->GetMode () == CoDelQueueDisc::QUEUE_DISC_MODE_BYTES)
-      {
-        NS_TEST_EXPECT_MSG_EQ (queue->GetNBytes (), size, error);
-      }
-    else if (queue->GetMode () == CoDelQueueDisc::QUEUE_DISC_MODE_PACKETS)
-      {
-        NS_TEST_EXPECT_MSG_EQ (queue->GetNPackets (), size, error);
-      }
-
-    NS_TEST_EXPECT_MSG_EQ (queue->GetQueueSize (), size, error);
-  }
-
 private:
   /**
    * Enqueue function
@@ -518,20 +446,22 @@ private:
    * \param newVal the new value
    */
   void DropNextTracer (uint32_t oldVal, uint32_t newVal);
-  StringValue m_mode; ///< mode
+  QueueSizeUnit m_mode; ///< mode
   uint32_t m_dropNextCount;    ///< count the number of times m_dropNext is recalculated
 };
 
-CoDelQueueDiscBasicDrop::CoDelQueueDiscBasicDrop (std::string mode)
-  : TestCase ("Basic drop operations for " + mode)
+CoDelQueueDiscBasicDrop::CoDelQueueDiscBasicDrop (QueueSizeUnit mode)
+  : TestCase ("Basic drop operations")
 {
-  m_mode = StringValue (mode);
+  m_mode = mode;
   m_dropNextCount = 0;
 }
 
 void
 CoDelQueueDiscBasicDrop::DropNextTracer (uint32_t oldVal, uint32_t newVal)
 {
+  NS_UNUSED(oldVal);
+  NS_UNUSED(newVal);
   m_dropNextCount++;
 }
 
@@ -542,22 +472,22 @@ CoDelQueueDiscBasicDrop::DoRun (void)
   uint32_t pktSize = 1000;
   uint32_t modeSize = 0;
 
-  NS_TEST_EXPECT_MSG_EQ (queue->SetAttributeFailSafe ("Mode", m_mode), true,
-                         "Verify that we can actually set the attribute Mode");
-  
-  if (queue->GetMode () == CoDelQueueDisc::QUEUE_DISC_MODE_BYTES)
+  if (m_mode == QueueSizeUnit::BYTES)
     {
       modeSize = pktSize;
     }
-  else if (queue->GetMode () == CoDelQueueDisc::QUEUE_DISC_MODE_PACKETS)
+  else if (m_mode == QueueSizeUnit::PACKETS)
     {
       modeSize = 1;
     }
 
+  NS_TEST_EXPECT_MSG_EQ (queue->SetAttributeFailSafe ("MaxSize", QueueSizeValue (QueueSize (m_mode, modeSize * 500))),
+                         true, "Verify that we can actually set the attribute MaxSize");
+
   queue->Initialize ();
 
   Enqueue (queue, pktSize, 20);
-  NS_TEST_EXPECT_MSG_EQ (queue->GetQueueSize (), 20 * modeSize, "There should be 20 packets in queue.");
+  NS_TEST_EXPECT_MSG_EQ (queue->GetCurrentSize ().GetValue (), 20 * modeSize, "There should be 20 packets in queue.");
 
   // Although the first dequeue occurs with a sojourn time above target
   // the dequeue should be successful in this interval
@@ -586,7 +516,7 @@ CoDelQueueDiscBasicDrop::Enqueue (Ptr<CoDelQueueDisc> queue, uint32_t size, uint
   Address dest;
   for (uint32_t i = 0; i < nPkt; i++)
     {
-      queue->Enqueue (Create<CodelQueueDiscTestItem> (Create<Packet> (size), dest, 0));
+      queue->Enqueue (Create<CodelQueueDiscTestItem> (Create<Packet> (size), dest));
     }
 }
 
@@ -594,7 +524,7 @@ void
 CoDelQueueDiscBasicDrop::Dequeue (Ptr<CoDelQueueDisc> queue, uint32_t modeSize)
 {
   uint32_t initialDropCount = queue->GetStats ().GetNDroppedPackets (CoDelQueueDisc::TARGET_EXCEEDED_DROP);
-  uint32_t initialQSize = queue->GetQueueSize ();
+  uint32_t initialQSize = queue->GetCurrentSize ().GetValue ();
   uint32_t initialDropNext = queue->GetDropNext ();
   Time currentTime = Simulator::Now ();
   uint32_t currentDropCount = 0;
@@ -615,13 +545,13 @@ CoDelQueueDiscBasicDrop::Dequeue (Ptr<CoDelQueueDisc> queue, uint32_t modeSize)
               NS_TEST_EXPECT_MSG_EQ (currentDropCount, 0, "We are not in dropping state."
                                      "Sojourn time has just gone above target from below."
                                      "Hence, there should be no packet drops");
-              QueueTestSize (queue, initialQSize - modeSize, "There should be 1 packet dequeued.");
+              NS_TEST_EXPECT_MSG_EQ (queue->GetCurrentSize ().GetValue (), initialQSize - modeSize, "There should be 1 packet dequeued.");
 
             }
           else if (currentTime >= queue->GetInterval ())
             {
               currentDropCount = queue->GetStats ().GetNDroppedPackets (CoDelQueueDisc::TARGET_EXCEEDED_DROP);
-              QueueTestSize (queue, initialQSize - 2 * modeSize, "Sojourn time has been above target for at least interval."
+              NS_TEST_EXPECT_MSG_EQ (queue->GetCurrentSize ().GetValue (), initialQSize - 2 * modeSize, "Sojourn time has been above target for at least interval."
                                      "We enter the dropping state, perform initial packet drop, and dequeue the next."
                                      "So there should be 2 more packets dequeued.");
               NS_TEST_EXPECT_MSG_EQ (currentDropCount, 1, "There should be 1 packet drop");
@@ -632,7 +562,7 @@ CoDelQueueDiscBasicDrop::Dequeue (Ptr<CoDelQueueDisc> queue, uint32_t modeSize)
           if (currentTime.GetMicroSeconds () < initialDropNext)
             {
               currentDropCount = queue->GetStats ().GetNDroppedPackets (CoDelQueueDisc::TARGET_EXCEEDED_DROP);
-              QueueTestSize (queue, initialQSize - modeSize, "We are in dropping state."
+              NS_TEST_EXPECT_MSG_EQ (queue->GetCurrentSize ().GetValue (), initialQSize - modeSize, "We are in dropping state."
                                      "Sojourn is still above target."
                                      "However, it's not time for next drop."
                                      "So there should be only 1 more packet dequeued");
@@ -642,7 +572,7 @@ CoDelQueueDiscBasicDrop::Dequeue (Ptr<CoDelQueueDisc> queue, uint32_t modeSize)
           else if (currentTime.GetMicroSeconds () >= initialDropNext)
             {
               currentDropCount = queue->GetStats ().GetNDroppedPackets (CoDelQueueDisc::TARGET_EXCEEDED_DROP);
-              QueueTestSize (queue, initialQSize - (m_dropNextCount + 1) * modeSize, "We are in dropping state."
+              NS_TEST_EXPECT_MSG_EQ (queue->GetCurrentSize ().GetValue (), initialQSize - (m_dropNextCount + 1) * modeSize, "We are in dropping state."
                                      "It's time for next drop."
                                      "The number of packets dequeued equals to the number of times m_dropNext is updated plus initial dequeue");
               NS_TEST_EXPECT_MSG_EQ (currentDropCount, 1 + m_dropNextCount, "The number of drops equals to the number of times m_dropNext is updated plus 1 from last dequeue");
@@ -664,17 +594,17 @@ public:
     : TestSuite ("codel-queue-disc", UNIT)
   {
     // Test 1: simple enqueue/dequeue with no drops
-    AddTestCase (new CoDelQueueDiscBasicEnqueueDequeue ("QUEUE_DISC_MODE_PACKETS"), TestCase::QUICK);
-    AddTestCase (new CoDelQueueDiscBasicEnqueueDequeue ("QUEUE_DISC_MODE_BYTES"), TestCase::QUICK);
+    AddTestCase (new CoDelQueueDiscBasicEnqueueDequeue (QueueSizeUnit::PACKETS), TestCase::QUICK);
+    AddTestCase (new CoDelQueueDiscBasicEnqueueDequeue (QueueSizeUnit::BYTES), TestCase::QUICK);
     // Test 2: enqueue with drops due to queue overflow
-    AddTestCase (new CoDelQueueDiscBasicOverflow ("QUEUE_DISC_MODE_PACKETS"), TestCase::QUICK);
-    AddTestCase (new CoDelQueueDiscBasicOverflow ("QUEUE_DISC_MODE_BYTES"), TestCase::QUICK);
+    AddTestCase (new CoDelQueueDiscBasicOverflow (QueueSizeUnit::PACKETS), TestCase::QUICK);
+    AddTestCase (new CoDelQueueDiscBasicOverflow (QueueSizeUnit::BYTES), TestCase::QUICK);
     // Test 3: test NewtonStep() against explicit port of Linux implementation
     AddTestCase (new CoDelQueueDiscNewtonStepTest (), TestCase::QUICK);
     // Test 4: test ControlLaw() against explicit port of Linux implementation
     AddTestCase (new CoDelQueueDiscControlLawTest (), TestCase::QUICK);
     // Test 5: enqueue/dequeue with drops according to CoDel algorithm
-    AddTestCase (new CoDelQueueDiscBasicDrop ("QUEUE_DISC_MODE_PACKETS"), TestCase::QUICK);
-    AddTestCase (new CoDelQueueDiscBasicDrop ("QUEUE_DISC_MODE_BYTES"), TestCase::QUICK);
+    AddTestCase (new CoDelQueueDiscBasicDrop (QueueSizeUnit::PACKETS), TestCase::QUICK);
+    AddTestCase (new CoDelQueueDiscBasicDrop (QueueSizeUnit::BYTES), TestCase::QUICK);
   }
 } g_coDelQueueTestSuite; ///< the test suite
