@@ -112,11 +112,17 @@ VisualSimulatorImpl::IsFinished (void) const
 void
 VisualSimulatorImpl::Run (void)
 {
-  if (!Py_IsInitialized ()) 
+  if (!Py_IsInitialized ())
     {
-      const char *argv[] = { "python", NULL};
-      Py_Initialize ();
-      PySys_SetArgv (1, (char**) argv);
+      #if PY_MAJOR_VERSION >= 3
+        const wchar_t *argv[] = { L"python", NULL};
+        Py_Initialize ();
+        PySys_SetArgv (1, (wchar_t**) argv);
+      #else
+        const char *argv[] = { "python", NULL};
+        Py_Initialize ();
+        PySys_SetArgv (1, (char**) argv);
+      #endif
       PyRun_SimpleString (
                           "import visualizer\n"
                           "visualizer.start();\n"
@@ -216,6 +222,12 @@ VisualSimulatorImpl::GetContext (void) const
   return m_simulator->GetContext ();
 }
 
+uint64_t
+VisualSimulatorImpl::GetEventCount (void) const
+{
+  return m_simulator->GetEventCount ();
+}
+
 void
 VisualSimulatorImpl::RunRealSimulator (void)
 {
