@@ -26,12 +26,14 @@
 #include "ns3/trace-helper.h"
 #include "ns3/wifi-phy.h"
 #include "wifi-mac-helper.h"
+#include <functional>
 
 namespace ns3 {
 
 class WifiNetDevice;
 class Node;
 class RadiotapHeader;
+class QueueItem;
 
 /**
  * \brief create PHY objects
@@ -98,6 +100,71 @@ public:
                           std::string n5 = "", const AttributeValue &v5 = EmptyAttributeValue (),
                           std::string n6 = "", const AttributeValue &v6 = EmptyAttributeValue (),
                           std::string n7 = "", const AttributeValue &v7 = EmptyAttributeValue ());
+  /**
+   * \param name the name of the frame capture model to set.
+   * \param n0 the name of the attribute to set
+   * \param v0 the value of the attribute to set
+   * \param n1 the name of the attribute to set
+   * \param v1 the value of the attribute to set
+   * \param n2 the name of the attribute to set
+   * \param v2 the value of the attribute to set
+   * \param n3 the name of the attribute to set
+   * \param v3 the value of the attribute to set
+   * \param n4 the name of the attribute to set
+   * \param v4 the value of the attribute to set
+   * \param n5 the name of the attribute to set
+   * \param v5 the value of the attribute to set
+   * \param n6 the name of the attribute to set
+   * \param v6 the value of the attribute to set
+   * \param n7 the name of the attribute to set
+   * \param v7 the value of the attribute to set
+   *
+   * Set the frame capture model and its attributes to use when Install is called.
+   */
+  void SetFrameCaptureModel (std::string name,
+                             std::string n0 = "", const AttributeValue &v0 = EmptyAttributeValue (),
+                             std::string n1 = "", const AttributeValue &v1 = EmptyAttributeValue (),
+                             std::string n2 = "", const AttributeValue &v2 = EmptyAttributeValue (),
+                             std::string n3 = "", const AttributeValue &v3 = EmptyAttributeValue (),
+                             std::string n4 = "", const AttributeValue &v4 = EmptyAttributeValue (),
+                             std::string n5 = "", const AttributeValue &v5 = EmptyAttributeValue (),
+                             std::string n6 = "", const AttributeValue &v6 = EmptyAttributeValue (),
+                             std::string n7 = "", const AttributeValue &v7 = EmptyAttributeValue ());
+  /**
+   * \param name the name of the preamble detection model to set.
+   * \param n0 the name of the attribute to set
+   * \param v0 the value of the attribute to set
+   * \param n1 the name of the attribute to set
+   * \param v1 the value of the attribute to set
+   * \param n2 the name of the attribute to set
+   * \param v2 the value of the attribute to set
+   * \param n3 the name of the attribute to set
+   * \param v3 the value of the attribute to set
+   * \param n4 the name of the attribute to set
+   * \param v4 the value of the attribute to set
+   * \param n5 the name of the attribute to set
+   * \param v5 the value of the attribute to set
+   * \param n6 the name of the attribute to set
+   * \param v6 the value of the attribute to set
+   * \param n7 the name of the attribute to set
+   * \param v7 the value of the attribute to set
+   *
+   * Set the preamble detection model and its attributes to use when Install is called.
+   */
+  void SetPreambleDetectionModel (std::string name,
+                                  std::string n0 = "", const AttributeValue &v0 = EmptyAttributeValue (),
+                                  std::string n1 = "", const AttributeValue &v1 = EmptyAttributeValue (),
+                                  std::string n2 = "", const AttributeValue &v2 = EmptyAttributeValue (),
+                                  std::string n3 = "", const AttributeValue &v3 = EmptyAttributeValue (),
+                                  std::string n4 = "", const AttributeValue &v4 = EmptyAttributeValue (),
+                                  std::string n5 = "", const AttributeValue &v5 = EmptyAttributeValue (),
+                                  std::string n6 = "", const AttributeValue &v6 = EmptyAttributeValue (),
+                                  std::string n7 = "", const AttributeValue &v7 = EmptyAttributeValue ());
+
+  /**
+   * Disable the preamble detection model.
+   */
+  void DisablePreambleDetectionModel ();
 
   /**
    * An enumeration of the pcap data link types (DLTs) which this helper
@@ -166,6 +233,8 @@ protected:
 
   ObjectFactory m_phy; ///< PHY object
   ObjectFactory m_errorRateModel; ///< error rate model
+  ObjectFactory m_frameCaptureModel; ///< frame capture model
+  ObjectFactory m_preambleDetectionModel; ///< preamble detection model
 
 
 private:
@@ -273,6 +342,49 @@ public:
                                 std::string n5 = "", const AttributeValue &v5 = EmptyAttributeValue (),
                                 std::string n6 = "", const AttributeValue &v6 = EmptyAttributeValue (),
                                 std::string n7 = "", const AttributeValue &v7 = EmptyAttributeValue ());
+
+  /**
+   * \param type the type of ns3::ObssPdAlgorithm to create.
+   * \param n0 the name of the attribute to set
+   * \param v0 the value of the attribute to set
+   * \param n1 the name of the attribute to set
+   * \param v1 the value of the attribute to set
+   * \param n2 the name of the attribute to set
+   * \param v2 the value of the attribute to set
+   * \param n3 the name of the attribute to set
+   * \param v3 the value of the attribute to set
+   * \param n4 the name of the attribute to set
+   * \param v4 the value of the attribute to set
+   * \param n5 the name of the attribute to set
+   * \param v5 the value of the attribute to set
+   * \param n6 the name of the attribute to set
+   * \param v6 the value of the attribute to set
+   * \param n7 the name of the attribute to set
+   * \param v7 the value of the attribute to set
+   *
+   * All the attributes specified in this method should exist
+   * in the requested algorithm.
+   */
+  void SetObssPdAlgorithm (std::string type,
+                           std::string n0 = "", const AttributeValue &v0 = EmptyAttributeValue (),
+                           std::string n1 = "", const AttributeValue &v1 = EmptyAttributeValue (),
+                           std::string n2 = "", const AttributeValue &v2 = EmptyAttributeValue (),
+                           std::string n3 = "", const AttributeValue &v3 = EmptyAttributeValue (),
+                           std::string n4 = "", const AttributeValue &v4 = EmptyAttributeValue (),
+                           std::string n5 = "", const AttributeValue &v5 = EmptyAttributeValue (),
+                           std::string n6 = "", const AttributeValue &v6 = EmptyAttributeValue (),
+                           std::string n7 = "", const AttributeValue &v7 = EmptyAttributeValue ());
+
+  /// Callback invoked to determine the MAC queue selected for a given packet
+  typedef std::function<std::size_t (Ptr<QueueItem>)> SelectQueueCallback;
+
+  /**
+   * \param f the select queue callback
+   *
+   * Set the select queue callback to set on the netdevice queue interface aggregated
+   * to the WifiNetDevice, in case RegularWifiMac with QoS enabled is used
+   */
+  void SetSelectQueueCallback (SelectQueueCallback f);
   /**
    * \param phy the PHY helper to create PHY objects
    * \param mac the MAC helper to create MAC objects
@@ -360,6 +472,8 @@ public:
 protected:
   ObjectFactory m_stationManager; ///< station manager
   WifiPhyStandard m_standard; ///< wifi standard
+  SelectQueueCallback m_selectQueueCallback; ///< select queue callback
+  ObjectFactory m_obssPdAlgorithm; ///< OBSS PD algorithm
 };
 
 } //namespace ns3
