@@ -52,13 +52,10 @@ public:
   AarfcdWifiManager ();
   virtual ~AarfcdWifiManager ();
 
-  // Inherited from WifiRemoteStationManager
-  void SetHtSupported (bool enable);
-  void SetVhtSupported (bool enable);
-  void SetHeSupported (bool enable);
 
 private:
-  // overridden from base class
+  // Overridden from base class.
+  void DoInitialize (void);
   WifiRemoteStation * DoCreateStation (void) const;
   void DoReportRxOk (WifiRemoteStation *station,
                      double rxSnr, WifiMode txMode);
