@@ -20,8 +20,12 @@
  *          Mirko Banchi <mk.banchi@gmail.com>
  */
 
-#include "adhoc-wifi-mac.h"
 #include "ns3/log.h"
+#include "ns3/packet.h"
+#include "adhoc-wifi-mac.h"
+#include "ht-capabilities.h"
+#include "vht-capabilities.h"
+#include "he-capabilities.h"
 #include "mac-low.h"
 
 namespace ns3 {
@@ -75,19 +79,19 @@ AdhocWifiMac::Enqueue (Ptr<const Packet> packet, Mac48Address to)
     {
       //In ad hoc mode, we assume that every destination supports all
       //the rates we support.
-      if (m_htSupported || m_vhtSupported || m_heSupported)
+      if (GetHtSupported () || GetVhtSupported () || GetHeSupported ())
         {
           m_stationManager->AddAllSupportedMcs (to);
         }
-      if (m_htSupported)
+      if (GetHtSupported ())
         {
           m_stationManager->AddStationHtCapabilities (to, GetHtCapabilities ());
         }
-      if (m_vhtSupported)
+      if (GetVhtSupported ())
         {
           m_stationManager->AddStationVhtCapabilities (to, GetVhtCapabilities ());
         }
-      if (m_heSupported)
+      if (GetHeSupported ())
         {
           m_stationManager->AddStationHeCapabilities (to, GetHeCapabilities ());
         }
@@ -107,7 +111,7 @@ AdhocWifiMac::Enqueue (Ptr<const Packet> packet, Mac48Address to)
   //back to non-QoS if talking to a peer that is also non-QoS. At
   //that point there will need to be per-station QoS state maintained
   //by the association state machine, and consulted here.
-  if (m_qosSupported)
+  if (GetQosSupported ())
     {
       hdr.SetType (WIFI_MAC_QOSDATA);
       hdr.SetQosAckPolicy (WifiMacHeader::NORMAL_ACK);
@@ -133,9 +137,9 @@ AdhocWifiMac::Enqueue (Ptr<const Packet> packet, Mac48Address to)
       hdr.SetType (WIFI_MAC_DATA);
     }
 
-  if (m_htSupported || m_vhtSupported || m_heSupported)
+  if (GetHtSupported () || GetVhtSupported () || GetHeSupported ())
     {
-      hdr.SetNoOrder ();
+      hdr.SetNoOrder (); // explicitly set to 0 for the time being since HT/VHT/HE control field is not yet implemented (set it to 1 when implemented)
     }
   hdr.SetAddr1 (to);
   hdr.SetAddr2 (m_low->GetAddress ());
@@ -143,7 +147,7 @@ AdhocWifiMac::Enqueue (Ptr<const Packet> packet, Mac48Address to)
   hdr.SetDsNotFrom ();
   hdr.SetDsNotTo ();
 
-  if (m_qosSupported)
+  if (GetQosSupported ())
     {
       //Sanity check that the TID is valid
       NS_ASSERT (tid < 8);
@@ -151,7 +155,7 @@ AdhocWifiMac::Enqueue (Ptr<const Packet> packet, Mac48Address to)
     }
   else
     {
-      m_dca->Queue (packet, hdr);
+      m_txop->Queue (packet, hdr);
     }
 }
 
@@ -178,20 +182,20 @@ AdhocWifiMac::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
     {
       //In ad hoc mode, we assume that every destination supports all
       //the rates we support.
-      if (m_htSupported || m_vhtSupported || m_heSupported)
+      if (GetHtSupported () || GetVhtSupported () || GetHeSupported ())
         {
           m_stationManager->AddAllSupportedMcs (from);
           m_stationManager->AddStationHtCapabilities (from, GetHtCapabilities ());
         }
-      if (m_htSupported)
+      if (GetHtSupported ())
         {
           m_stationManager->AddStationHtCapabilities (from, GetHtCapabilities ());
         }
-      if (m_vhtSupported)
+      if (GetVhtSupported ())
         {
           m_stationManager->AddStationVhtCapabilities (from, GetVhtCapabilities ());
         }
-      if (m_heSupported)
+      if (GetHeSupported ())
         {
           m_stationManager->AddStationHeCapabilities (from, GetHeCapabilities ());
         }
