@@ -31,7 +31,8 @@ enum BlockAckType
 {
   BASIC_BLOCK_ACK,
   COMPRESSED_BLOCK_ACK,
-  MULTI_TID_BLOCK_ACK
+  EXTENDED_COMPRESSED_BLOCK_ACK,
+  MULTI_TID_BLOCK_ACK,
 };
 
 } //namespace ns3
