@@ -24,6 +24,7 @@
 #define MAC_LOW_TRANSMISSION_PARAMETERS_H
 
 #include "ns3/uinteger.h"
+#include "block-ack-type.h"
 
 namespace ns3 {
 
@@ -54,6 +55,10 @@ public:
    * Wait COMPRESSEDBLOCKACKTimeout for a Compressed Block Ack Response frame.
    */
   void EnableCompressedBlockAck (void);
+  /**
+   * Wait COMPRESSEDBLOCKACKTimeout for an Extended Compressed Block Ack Response frame.
+   */
+  void EnableExtendedCompressedBlockAck (void);
   /**
    * NOT IMPLEMENTED FOR NOW
    */
@@ -100,19 +105,13 @@ public:
    *
    * \sa EnableBlockAck
    */
-  bool MustWaitBasicBlockAck (void) const;
+  bool MustWaitBlockAck (void) const;
   /**
-   * \returns true if compressed block ack mechanism is used, false otherwise.
+   * \returns the selected block ack variant.
    *
-   * \sa EnableCompressedBlockAck
+   * Only call this method if the block ack mechanism is used.
    */
-  bool MustWaitCompressedBlockAck (void) const;
-  /**
-   * \returns true if multi-tid block ack mechanism is used, false otherwise.
-   *
-   * \sa EnableMultiTidBlockAck
-   */
-  bool MustWaitMultiTidBlockAck (void) const;
+  BlockAckType GetBlockAckType (void) const;
   /**
    * \returns true if RTS should be sent and CTS waited for before
    *          sending data, false otherwise.
@@ -137,6 +136,7 @@ private:
     ACK_NORMAL,
     BLOCK_ACK_BASIC,
     BLOCK_ACK_COMPRESSED,
+    BLOCK_ACK_EXTENDED_COMPRESSED,
     BLOCK_ACK_MULTI_TID
   } m_waitAck; //!< wait ack
   bool m_sendRts; //!< send an RTS?
