@@ -35,21 +35,22 @@
 #include "block-ack-type.h"
 #include "wifi-mpdu-type.h"
 
-class TwoLevelAggregationTest;
-class AmpduAggregationTest;
-
 namespace ns3 {
 
+class WifiMac;
 class WifiPhy;
 class Txop;
 class QosTxop;
 class WifiMacQueueItem;
 class WifiMacQueue;
+class WifiPsdu;
 class BlockAckAgreement;
 class MgtAddBaResponseHeader;
 class WifiRemoteStationManager;
 class CtrlBAckRequestHeader;
 class CtrlBAckResponseHeader;
+class MsduAggregator;
+class MpduAggregator;
 
 /**
  * \ingroup wifi
@@ -58,10 +59,7 @@ class CtrlBAckResponseHeader;
 class MacLow : public Object
 {
 public:
-  /// Allow test cases to access private members
-  friend class ::TwoLevelAggregationTest;
-  /// Allow test cases to access private members
-  friend class ::AmpduAggregationTest;
+
   /**
    * typedef for a callback for MacLowRx
    */
@@ -90,6 +88,12 @@ public:
    * Remove WifiPhy associated with this MacLow.
    */
   void ResetPhy (void);
+  /**
+   * Set up WifiMac associated with this MacLow.
+   *
+   * \param mac WifiMac associated with this MacLow
+   */
+  void SetMac (const Ptr<WifiMac> mac);
   /**
    * Set up WifiRemoteStationManager associated with this MacLow.
    *
@@ -179,7 +183,7 @@ public:
    *
    * \return true if CTS-to-self is supported, false otherwise
    */
-  bool GetCtsToSelfSupported () const;
+  bool GetCtsToSelfSupported (void) const;
   /**
    * Return the MAC address of this MacLow.
    *
@@ -197,13 +201,13 @@ public:
    *
    * \return Basic Block ACK timeout
    */
-  Time GetBasicBlockAckTimeout () const;
+  Time GetBasicBlockAckTimeout (void) const;
   /**
    * Return Compressed Block ACK timeout of this MacLow.
    *
    * \return Compressed Block ACK timeout
    */
-  Time GetCompressedBlockAckTimeout () const;
+  Time GetCompressedBlockAckTimeout (void) const;
   /**
    * Return CTS timeout of this MacLow.
    *
@@ -272,6 +276,40 @@ public:
    */
   void RegisterDcf (Ptr<ChannelAccessManager> dcf);
 
+  /**
+   * Check whether the given MPDU, if transmitted according to the given TX vector,
+   * meets the constraint on the maximum A-MPDU size (by assuming that the frame
+   * has to be aggregated to an existing A-MPDU of the given size) and its
+   * transmission time exceeds neither the max PPDU duration (depending on the
+   * PPDU format) nor the given PPDU duration limit (if strictly positive).
+   * The given MPDU needs to be a QoS Data frame.
+   *
+   * \param mpdu the MPDU.
+   * \param txVector the TX vector used to transmit the MPDU
+   * \param ampduSize the size of the existing A-MPDU, if any
+   * \param ppduDurationLimit the limit on the PPDU duration
+   * \returns true if constraints on size and duration limit are met.
+   */
+  bool IsWithinSizeAndTimeLimits (Ptr<const WifiMacQueueItem> mpdu, WifiTxVector txVector,
+                                  uint32_t ampduSize, Time ppduDurationLimit);
+  /**
+   * Check whether an MPDU of the given size, destined to the given receiver and
+   * belonging to the given TID, if transmitted according to the given TX vector,
+   * meets the constraint on the maximum A-MPDU size (by assuming that the frame
+   * has to be aggregated to an existing A-MPDU of the given size) and its
+   * transmission time exceeds neither the max PPDU duration (depending on the
+   * PPDU format) nor the given PPDU duration limit (if strictly positive).
+   *
+   * \param mpduSize the MPDU size.
+   * \param receiver the receiver
+   * \param tid the TID
+   * \param txVector the TX vector used to transmit the MPDU
+   * \param ampduSize the size of the existing A-MPDU, if any
+   * \param ppduDurationLimit the limit on the PPDU duration
+   * \returns true if constraints on size and duration limit are met.
+   */
+  bool IsWithinSizeAndTimeLimits (uint32_t mpduSize, Mac48Address receiver, uint8_t tid,
+                                  WifiTxVector txVector, uint32_t ampduSize, Time ppduDurationLimit);
   /**
    * \param packet to send (does not include the 802.11 MAC header and checksum)
    * \param hdr header associated to the packet to send.
@@ -292,7 +330,7 @@ public:
    * \param fragmentSize the packet fragment size (if fragmentation is used)
    * \return the transmission time that includes the time for the next packet transmission
    *
-   * This transmission time includes the time required for
+   * This transmission time does not include the time required for
    * the next packet transmission if one was selected.
    */
   Time CalculateOverallTxTime (Ptr<const Packet> packet,
@@ -301,16 +339,25 @@ public:
                                uint32_t fragmentSize = 0) const;
 
   /**
-   * \param packet packet to send
-   * \param hdr 802.11 header for packet to send
+   * \param item packet to send (does not include the 802.11 MAC header and checksum)
+   * \param params transmission parameters of packet.
+   *
+   * This transmission time does not include the time required to transmit the frame.
+   * It only includes the time for the RTS/CTS exchange (if any) and for the Ack
+   * frame (if any).
+   */
+  Time CalculateOverheadTxTime (Ptr<const WifiMacQueueItem> item,
+                               const MacLowTransmissionParameters& params) const;
+
+  /**
+   * \param mpdu packet to send
    * \param parameters the transmission parameters to use for this packet.
    * \param txop pointer to the calling Txop.
    *
    * Start the transmission of the input packet and notify the listener
    * of transmission events.
    */
-  virtual void StartTransmission (Ptr<const Packet> packet,
-                                  const WifiMacHeader* hdr,
+  virtual void StartTransmission (Ptr<WifiMacQueueItem> mpdu,
                                   MacLowTransmissionParameters parameters,
                                   Ptr<Txop> txop);
 
@@ -326,12 +373,11 @@ public:
   void ReceiveOk (Ptr<Packet> packet, double rxSnr, WifiTxVector txVector, bool ampduSubframe);
   /**
    * \param packet packet received.
-   * \param rxSnr snr of packet received.
    *
    * This method is typically invoked by the lower PHY layer to notify
    * the MAC layer that a packet was unsuccessfully received.
    */
-  void ReceiveError (Ptr<Packet> packet, double rxSnr);
+  void ReceiveError (Ptr<Packet> packet);
   /**
    * \param duration switching delay duration.
    *
@@ -387,53 +433,27 @@ public:
    * associated to this AC.
    */
   void RegisterEdcaForAc (AcIndex ac, Ptr<QosTxop> edca);
-  /**
-   * \param packet the packet to be aggregated. If the aggregation is successful, it corresponds either to the first data packet that will be aggregated or to the BAR that will be piggybacked at the end of the A-MPDU.
-   * \param hdr the WifiMacHeader for the packet.
-   * \return the A-MPDU packet if aggregation is successful, the input packet otherwise
-   *
-   * This function adds the packets that will be added to an A-MPDU to an aggregate queue
-   *
-   */
-  Ptr<Packet> AggregateToAmpdu (Ptr<const Packet> packet, const WifiMacHeader hdr);
   /**
    * \param aggregatedPacket which is the current A-MPDU
    * \param rxSnr snr of packet received
    * \param txVector TXVECTOR of packet received
+   * \param statusPerMpdu reception status per MPDU
    *
    * This function de-aggregates an A-MPDU and decide if each MPDU is received correctly or not
    *
    */
-  void DeaggregateAmpduAndReceive (Ptr<Packet> aggregatedPacket, double rxSnr, WifiTxVector txVector);
-  /**
-   * \param peekedPacket the packet to be aggregated
-   * \param peekedHdr the WifiMacHeader for the packet.
-   * \param aggregatedPacket the current A-MPDU
-   * \param blockAckSize the size of a piggybacked block ack request
-   * \return false if the given packet can be added to an A-MPDU, true otherwise
-   *
-   * This function decides if a given packet can be added to an A-MPDU or not
-   *
-   */
-  bool StopMpduAggregation (Ptr<const Packet> peekedPacket, WifiMacHeader peekedHdr, Ptr<Packet> aggregatedPacket, uint8_t blockAckSize) const;
-  /**
-   *
-   * This function is called to flush the aggregate queue, which is used for A-MPDU
-   * \param tid the Traffic ID
-   *
-   */
-  void FlushAggregateQueue (uint8_t tid);
+  void DeaggregateAmpduAndReceive (Ptr<Packet> aggregatedPacket, double rxSnr, WifiTxVector txVector,
+                                   std::vector<bool> statusPerMpdu);
 
   /**
    * Return a TXVECTOR for the DATA frame given the destination.
    * The function consults WifiRemoteStationManager, which controls the rate
    * to different destinations.
    *
-   * \param packet the packet being asked for TXVECTOR
-   * \param hdr the WifiMacHeader
-   * \return TXVECTOR for the given packet
+   * \param item the item being asked for TXVECTOR
+   * \return TXVECTOR for the given item
    */
-  virtual WifiTxVector GetDataTxVector (Ptr<const Packet> packet, const WifiMacHeader *hdr) const;
+  virtual WifiTxVector GetDataTxVector (Ptr<const WifiMacQueueItem> item) const;
   /**
    * Start NAV with the given duration.
    *
@@ -450,6 +470,31 @@ public:
    */
   bool CanTransmitNextCfFrame (void) const;
 
+  /**
+   * Returns the aggregator used to construct A-MSDU subframes.
+   *
+   * \return the aggregator used to construct A-MSDU subframes.
+   */
+  Ptr<MsduAggregator> GetMsduAggregator (void) const;
+  /**
+   * Returns the aggregator used to construct A-MPDU subframes.
+   *
+   * \return the aggregator used to construct A-MPDU subframes.
+   */
+  Ptr<MpduAggregator> GetMpduAggregator (void) const;
+
+  /**
+   * Set the aggregator used to construct A-MSDU subframes.
+   *
+   * \param aggr pointer to the MSDU aggregator.
+   */
+  void SetMsduAggregator (const Ptr<MsduAggregator> aggr);
+  /**
+   * Set the aggregator used to construct A-MPDU subframes.
+   *
+   * \param aggr pointer to the MPDU aggregator.
+   */
+  void SetMpduAggregator (const Ptr<MpduAggregator> aggr);
 
 private:
   /**
@@ -464,31 +509,21 @@ private:
    */
   uint32_t GetCfEndSize (void) const;
   /**
-   * Forward the packet down to WifiPhy for transmission. This is called for the entire A-MPDu when MPDU aggregation is used.
+   * Forward a PSDU down to WifiPhy for transmission.
    *
-   * \param packet the packet
-   * \param hdr the header
+   * \param psdu the PSDU
    * \param txVector the transmit vector
    */
-  void ForwardDown (Ptr<const Packet> packet, const WifiMacHeader *hdr, WifiTxVector txVector);
-  /**
-   * Forward the MPDU down to WifiPhy for transmission. This is called for each MPDU when MPDU aggregation is used.
-   *
-   * \param packet the packet
-   * \param txVector the transmit vector
-   * \param mpdutype the MPDU type
-   */
-  void SendMpdu (Ptr<const Packet> packet, WifiTxVector txVector, MpduType mpdutype);
+  void ForwardDown (Ptr<const WifiPsdu> psdu, WifiTxVector txVector);
   /**
    * Return a TXVECTOR for the RTS frame given the destination.
    * The function consults WifiRemoteStationManager, which controls the rate
    * to different destinations.
    *
-   * \param packet the packet being asked for RTS TXVECTOR
-   * \param hdr the WifiMacHeader
-   * \return TXVECTOR for the RTS of the given packet
+   * \param item the item being asked for RTS TXVECTOR
+   * \return TXVECTOR for the RTS of the given item
    */
-  WifiTxVector GetRtsTxVector (Ptr<const Packet> packet, const WifiMacHeader *hdr) const;
+  WifiTxVector GetRtsTxVector (Ptr<const WifiMacQueueItem> item) const;
   /**
    * Return a TXVECTOR for the CTS frame given the destination and the mode of the RTS
    * used by the sender.
@@ -544,6 +579,14 @@ private:
    * \return TXVECTOR for the Block ACK
    */
   WifiTxVector GetAckTxVectorForData (Mac48Address to, WifiMode dataTxMode) const;
+  /**
+   * Get control answer mode function.
+   *
+   * \param reqMode request mode
+   *
+   * \return control answer mode
+   */
+  WifiMode GetControlAnswerMode (WifiMode reqMode) const;
   /**
    * Return the time required to transmit the CTS (including preamble and FCS).
    *
@@ -585,13 +628,6 @@ private:
    * \return the time required to transmit the Block ACK (including preamble and FCS)
    */
   Time GetBlockAckDuration (WifiTxVector blockAckReqTxVector, BlockAckType type) const;
-  /**
-   * Check if the current packet should be sent with a RTS protection.
-   *
-   * \return true if RTS protection should be used,
-   *         false otherwise
-   */
-  bool NeedRts (void) const;
   /**
    * Check if CTS-to-self mechanism should be used for the current packet.
    *
@@ -629,7 +665,7 @@ private:
   /**
    * Notify ChannelAccessManager that ACK timer should be reset.
    */
-  void NotifyAckTimeoutResetNow ();
+  void NotifyAckTimeoutResetNow (void);
   /**
    * Notify ChannelAccessManager that CTS timer should be started for the given duration.
    *
@@ -639,7 +675,7 @@ private:
   /**
    * Notify ChannelAccessManager that CTS timer should be reset.
    */
-  void NotifyCtsTimeoutResetNow ();
+  void NotifyCtsTimeoutResetNow (void);
   /**
    * Reset NAV after CTS was missed when the NAV was
    * set with RTS.
@@ -792,8 +828,8 @@ private:
    * \param blockAckReqTxVector the transmit vector
    * \param rxSnr the receive SNR
    */
-  void SendBlockAckAfterAmpdu (uint8_t tid, Mac48Address originator,
-                               Time duration, WifiTxVector blockAckReqTxVector, double rxSnr);
+  void SendBlockAckAfterAmpdu (uint8_t tid, Mac48Address originator, Time duration,
+                               WifiTxVector blockAckReqTxVector, double rxSnr);
   /**
    * This method creates block ack frame with header equals to <i>blockAck</i> and start its transmission.
    *
@@ -828,51 +864,12 @@ private:
    * \param phy the WifiPhy this MacLow is connected to
    */
   void RemovePhyMacLowListener (Ptr<WifiPhy> phy);
-  /**
-   * Checks if the given packet will be aggregated to an A-MPDU or not
-   *
-   * \param packet packet to check whether it can be aggregated in an A-MPDU
-   * \param hdr 802.11 header for packet to check whether it can be aggregated in an A-MPDU
-   * \returns true if is A-MPDU
-   */
-  bool IsAmpdu (Ptr<const Packet> packet, const WifiMacHeader hdr);
-  /**
-   * Insert in a temporary queue.
-   * It is only used with a RTS/CTS exchange for an A-MPDU transmission.
-   *
-   * \param packet packet to be inserted in the A-MPDU tx queue
-   * \param hdr 802.11 header for the packet to be inserted in the A-MPDU tx queue
-   * \param tStamp timestamp of the packet to be inserted in the A-MPDU tx queue
-   * \param tid the Traffic ID of the packet to be inserted in the A-MPDU tx queue
-   */
-  void InsertInTxQueue (Ptr<const Packet> packet, const WifiMacHeader &hdr, Time tStamp, uint8_t tid);
-  /**
-   * Perform MSDU aggregation for a given MPDU in an A-MPDU
-   *
-   * \param packet packet picked for aggregation
-   * \param hdr 802.11 header for packet picked for aggregation
-   * \param tstamp timestamp
-   * \param currentAmpduPacket current A-MPDU packet
-   * \param blockAckSize size of the piggybacked block ack request
-   *
-   * \return the aggregate if MSDU aggregation succeeded, 0 otherwise
-   */
-  Ptr<Packet> PerformMsduAggregation (Ptr<const Packet> packet, WifiMacHeader *hdr, Time *tstamp, Ptr<Packet> currentAmpduPacket, uint8_t blockAckSize);
 
   Ptr<WifiPhy> m_phy; //!< Pointer to WifiPhy (actually send/receives frames)
+  Ptr<WifiMac> m_mac; //!< Pointer to WifiMac (to fetch configuration)
   Ptr<WifiRemoteStationManager> m_stationManager; //!< Pointer to WifiRemoteStationManager (rate control)
   MacLowRxCallback m_rxCallback; //!< Callback to pass packet up
 
-  /**
-   * A struct for packet, Wifi header, and timestamp.
-   */
-  struct Item
-  {
-    Ptr<const Packet> packet; //!< the packet
-    WifiMacHeader hdr; //!< the header
-    Time timestamp; //!< the timestamp
-  }; //!< item structure
-
   /**
    * A struct that holds information about ACK piggybacking (CF-ACK).
    */
@@ -893,6 +890,9 @@ private:
   typedef std::vector<Ptr<ChannelAccessManager> > ChannelAccessManagers;
   ChannelAccessManagers m_channelAccessManagers; //!< List of ChannelAccessManager
 
+  Ptr<MsduAggregator> m_msduAggregator;             //!< A-MSDU aggregator
+  Ptr<MpduAggregator> m_mpduAggregator;             //!< A-MPDU aggregator
+
   EventId m_normalAckTimeoutEvent;      //!< Normal ACK timeout event
   EventId m_blockAckTimeoutEvent;       //!< Block ACK timeout event
   EventId m_ctsTimeoutEvent;            //!< CTS timeout event
@@ -903,8 +903,7 @@ private:
   EventId m_endTxNoAckEvent;            //!< Event for finishing transmission that does not require ACK
   EventId m_navCounterResetCtsMissed;   //!< Event to reset NAV when CTS is not received
 
-  Ptr<Packet> m_currentPacket;              //!< Current packet transmitted/to be transmitted
-  WifiMacHeader m_currentHdr;               //!< Header of the current transmitted packet
+  Ptr<WifiPsdu> m_currentPacket;            //!< Current packet transmitted/to be transmitted
   Ptr<Txop> m_currentTxop;                  //!< Current TXOP
   MacLowTransmissionParameters m_txParams;  //!< Transmission parameters of the current packet
   Mac48Address m_self;                      //!< Address of this MacLow (Mac48Address)
@@ -929,7 +928,6 @@ private:
   Time m_cfpForeshortening; //!< The delay the current CF period should be foreshortened
 
   bool m_promisc;  //!< Flag if the device is operating in promiscuous mode
-  bool m_ampdu;    //!< Flag if the current transmission involves an A-MPDU
 
   class PhyMacLowListener * m_phyMacLowListener; //!< Listener needed to monitor when a channel switching occurs.
 
@@ -955,8 +953,6 @@ private:
   QueueEdcas m_edca; //!< EDCA queues
 
   bool m_ctsToSelfSupported;             //!< Flag whether CTS-to-self is supported
-  Ptr<WifiMacQueue> m_aggregateQueue[8]; //!< Queues per TID used for MPDU aggregation
-  std::vector<Item> m_txPackets[8];      //!< Contain temporary items to be sent with the next A-MPDU transmission for a given TID, once RTS/CTS exchange has succeeded.
   WifiTxVector m_currentTxVector;        //!< TXVECTOR used for the current packet transmission
 
   CfAckInfo m_cfAckInfo; //!< Info about piggyback ACKs used in PCF
