@@ -22,13 +22,15 @@
 #define MAC_RX_MIDDLE_H
 
 #include <map>
-#include "ns3/packet.h"
 #include "ns3/simple-ref-count.h"
+#include "ns3/callback.h"
 
 namespace ns3 {
 
 class WifiMacHeader;
 class OriginatorRxStatus;
+class Packet;
+class Mac48Address;
 
 /**
  * \ingroup wifi
@@ -53,6 +55,13 @@ public:
    */
   void SetForwardCallback (ForwardUpCallback callback);
 
+  /**
+   * Set a callback to trigger the next PCF frame.
+   *
+   * \param callback
+   */
+  void SetPcfCallback (Callback<void> callback);
+
   /**
    * Receive a packet.
    *
@@ -113,17 +122,19 @@ private:
    */
   typedef std::map <std::pair<Mac48Address, uint8_t>, OriginatorRxStatus *, std::less<std::pair<Mac48Address,uint8_t> > > QosOriginators;
   /**
-   * typedef for an interator for Originators
+   * typedef for an iterator for Originators
    */
   typedef std::map <Mac48Address, OriginatorRxStatus *, std::less<Mac48Address> >::iterator OriginatorsI;
   /**
-   * typedef for an interator for QosOriginators
+   * typedef for an iterator for QosOriginators
    */
   typedef std::map <std::pair<Mac48Address, uint8_t>, OriginatorRxStatus *, std::less<std::pair<Mac48Address,uint8_t> > >::iterator QosOriginatorsI;
 
   Originators m_originatorStatus; ///< originator status
   QosOriginators m_qosOriginatorStatus; ///< QOS originator status
   ForwardUpCallback m_callback; ///< forward up callback
+
+  Callback<void> m_pcfCallback; //!< PCF callback
 };
 
 } //namespace ns3
