@@ -20,6 +20,7 @@
  */
 
 #include "ns3/socket.h"
+#include "ns3/queue-item.h"
 #include "qos-utils.h"
 #include "wifi-mac-header.h"
 #include "mgt-headers.h"
@@ -159,5 +160,28 @@ GetTid (Ptr<const Packet> packet, const WifiMacHeader hdr)
     }
 }
 
+uint8_t
+SelectQueueByDSField (Ptr<QueueItem> item)
+{
+  uint8_t dscp, priority = 0;
+  if (item->GetUint8Value (QueueItem::IP_DSFIELD, dscp))
+    {
+      // if the QoS map element is implemented, it should be used here
+      // to set the priority.
+      // User priority is set to the three most significant bits of the DS field
+      priority = dscp >> 5;
+    }
+
+  // replace the priority tag
+  SocketPriorityTag priorityTag;
+  priorityTag.SetPriority (priority);
+  item->GetPacket ()->ReplacePacketTag (priorityTag);
+
+  // if the admission control were implemented, here we should check whether
+  // the access category assigned to the packet should be downgraded
+
+  return static_cast<uint8_t> (QosUtilsMapTidToAc (priority));
+}
+
 
 } //namespace ns3
