@@ -18,8 +18,8 @@
  * Author: Mathieu Lacage <mathieu.lacage@sophia.inria.fr>
  */
 
-#include "supported-rates.h"
 #include "ns3/log.h"
+#include "supported-rates.h"
 
 namespace ns3 {
 
@@ -56,50 +56,26 @@ SupportedRates::operator= (const SupportedRates& rates)
 }
 
 void
-SupportedRates::AddSupportedRate (uint32_t bs)
+SupportedRates::AddSupportedRate (uint64_t bs)
 {
   NS_LOG_FUNCTION (this << bs);
   NS_ASSERT_MSG (IsBssMembershipSelectorRate (bs) == false, "Invalid rate");
   NS_ASSERT (m_nRates < MAX_SUPPORTED_RATES);
-  if (bs == BSS_MEMBERSHIP_SELECTOR_HT_PHY)
+  if (IsSupportedRate (bs))
     {
-      // Encoding defined in Sec. 8.4.2.3, IEEE 802.11-2012
-      m_rates[m_nRates] = (BSS_MEMBERSHIP_SELECTOR_HT_PHY | 0x80);
-      m_nRates++;
-      NS_LOG_DEBUG ("add HT_PHY membership selector");
-    }
-  else if (bs == BSS_MEMBERSHIP_SELECTOR_VHT_PHY)
-    {
-      // Encoding defined in Sec. 8.4.2.3, IEEE 802.11-2012
-      m_rates[m_nRates] = (BSS_MEMBERSHIP_SELECTOR_VHT_PHY | 0x80);
-      m_nRates++;
-      NS_LOG_DEBUG ("add VHT_PHY membership selector");
-    }
-  else if (bs == BSS_MEMBERSHIP_SELECTOR_HE_PHY)
-    {
-      // Encoding defined in Sec. 8.4.2.3, IEEE 802.11-2012
-      m_rates[m_nRates] = (BSS_MEMBERSHIP_SELECTOR_HE_PHY | 0x80);
-      m_nRates++;
-      NS_LOG_DEBUG ("add HE_PHY membership selector");
-    }
-  else
-    {
-      if (IsSupportedRate (bs))
-        {
-          return;
-        }
-      m_rates[m_nRates] = bs / 500000;
-      m_nRates++;
-      NS_LOG_DEBUG ("add rate=" << bs << ", n rates=" << +m_nRates);
+      return;
     }
+  m_rates[m_nRates] = static_cast<uint8_t> (bs / 500000);
+  m_nRates++;
+  NS_LOG_DEBUG ("add rate=" << bs << ", n rates=" << +m_nRates);
 }
 
 void
-SupportedRates::SetBasicRate (uint32_t bs)
+SupportedRates::SetBasicRate (uint64_t bs)
 {
   NS_LOG_FUNCTION (this << bs);
   NS_ASSERT_MSG (IsBssMembershipSelectorRate (bs) == false, "Invalid rate");
-  uint8_t rate = bs / 500000;
+  uint8_t rate = static_cast<uint8_t> (bs / 500000);
   for (uint8_t i = 0; i < m_nRates; i++)
     {
       if ((rate | 0x80) == m_rates[i])
@@ -118,14 +94,14 @@ SupportedRates::SetBasicRate (uint32_t bs)
 }
 
 void
-SupportedRates::AddBssMembershipSelectorRate (uint32_t bs)
+SupportedRates::AddBssMembershipSelectorRate (uint64_t bs)
 {
   NS_LOG_FUNCTION (this << bs);
-  if ((bs != BSS_MEMBERSHIP_SELECTOR_HT_PHY) && (bs != BSS_MEMBERSHIP_SELECTOR_VHT_PHY) && (bs != BSS_MEMBERSHIP_SELECTOR_HE_PHY))
-    {
-      NS_ASSERT_MSG (false, "Value " << bs << " not a BSS Membership Selector");
-    }
-  uint32_t rate = (bs | 0x80);
+  NS_ASSERT_MSG (bs == BSS_MEMBERSHIP_SELECTOR_HT_PHY ||
+ 	         bs == BSS_MEMBERSHIP_SELECTOR_VHT_PHY ||
+ 	         bs == BSS_MEMBERSHIP_SELECTOR_HE_PHY,
+                 "Value " << bs << " not a BSS Membership Selector");
+  uint8_t rate = static_cast<uint8_t> (bs / 500000);
   for (uint8_t i = 0; i < m_nRates; i++)
     {
       if (rate == m_rates[i])
@@ -134,15 +110,15 @@ SupportedRates::AddBssMembershipSelectorRate (uint32_t bs)
         }
     }
   m_rates[m_nRates] = rate;
-  NS_LOG_DEBUG ("add BSS membership selector rate " << bs << " as rate " << m_nRates);
+  NS_LOG_DEBUG ("add BSS membership selector rate " << bs << " as rate " << +rate);
   m_nRates++;
 }
 
 bool
-SupportedRates::IsBasicRate (uint32_t bs) const
+SupportedRates::IsBasicRate (uint64_t bs) const
 {
   NS_LOG_FUNCTION (this << bs);
-  uint8_t rate = (bs / 500000) | 0x80;
+  uint8_t rate = static_cast<uint8_t> (bs / 500000) | 0x80;
   for (uint8_t i = 0; i < m_nRates; i++)
     {
       if (rate == m_rates[i])
@@ -154,10 +130,10 @@ SupportedRates::IsBasicRate (uint32_t bs) const
 }
 
 bool
-SupportedRates::IsSupportedRate (uint32_t bs) const
+SupportedRates::IsSupportedRate (uint64_t bs) const
 {
   NS_LOG_FUNCTION (this << bs);
-  uint8_t rate = bs / 500000;
+  uint8_t rate = static_cast<uint8_t> (bs / 500000);
   for (uint8_t i = 0; i < m_nRates; i++)
     {
       if (rate == m_rates[i]
@@ -170,7 +146,7 @@ SupportedRates::IsSupportedRate (uint32_t bs) const
 }
 
 bool
-SupportedRates::IsBssMembershipSelectorRate (uint32_t bs) const
+SupportedRates::IsBssMembershipSelectorRate (uint64_t bs) const
 {
   NS_LOG_FUNCTION (this << bs);
   if ((bs & 0x7f) == BSS_MEMBERSHIP_SELECTOR_HT_PHY
