@@ -161,8 +161,6 @@ VhtOperation::DeserializeInformationField (Buffer::Iterator start, uint8_t lengt
   return length;
 }
 
-ATTRIBUTE_HELPER_CPP (VhtOperation);
-
 /**
  * output stream output operator
  *
@@ -181,24 +179,4 @@ operator << (std::ostream &os, const VhtOperation &VhtOperation)
   return os;
 }
 
-/**
- * input stream input operator
- *
- * \param is input stream
- * \param VhtOperation the VHT operation
- *
- * \returns input stream
- */
-std::istream &operator >> (std::istream &is, VhtOperation &VhtOperation)
-{
-  uint8_t c1, c2, c3;
-  uint16_t c4;
-  is >> c1 >> c2 >> c3 >> c4;
-  VhtOperation.SetChannelWidth (c1);
-  VhtOperation.SetChannelCenterFrequencySegment0 (c2);
-  VhtOperation.SetChannelCenterFrequencySegment1 (c3);
-  VhtOperation.SetBasicVhtMcsAndNssSet (c4);
-  return is;
-}
-
 } //namespace ns3
