@@ -538,6 +538,12 @@ public:
    * \return the Traffic ID of a QoS header
    */
   uint8_t GetQosTid (void) const;
+  /**
+   * Return the QoS ACK policy in the QoS control field.
+   *
+   * \return the QoS ACK policy in the QoS control field
+   */
+  QosAckPolicy GetQosAckPolicy (void) const;
   /**
    * Return the size of the WifiMacHeader in octets.
    * GetSerializedSize calls this function.
