@@ -22,16 +22,24 @@
  */
 
 #include "ns3/simulator.h"
+#include "ns3/packet.h"
+#include "ns3/log.h"
 #include "wifi-mac-queue-item.h"
+#include "wifi-mac-trailer.h"
 
 namespace ns3 {
 
 NS_LOG_COMPONENT_DEFINE ("WifiMacQueueItem");
 
 WifiMacQueueItem::WifiMacQueueItem (Ptr<const Packet> p, const WifiMacHeader & header)
+  : WifiMacQueueItem (p, header, Simulator::Now ())
+{
+}
+
+WifiMacQueueItem::WifiMacQueueItem (Ptr<const Packet> p, const WifiMacHeader & header, Time tstamp)
   : m_packet (p),
     m_header (header),
-    m_tstamp (Simulator::Now ())
+    m_tstamp (tstamp)
 {
 }
 
@@ -51,6 +59,12 @@ WifiMacQueueItem::GetHeader (void) const
   return m_header;
 }
 
+WifiMacHeader&
+WifiMacQueueItem::GetHeader (void)
+{
+  return m_header;
+}
+
 Mac48Address
 WifiMacQueueItem::GetDestinationAddress (void) const
 {
@@ -66,9 +80,38 @@ WifiMacQueueItem::GetTimeStamp (void) const
 uint32_t
 WifiMacQueueItem::GetSize (void) const
 {
-  return m_packet->GetSize () + m_header.GetSerializedSize ();
+  return m_packet->GetSize () + m_header.GetSerializedSize () + WIFI_MAC_FCS_LENGTH;
 }
 
-NS_OBJECT_TEMPLATE_CLASS_DEFINE (Queue, WifiMacQueueItem);
+void
+WifiMacQueueItem::Print (std::ostream& os) const
+{
+  os << "size=" << m_packet->GetSize ()
+     << ", to=" << m_header.GetAddr1 ()
+     << ", seqN=" << m_header.GetSequenceNumber ()
+     << ", lifetime=" << (Simulator::Now () - m_tstamp).GetMicroSeconds () << "us";
+  if (m_header.IsQosData ())
+    {
+      os << ", tid=" << +m_header.GetQosTid ();
+      if (m_header.IsQosNoAck ())
+        {
+          os << ", ack=NoAck";
+        }
+      else if (m_header.IsQosAck ())
+        {
+          os << ", ack=NormalAck";
+        }
+      else if (m_header.IsQosBlockAck ())
+        {
+          os << ", ack=BlockAck";
+        }
+    }
+}
+
+std::ostream & operator << (std::ostream &os, const WifiMacQueueItem &item)
+{
+  item.Print (os);
+  return os;
+}
 
 } //namespace ns3
