@@ -30,6 +30,7 @@ namespace ns3 {
 NS_LOG_COMPONENT_DEFINE ("WifiMacQueue");
 
 NS_OBJECT_ENSURE_REGISTERED (WifiMacQueue);
+NS_OBJECT_TEMPLATE_CLASS_DEFINE (Queue, WifiMacQueueItem);
 
 TypeId
 WifiMacQueue::GetTypeId (void)
@@ -38,6 +39,11 @@ WifiMacQueue::GetTypeId (void)
     .SetParent<Queue<WifiMacQueueItem> > ()
     .SetGroupName ("Wifi")
     .AddConstructor<WifiMacQueue> ()
+    .AddAttribute ("MaxQueueSize",
+                   "The max queue size",
+                   QueueSizeValue (QueueSize ("500p")),
+                   MakeQueueSizeAccessor (&WifiMacQueue::SetMaxQueueSize),
+                   MakeQueueSizeChecker ())
     .AddAttribute ("MaxDelay", "If a packet stays longer than this delay in the queue, it is dropped.",
                    TimeValue (MilliSeconds (500)),
                    MakeTimeAccessor (&WifiMacQueue::SetMaxDelay),
@@ -47,12 +53,16 @@ WifiMacQueue::GetTypeId (void)
                    MakeEnumAccessor (&WifiMacQueue::m_dropPolicy),
                    MakeEnumChecker (WifiMacQueue::DROP_OLDEST, "DropOldest",
                                     WifiMacQueue::DROP_NEWEST, "DropNewest"))
+    .AddTraceSource ("Expired", "MPDU dropped because its lifetime expired.",
+                     MakeTraceSourceAccessor (&WifiMacQueue::m_traceExpired),
+                     "ns3::WifiMacQueueItem::TracedCallback")
   ;
   return tid;
 }
 
 WifiMacQueue::WifiMacQueue ()
-  : NS_LOG_TEMPLATE_DEFINE ("WifiMacQueue")
+  : m_expiredPacketsPresent (false),
+    NS_LOG_TEMPLATE_DEFINE ("WifiMacQueue")
 {
 }
 
@@ -61,6 +71,21 @@ WifiMacQueue::~WifiMacQueue ()
   NS_LOG_FUNCTION_NOARGS ();
 }
 
+const WifiMacQueue::ConstIterator WifiMacQueue::EMPTY = std::list<Ptr<WifiMacQueueItem>> ().end ();
+
+void
+WifiMacQueue::SetMaxQueueSize (QueueSize size)
+{
+  NS_LOG_FUNCTION (this << size);
+  m_maxSize = size;
+}
+
+QueueSize
+WifiMacQueue::GetMaxQueueSize (void) const
+{
+  return m_maxSize;
+}
+
 void
 WifiMacQueue::SetMaxDelay (Time delay)
 {
@@ -83,6 +108,7 @@ WifiMacQueue::TtlExceeded (ConstIterator &it)
     {
       NS_LOG_DEBUG ("Removing packet that stayed in the queue for too long (" <<
                     Simulator::Now () - (*it)->GetTimeStamp () << ")");
+      m_traceExpired (*it);
       auto curr = it++;
       DoRemove (curr);
       return true;
@@ -93,62 +119,64 @@ WifiMacQueue::TtlExceeded (ConstIterator &it)
 bool
 WifiMacQueue::Enqueue (Ptr<WifiMacQueueItem> item)
 {
-  NS_LOG_FUNCTION (this << item);
-  NS_ASSERT_MSG (GetMaxSize ().GetUnit () == QueueSizeUnit::PACKETS,
-                 "WifiMacQueues must be in packet mode");
+  NS_LOG_FUNCTION (this << *item);
 
-  // if the queue is full, remove the first stale packet (if any) encountered
-  // starting from the head of the queue, in order to make room for the new packet.
-  if (QueueBase::GetNPackets () == GetMaxSize ().GetValue ())
-    {
-      auto it = Head ();
-      while (it != Tail () && !TtlExceeded (it))
-        {
-          it++;
-        }
-    }
-
-  if (QueueBase::GetNPackets () == GetMaxSize ().GetValue () && m_dropPolicy == DROP_OLDEST)
-    {
-      NS_LOG_DEBUG ("Remove the oldest item in the queue");
-      DoRemove (Head ());
-    }
-
-  return DoEnqueue (Tail (), item);
+  return Insert (end (), item);
 }
 
 bool
 WifiMacQueue::PushFront (Ptr<WifiMacQueueItem> item)
 {
-  NS_LOG_FUNCTION (this << item);
+  NS_LOG_FUNCTION (this << *item);
+
+  return Insert (begin (), item);
+}
+
+bool
+WifiMacQueue::Insert (ConstIterator pos, Ptr<WifiMacQueueItem> item)
+{
+  NS_LOG_FUNCTION (this << *item);
   NS_ASSERT_MSG (GetMaxSize ().GetUnit () == QueueSizeUnit::PACKETS,
                  "WifiMacQueues must be in packet mode");
 
-  // if the queue is full, remove the first stale packet (if any) encountered
-  // starting from the head of the queue, in order to make room for the new packet.
-  if (QueueBase::GetNPackets () == GetMaxSize ().GetValue ())
+  QueueBase::SetMaxSize (GetMaxQueueSize ()); //Make sure QueueBase has the same maximum queue size
+
+  // insert the item if the queue is not full
+  if (QueueBase::GetNPackets () < GetMaxSize ().GetValue ())
     {
-      auto it = Head ();
-      while (it != Tail () && !TtlExceeded (it))
-        {
-          it++;
-        }
+      return DoEnqueue (pos, item);
     }
 
-  if (QueueBase::GetNPackets () == GetMaxSize ().GetValue () && m_dropPolicy == DROP_OLDEST)
+  // the queue is full; scan the list in the attempt to remove stale packets
+  ConstIterator it = begin ();
+  while (it != end ())
+    {
+      if (it == pos && TtlExceeded (it))
+        {
+          return DoEnqueue (it, item);
+        }
+      if (TtlExceeded (it))
+        {
+          return DoEnqueue (pos, item);
+        }
+      it++;
+    }
+
+  // the queue is still full, remove the oldest item if the policy is drop oldest
+  if (m_dropPolicy == DROP_OLDEST)
     {
       NS_LOG_DEBUG ("Remove the oldest item in the queue");
-      DoRemove (Head ());
+      DoRemove (begin ());
     }
 
-  return DoEnqueue (Head (), item);
+  return DoEnqueue (pos, item);
 }
 
 Ptr<WifiMacQueueItem>
 WifiMacQueue::Dequeue (void)
 {
   NS_LOG_FUNCTION (this);
-  for (auto it = Head (); it != Tail (); )
+  for (ConstIterator it = begin (); it != end (); )
     {
       if (!TtlExceeded (it))
         {
@@ -163,62 +191,90 @@ Ptr<WifiMacQueueItem>
 WifiMacQueue::DequeueByAddress (Mac48Address dest)
 {
   NS_LOG_FUNCTION (this << dest);
+  ConstIterator it = PeekByAddress (dest);
 
-  for (auto it = Head (); it != Tail (); )
+  if (it == end ())
     {
-      if (!TtlExceeded (it))
-        {
-          if ((*it)->GetHeader ().IsData () && (*it)->GetDestinationAddress () == dest)
-            {
-              return DoDequeue (it);
-            }
-
-          it++;
-        }
+      return 0;
     }
-  NS_LOG_DEBUG ("The queue is empty");
-  return 0;
+  return Dequeue (it);
+}
+
+Ptr<WifiMacQueueItem>
+WifiMacQueue::DequeueByTid (uint8_t tid)
+{
+  NS_LOG_FUNCTION (this << +tid);
+  ConstIterator it = PeekByTid (tid);
+
+  if (it == end ())
+    {
+      return 0;
+    }
+  return Dequeue (it);
 }
 
 Ptr<WifiMacQueueItem>
 WifiMacQueue::DequeueByTidAndAddress (uint8_t tid, Mac48Address dest)
 {
-  NS_LOG_FUNCTION (this << dest);
-  for (auto it = Head (); it != Tail (); )
-    {
-      if (!TtlExceeded (it))
-        {
-          if ((*it)->GetHeader ().IsQosData () && (*it)->GetDestinationAddress () == dest
-              && (*it)->GetHeader ().GetQosTid () == tid)
-            {
-              return DoDequeue (it);
-            }
+  NS_LOG_FUNCTION (this << +tid << dest);
+  ConstIterator it = PeekByTidAndAddress (tid, dest);
 
-          it++;
-        }
+  if (it == end ())
+    {
+      return 0;
     }
-  NS_LOG_DEBUG ("The queue is empty");
-  return 0;
+  return Dequeue (it);
 }
 
 Ptr<WifiMacQueueItem>
 WifiMacQueue::DequeueFirstAvailable (const Ptr<QosBlockedDestinations> blockedPackets)
 {
   NS_LOG_FUNCTION (this);
-  for (auto it = Head (); it != Tail (); )
-    {
-      if (!TtlExceeded (it))
-        {
-          if (!(*it)->GetHeader ().IsQosData ()
-              || !blockedPackets->IsBlocked ((*it)->GetHeader ().GetAddr1 (), (*it)->GetHeader ().GetQosTid ()))
-            {
-              return DoDequeue (it);
-            }
+  ConstIterator it = PeekFirstAvailable (blockedPackets);
 
+  if (it == end ())
+    {
+      return 0;
+    }
+  return Dequeue (it);
+}
+
+Ptr<WifiMacQueueItem>
+WifiMacQueue::Dequeue (ConstIterator pos)
+{
+  NS_LOG_FUNCTION (this);
+
+  if (!m_expiredPacketsPresent)
+    {
+      if (TtlExceeded (pos))
+        {
+          NS_LOG_DEBUG ("Packet lifetime expired");
+          return 0;
+        }
+      return DoDequeue (pos);
+    }
+
+  // remove stale items queued before the given position
+  ConstIterator it = begin ();
+  while (it != end ())
+    {
+      if (it == pos)
+        {
+          // reset the flag signaling the presence of expired packets before returning
+          m_expiredPacketsPresent = false;
+
+          if (TtlExceeded (it))
+            {
+              return 0;
+            }
+          return DoDequeue (it);
+        }
+      else if (!TtlExceeded (it))
+        {
           it++;
         }
     }
-  NS_LOG_DEBUG ("The queue is empty");
+  NS_LOG_DEBUG ("Invalid iterator");
   return 0;
 }
 
@@ -226,7 +282,7 @@ Ptr<const WifiMacQueueItem>
 WifiMacQueue::Peek (void) const
 {
   NS_LOG_FUNCTION (this);
-  for (auto it = Head (); it != Tail (); it++)
+  for (auto it = begin (); it != end (); it++)
     {
       // skip packets that stayed in the queue for too long. They will be
       // actually removed from the queue by the next call to a non-const method
@@ -234,51 +290,122 @@ WifiMacQueue::Peek (void) const
         {
           return DoPeek (it);
         }
+      // signal the presence of expired packets
+      m_expiredPacketsPresent = true;
     }
   NS_LOG_DEBUG ("The queue is empty");
   return 0;
 }
 
-Ptr<const WifiMacQueueItem>
-WifiMacQueue::PeekByTidAndAddress (uint8_t tid, Mac48Address dest)
+WifiMacQueue::ConstIterator
+WifiMacQueue::PeekByAddress (Mac48Address dest, ConstIterator pos) const
 {
   NS_LOG_FUNCTION (this << dest);
-  for (auto it = Head (); it != Tail (); )
+  ConstIterator it = (pos != EMPTY ? pos : begin ());
+  while (it != end ())
     {
-      if (!TtlExceeded (it))
+      // skip packets that stayed in the queue for too long. They will be
+      // actually removed from the queue by the next call to a non-const method
+      if (Simulator::Now () <= (*it)->GetTimeStamp () + m_maxDelay)
+        {
+          if (((*it)->GetHeader ().IsData () || (*it)->GetHeader ().IsQosData ())
+              && (*it)->GetDestinationAddress () == dest)
+            {
+              return it;
+            }
+        }
+      else
+        {
+          // signal the presence of expired packets
+          m_expiredPacketsPresent = true;
+        }
+      it++;
+    }
+  NS_LOG_DEBUG ("The queue is empty");
+  return end ();
+}
+
+WifiMacQueue::ConstIterator
+WifiMacQueue::PeekByTid (uint8_t tid, ConstIterator pos) const
+{
+  NS_LOG_FUNCTION (this << +tid);
+  ConstIterator it = (pos != EMPTY ? pos : begin ());
+  while (it != end ())
+    {
+      // skip packets that stayed in the queue for too long. They will be
+      // actually removed from the queue by the next call to a non-const method
+      if (Simulator::Now () <= (*it)->GetTimeStamp () + m_maxDelay)
+        {
+          if ((*it)->GetHeader ().IsQosData () && (*it)->GetHeader ().GetQosTid () == tid)
+            {
+              return it;
+            }
+        }
+      else
+        {
+          // signal the presence of expired packets
+          m_expiredPacketsPresent = true;
+        }
+      it++;
+    }
+  NS_LOG_DEBUG ("The queue is empty");
+  return end ();
+}
+
+WifiMacQueue::ConstIterator
+WifiMacQueue::PeekByTidAndAddress (uint8_t tid, Mac48Address dest, ConstIterator pos) const
+{
+  NS_LOG_FUNCTION (this << +tid << dest);
+  ConstIterator it = (pos != EMPTY ? pos : begin ());
+  while (it != end ())
+    {
+      // skip packets that stayed in the queue for too long. They will be
+      // actually removed from the queue by the next call to a non-const method
+      if (Simulator::Now () <= (*it)->GetTimeStamp () + m_maxDelay)
         {
           if ((*it)->GetHeader ().IsQosData () && (*it)->GetDestinationAddress () == dest
               && (*it)->GetHeader ().GetQosTid () == tid)
             {
-              return DoPeek (it);
+              return it;
             }
-
-          it++;
         }
+      else
+        {
+          // signal the presence of expired packets
+          m_expiredPacketsPresent = true;
+        }
+      it++;
     }
   NS_LOG_DEBUG ("The queue is empty");
-  return 0;
+  return end ();
 }
 
-Ptr<const WifiMacQueueItem>
-WifiMacQueue::PeekFirstAvailable (const Ptr<QosBlockedDestinations> blockedPackets)
+WifiMacQueue::ConstIterator
+WifiMacQueue::PeekFirstAvailable (const Ptr<QosBlockedDestinations> blockedPackets, ConstIterator pos) const
 {
   NS_LOG_FUNCTION (this);
-  for (auto it = Head (); it != Tail (); )
+  ConstIterator it = (pos != EMPTY ? pos : begin ());
+  while (it != end ())
     {
-      if (!TtlExceeded (it))
+      // skip packets that stayed in the queue for too long. They will be
+      // actually removed from the queue by the next call to a non-const method
+      if (Simulator::Now () <= (*it)->GetTimeStamp () + m_maxDelay)
         {
-          if (!(*it)->GetHeader ().IsQosData ()
+          if (!(*it)->GetHeader ().IsQosData () || !blockedPackets
               || !blockedPackets->IsBlocked ((*it)->GetHeader ().GetAddr1 (), (*it)->GetHeader ().GetQosTid ()))
             {
-              return DoPeek (it);
+              return it;
             }
-
-          it++;
         }
+      else
+        {
+          // signal the presence of expired packets
+          m_expiredPacketsPresent = true;
+        }
+      it++;
     }
   NS_LOG_DEBUG ("The queue is empty");
-  return 0;
+  return end ();
 }
 
 Ptr<WifiMacQueueItem>
@@ -286,7 +413,7 @@ WifiMacQueue::Remove (void)
 {
   NS_LOG_FUNCTION (this);
 
-  for (auto it = Head (); it != Tail (); )
+  for (ConstIterator it = begin (); it != end (); )
     {
       if (!TtlExceeded (it))
         {
@@ -301,7 +428,7 @@ bool
 WifiMacQueue::Remove (Ptr<const Packet> packet)
 {
   NS_LOG_FUNCTION (this << packet);
-  for (auto it = Head (); it != Tail (); )
+  for (ConstIterator it = begin (); it != end (); )
     {
       if (!TtlExceeded (it))
         {
@@ -318,6 +445,40 @@ WifiMacQueue::Remove (Ptr<const Packet> packet)
   return false;
 }
 
+WifiMacQueue::ConstIterator
+WifiMacQueue::Remove (ConstIterator pos, bool removeExpired)
+{
+  NS_LOG_FUNCTION (this);
+
+  if (!removeExpired)
+    {
+      ConstIterator curr = pos++;
+      DoRemove (curr);
+      return pos;
+    }
+
+  // remove stale items queued before the given position
+  ConstIterator it = begin ();
+  while (it != end ())
+    {
+      if (it == pos)
+        {
+          // reset the flag signaling the presence of expired packets before returning
+          m_expiredPacketsPresent = false;
+
+          ConstIterator curr = pos++;
+          DoRemove (curr);
+          return pos;
+        }
+      else if (!TtlExceeded (it))
+        {
+          it++;
+        }
+    }
+  NS_LOG_DEBUG ("Invalid iterator");
+  return end ();
+}
+
 uint32_t
 WifiMacQueue::GetNPacketsByAddress (Mac48Address dest)
 {
@@ -325,7 +486,7 @@ WifiMacQueue::GetNPacketsByAddress (Mac48Address dest)
 
   uint32_t nPackets = 0;
 
-  for (auto it = Head (); it != Tail (); )
+  for (ConstIterator it = begin (); it != end (); )
     {
       if (!TtlExceeded (it))
         {
@@ -346,7 +507,7 @@ WifiMacQueue::GetNPacketsByTidAndAddress (uint8_t tid, Mac48Address dest)
 {
   NS_LOG_FUNCTION (this << dest);
   uint32_t nPackets = 0;
-  for (auto it = Head (); it != Tail (); )
+  for (ConstIterator it = begin (); it != end (); )
     {
       if (!TtlExceeded (it))
         {
@@ -367,7 +528,7 @@ bool
 WifiMacQueue::IsEmpty (void)
 {
   NS_LOG_FUNCTION (this);
-  for (auto it = Head (); it != Tail (); )
+  for (ConstIterator it = begin (); it != end (); )
     {
       if (!TtlExceeded (it))
         {
@@ -384,7 +545,7 @@ WifiMacQueue::GetNPackets (void)
 {
   NS_LOG_FUNCTION (this);
   // remove packets that stayed in the queue for too long
-  for (auto it = Head (); it != Tail (); )
+  for (ConstIterator it = begin (); it != end (); )
     {
       if (!TtlExceeded (it))
         {
@@ -399,7 +560,7 @@ WifiMacQueue::GetNBytes (void)
 {
   NS_LOG_FUNCTION (this);
   // remove packets that stayed in the queue for too long
-  for (auto it = Head (); it != Tail (); )
+  for (ConstIterator it = begin (); it != end (); )
     {
       if (!TtlExceeded (it))
         {
