@@ -25,11 +25,20 @@
 #define WIFI_MAC_QUEUE_H
 
 #include "wifi-mac-queue-item.h"
+#include "ns3/queue.h"
 
 namespace ns3 {
 
 class QosBlockedDestinations;
 
+// The following explicit template instantiation declaration prevents modules
+// including this header file from implicitly instantiating Queue<WifiMacQueueItem>.
+// This would cause python examples using wifi to crash at runtime with the
+// following error message: "Trying to allocate twice the same uid:
+// ns3::Queue<WifiMacQueueItem>"
+extern template class Queue<WifiMacQueueItem>;
+
+
 /**
  * \ingroup wifi
  *
@@ -63,6 +72,24 @@ public:
     DROP_OLDEST
   };
 
+  /// allow the usage of iterators and const iterators
+  using Queue<WifiMacQueueItem>::ConstIterator;
+  using Queue<WifiMacQueueItem>::Iterator;
+  using Queue<WifiMacQueueItem>::begin;
+  using Queue<WifiMacQueueItem>::end;
+
+  /**
+   * \brief Set the maximum size of this queue
+   *
+   * Trying to set a null size has no effect.
+   *
+   * \param size the maximum size
+   */
+  void SetMaxQueueSize (QueueSize size);
+  /**
+   * \return the maximum size of this queue
+   */
+  QueueSize GetMaxQueueSize (void) const;
   /**
    * Set the maximum delay before the packet is discarded.
    *
@@ -90,6 +117,14 @@ public:
    * \return true if success, false if the packet has been dropped
    */
   bool PushFront (Ptr<WifiMacQueueItem> item);
+  /**
+   * Enqueue the given Wifi MAC queue item before the given position.
+   *
+   * \param pos the position before which the item is to be inserted
+   * \param item the Wifi MAC queue item to be enqueued
+   * \return true if success, false if the packet has been dropped
+   */
+  bool Insert (ConstIterator pos, Ptr<WifiMacQueueItem> item);
   /**
    * Dequeue the packet in the front of the queue.
    *
@@ -97,8 +132,8 @@ public:
    */
   Ptr<WifiMacQueueItem> Dequeue (void);
   /**
-   * Search and return, if present in the queue, the first packet having the
-   * address indicated by <i>type</i> equal to <i>addr</i>.
+   * Search and return, if present in the queue, the first packet (either Data
+   * frame or QoS Data frame) having the receiver address equal to <i>addr</i>.
    * This method removes the packet from the queue.
    * It is typically used by ns3::Txop during the CF period.
    *
@@ -107,6 +142,16 @@ public:
    * \return the packet
    */
   Ptr<WifiMacQueueItem> DequeueByAddress (Mac48Address dest);
+  /**
+   * Search and return, if present in the queue, the first packet having the
+   * tid equal to <i>tid</i>.
+   * This method removes the packet from the queue.
+   *
+   * \param tid the given tid
+   *
+   * \return the packet
+   */
+  Ptr<WifiMacQueueItem> DequeueByTid (uint8_t tid);
   /**
    * Search and return, if present in the queue, the first packet having the
    * address indicated by <i>type</i> equal to <i>addr</i>, and tid
@@ -132,35 +177,72 @@ public:
    *
    * \return packet
    */
-  Ptr<WifiMacQueueItem> DequeueFirstAvailable (const Ptr<QosBlockedDestinations> blockedPackets);
+  Ptr<WifiMacQueueItem> DequeueFirstAvailable (const Ptr<QosBlockedDestinations> blockedPackets = nullptr);
+  /**
+   * Dequeue the item at position <i>pos</i> in the queue. Return a null
+   * pointer if the given iterator is invalid, the queue is empty or the
+   * lifetime of the item pointed to by the given iterator is expired.
+   *
+   * \param pos the position of the item to be dequeued
+   * \return the dequeued item, if any
+   */
+  Ptr<WifiMacQueueItem> Dequeue (WifiMacQueue::ConstIterator pos);
   /**
    * Peek the packet in the front of the queue. The packet is not removed.
    *
    * \return the packet
    */
   Ptr<const WifiMacQueueItem> Peek (void) const;
+  /**
+   * Search and return, if present in the queue, the first packet (either Data
+   * frame or QoS Data frame) having the receiver address equal to <i>addr</i>.
+   * If <i>pos</i> is a valid iterator, the search starts from the packet pointed
+   * to by the given iterator.
+   * This method does not remove the packet from the queue.
+   *
+   * \param dest the given destination
+   * \param pos the iterator pointing to the packet the search starts from
+   *
+   * \return an iterator pointing to the peeked packet
+   */
+  ConstIterator PeekByAddress (Mac48Address dest, ConstIterator pos = EMPTY) const;
   /**
    * Search and return, if present in the queue, the first packet having the
-   * address indicated by <i>type</i> equal to <i>addr</i>, and tid
-   * equal to <i>tid</i>. This method does not remove the packet from the queue.
-   * It is typically used by ns3::QosTxop in order to perform correct MSDU
-   * aggregation (A-MSDU).
+   * tid equal to <i>tid</i>. If <i>pos</i> is a valid iterator, the search starts
+   * from the packet pointed to by the given iterator.
+   * This method does not remove the packet from the queue.
+   *
+   * \param tid the given TID
+   * \param pos the iterator pointing to the packet the search starts from
+   *
+   * \return an iterator pointing to the peeked packet
+   */
+  ConstIterator PeekByTid (uint8_t tid, ConstIterator pos = EMPTY) const;
+  /**
+   * Search and return, if present in the queue, the first packet having the
+   * receiver address equal to <i>dest</i>, and tid equal to <i>tid</i>.
+   * If <i>pos</i> is a valid iterator, the search starts from the packet pointed
+   * to by the given iterator. This method does not remove the packet from the queue.
+   * It is typically used by ns3::QosTxop in order to perform correct MSDU aggregation
+   * (A-MSDU).
    *
    * \param tid the given TID
    * \param dest the given destination
+   * \param pos the iterator pointing to the packet the search starts from
    *
-   * \return packet
+   * \return an iterator pointing to the peeked packet
    */
-  Ptr<const WifiMacQueueItem> PeekByTidAndAddress (uint8_t tid,
-                                                   Mac48Address dest);
+  ConstIterator PeekByTidAndAddress (uint8_t tid, Mac48Address dest, ConstIterator pos = EMPTY) const;
   /**
    * Return first available packet for transmission. The packet is not removed from queue.
    *
    * \param blockedPackets
+   * \param pos the iterator pointing to the packet the search starts from
    *
-   * \return packet
+   * \return an iterator pointing to the peeked packet
    */
-  Ptr<const WifiMacQueueItem> PeekFirstAvailable (const Ptr<QosBlockedDestinations> blockedPackets);
+  ConstIterator PeekFirstAvailable (const Ptr<QosBlockedDestinations> blockedPackets = nullptr,
+                                    ConstIterator pos = EMPTY) const;
   /**
    * Remove the packet in the front of the queue.
    *
@@ -177,6 +259,17 @@ public:
    * \return true if the packet was removed, false otherwise
    */
   bool Remove (Ptr<const Packet> packet);
+  /**
+   * Remove the item at position <i>pos</i> in the queue and return an iterator
+   * pointing to the item following the removed one. If <i>removeExpired</i> is
+   * true, all the items in the queue from the head to the given position are
+   * removed if their lifetime expired.
+   *
+   * \param pos the position of the item to be removed
+   * \param removeExpired true to remove expired items
+   * \return an iterator pointing to the item following the removed one
+   */
+  ConstIterator Remove (ConstIterator pos, bool removeExpired = false);
   /**
    * Return the number of packets having destination address specified by
    * <i>dest</i>.
@@ -218,6 +311,8 @@ public:
    */
   uint32_t GetNBytes (void);
 
+  static const ConstIterator EMPTY;         //!< Invalid iterator to signal an empty queue
+
 private:
   /**
    * Remove the item pointed to by the iterator <i>it</i> if it has been in the
@@ -229,8 +324,13 @@ private:
    */
   bool TtlExceeded (ConstIterator &it);
 
+  QueueSize m_maxSize;                      //!< max queue size
   Time m_maxDelay;                          //!< Time to live for packets in the queue
   DropPolicy m_dropPolicy;                  //!< Drop behavior of queue
+  mutable bool m_expiredPacketsPresent;     //!> True if expired packets are in the queue
+
+  /// Traced callback: fired when a packet is dropped due to lifetime expiration
+  TracedCallback<Ptr<const WifiMacQueueItem> > m_traceExpired;
 
   NS_LOG_TEMPLATE_DECLARE;                  //!< redefinition of the log component
 };
