@@ -33,12 +33,12 @@ enum WifiPreamble
   WIFI_PREAMBLE_SHORT,
   WIFI_PREAMBLE_HT_MF,
   WIFI_PREAMBLE_HT_GF,
-  WIFI_PREAMBLE_VHT,
+  WIFI_PREAMBLE_VHT_SU,
+  WIFI_PREAMBLE_VHT_MU,
   WIFI_PREAMBLE_HE_SU,
   WIFI_PREAMBLE_HE_ER_SU,
   WIFI_PREAMBLE_HE_MU,
-  WIFI_PREAMBLE_HE_TB,
-  WIFI_PREAMBLE_NONE
+  WIFI_PREAMBLE_HE_TB
 };
 
 } //namespace ns3
