@@ -399,6 +399,11 @@ public:
 private:
   void DoDispose (void);
 
+  /**
+   * \returns draw of device, at given state.
+   */
+  double GetStateA (int state) const;
+
   /**
    * \returns Current draw of device, at current state.
    *
