@@ -23,65 +23,85 @@
 
 #include "ns3/traced-callback.h"
 #include "ns3/object.h"
-#include "ns3/nstime.h"
 #include "ns3/data-rate.h"
 #include "ns3/mac48-address.h"
 #include "wifi-mode.h"
-#include "wifi-preamble.h"
+#include "wifi-utils.h"
+#include "wifi-remote-station-info.h"
+#include "ht-capabilities.h"
+#include "vht-capabilities.h"
+#include "he-capabilities.h"
 
 namespace ns3 {
 
-struct WifiRemoteStation;
-struct WifiRemoteStationState;
-
 class WifiPhy;
 class WifiMac;
 class WifiMacHeader;
 class Packet;
-class HtCapabilities;
-class VhtCapabilities;
-class HeCapabilities;
 class WifiTxVector;
 
+struct WifiRemoteStationState;
+
 /**
- * \brief Tid independent remote station statistics
+ * \brief hold per-remote-station state.
  *
- * Structure is similar to struct sta_info in Linux kernel (see
- * net/mac80211/sta_info.h)
+ * The state in this class is used to keep track
+ * of association status if we are in an infrastructure
+ * network and to perform the selection of tx parameters
+ * on a per-packet basis.
+ *
+ * This class is typically subclassed and extended by
+ * rate control implementations
  */
-class WifiRemoteStationInfo
+struct WifiRemoteStation
+{
+  virtual ~WifiRemoteStation () {};
+  WifiRemoteStationState *m_state;  //!< Remote station state
+  uint32_t m_ssrc;                  //!< STA short retry count
+  uint32_t m_slrc;                  //!< STA long retry count
+  uint8_t m_tid;                    //!< traffic ID
+};
+
+/**
+ * A struct that holds information about each remote station.
+ */
+struct WifiRemoteStationState
 {
-public:
-  WifiRemoteStationInfo ();
   /**
-   * \brief Updates average frame error rate when data or RTS was transmitted successfully.
-   *
-   * \param retryCounter is slrc or ssrc value at the moment of success transmission.
+   * State of the station
    */
-  void NotifyTxSuccess (uint32_t retryCounter);
-  /// Updates average frame error rate when final data or RTS has failed.
-  void NotifyTxFailed ();
+  enum
+  {
+    BRAND_NEW,
+    DISASSOC,
+    WAIT_ASSOC_TX_OK,
+    GOT_ASSOC_TX_OK
+  } m_state;
+
   /**
-   * Return frame error rate (probability that frame is corrupted due to transmission error).
-   * \returns the frame error rate
+   * This member is the list of WifiMode objects that comprise the
+   * OperationalRateSet parameter for this remote station. This list
+   * is constructed through calls to
+   * WifiRemoteStationManager::AddSupportedMode(), and an API that
+   * allows external access to it is available through
+   * WifiRemoteStationManager::GetNSupported() and
+   * WifiRemoteStationManager::GetSupported().
    */
-  double GetFrameErrorRate () const;
-private:
-  /**
-   * \brief Calculate averaging coefficient for frame error rate. Depends on time of the last update.
-   *
-   * \attention Calling this method twice gives different results,
-   * because it resets time of last update.
-   *
-   * \return average coefficient for frame error rate
-   */
-  double CalculateAveragingCoefficient ();
-  /// averaging coefficient depends on the memory time
-  Time m_memoryTime;
-  /// when last update has occurred
-  Time m_lastUpdate;
-  /// moving percentage of failed frames
-  double m_failAvg;
+  WifiModeList m_operationalRateSet; //!< opertional rate set
+  WifiModeList m_operationalMcsSet; //!< operational MCS set
+  Mac48Address m_address;  //!< Mac48Address of the remote station
+  WifiRemoteStationInfo m_info; //!< remote station info
+  Ptr<const HtCapabilities> m_htCapabilities;  //!< remote station HT capabilities
+  Ptr<const VhtCapabilities> m_vhtCapabilities;  //!< remote station VHT capabilities
+  Ptr<const HeCapabilities> m_heCapabilities;  //!< remote station HE capabilities
+
+  uint16_t m_channelWidth;    //!< Channel width (in MHz) supported by the remote station
+  uint16_t m_guardInterval;   //!< HE Guard interval duration (in nanoseconds) supported by the remote station
+  uint8_t m_ness;             //!< Number of streams in beamforming of the remote station
+  bool m_aggregation;         //!< Flag if MPDU aggregation is used by the remote station
+  bool m_shortPreamble;       //!< Flag if short PLCP preamble is supported by the remote station
+  bool m_shortSlotTime;       //!< Flag if short ERP slot time is supported by the remote station
+  bool m_qosSupported;        //!< Flag if HT is supported by the station
 };
 
 /**
@@ -109,6 +129,15 @@ public:
     CTS_TO_SELF
   };
 
+  /**
+   * A vector of WifiRemoteStations
+   */
+  typedef std::vector <WifiRemoteStation *> Stations;
+  /**
+   * A vector of WifiRemoteStationStates
+   */
+  typedef std::vector <WifiRemoteStationState *> StationStates;
+
   /**
    * Set up PHY associated with this device since it is the object that
    * knows the full set of transmit rates that are supported.
@@ -191,53 +220,74 @@ public:
    */
   void AddStationHeCapabilities (Mac48Address from, HeCapabilities hecapabilities);
   /**
-   * Enable or disable HT capability support.
+   * Return the HT capabilities sent by the remote station.
    *
-   * \param enable enable or disable HT capability support
+   * \param from the address of the remote station
+   * \return the HT capabilities sent by the remote station
    */
-  virtual void SetHtSupported (bool enable);
+  Ptr<const HtCapabilities> GetStationHtCapabilities (Mac48Address from);
+  /**
+   * Return the VHT capabilities sent by the remote station.
+   *
+   * \param from the address of the remote station
+   * \return the VHT capabilities sent by the remote station
+   */
+  Ptr<const VhtCapabilities> GetStationVhtCapabilities (Mac48Address from);
+  /**
+   * Return the HE capabilities sent by the remote station.
+   *
+   * \param from the address of the remote station
+   * \return the HE capabilities sent by the remote station
+   */
+  Ptr<const HeCapabilities> GetStationHeCapabilities (Mac48Address from);
   /**
    * Return whether the device has HT capability support enabled.
    *
    * \return true if HT capability support is enabled, false otherwise
    */
-  bool HasHtSupported (void) const;
-  /**
-   * Enable or disable VHT capability support.
-   *
-   * \param enable enable or disable VHT capability support
-   */
-  virtual void SetVhtSupported (bool enable);
+  bool GetHtSupported (void) const;
   /**
    * Return whether the device has VHT capability support enabled.
    *
    * \return true if VHT capability support is enabled, false otherwise
    */
-  bool HasVhtSupported (void) const;
-  /**
-   * Enable or disable HE capability support.
-   *
-   * \param enable enable or disable HE capability support
-   */
-  virtual void SetHeSupported (bool enable);
+  bool GetVhtSupported (void) const;
   /**
    * Return whether the device has HE capability support enabled.
    *
    * \return true if HE capability support is enabled, false otherwise
    */
-  bool HasHeSupported (void) const;
+  bool GetHeSupported (void) const;
   /**
    * Enable or disable PCF capability support.
    *
    * \param enable enable or disable PCF capability support
    */
-  virtual void SetPcfSupported (bool enable);
+  void SetPcfSupported (bool enable);
   /**
    * Return whether the device has PCF capability support enabled.
    *
    * \return true if PCF capability support is enabled, false otherwise
    */
-  bool HasPcfSupported (void) const;
+  bool GetPcfSupported (void) const;
+  /**
+   * Return whether the device has HT Greenfield support enabled.
+   *
+   * \return true if HT Grenfield support is enabled, false otherwise
+   */
+  bool GetGreenfieldSupported (void) const;
+  /**
+   * Return whether the device has SGI support enabled.
+   *
+   * \return true if SGI support is enabled, false otherwise
+   */
+  bool GetShortGuardIntervalSupported (void) const;
+  /**
+   * Return the supported HE guard interval duration (in nanoseconds).
+   *
+   * \return the supported HE guard interval duration (in nanoseconds)
+   */
+  uint16_t GetGuardInterval (void) const;
   /**
    * Enable or disable protection for non-ERP stations.
    *
@@ -450,7 +500,7 @@ public:
    * \return true if the station supports HT/VHT short guard interval,
    *         false otherwise
    */
-  bool GetShortGuardInterval (Mac48Address address) const;
+  bool GetShortGuardIntervalSupported (Mac48Address address) const;
   /**
    * Return the number of spatial streams supported by the station.
    *
@@ -485,6 +535,15 @@ public:
    *         false otherwise
    */
   bool GetVhtSupported (Mac48Address address) const;
+  /**
+   * Return whether the station supports HE or not.
+   *
+   * \param address the address of the station
+   *
+   * \return true if HE is supported by the station,
+   *         false otherwise
+   */
+  bool GetHeSupported (Mac48Address address) const;
 
   /**
    * Return a mode for non-unicast packets.
@@ -805,27 +864,6 @@ public:
   bool IsLastFragment (Mac48Address address, const WifiMacHeader *header,
                        Ptr<const Packet> packet, uint32_t fragmentNumber);
 
-  /**
-   * \param address remote address
-   * \param rtsMode the transmission mode used to send an RTS we just received
-   *
-   * \return the transmission mode to use for the CTS to complete the RTS/CTS handshake.
-   */
-  WifiTxVector GetCtsTxVector (Mac48Address address, WifiMode rtsMode);
-  /**
-   * \param address
-   * \param dataMode the transmission mode used to send an ACK we just received
-   *
-   * \return the transmission mode to use for the ACK to complete the data/ACK handshake.
-   */
-  WifiTxVector GetAckTxVector (Mac48Address address, WifiMode dataMode);
-  /**
-   * \param address
-   * \param dataMode the transmission mode used to send an ACK we just received
-   *
-   * \return the transmission mode to use for the ACK to complete the data/ACK handshake.
-   */
-  WifiTxVector GetBlockAckTxVector (Mac48Address address, WifiMode dataMode);
   /**
    * \return the default transmission power
    */
@@ -845,11 +883,19 @@ public:
   /**
    * \return the number of antennas supported by the phy layer
    */
-  uint8_t GetNumberOfAntennas (void);
+  uint8_t GetNumberOfAntennas (void) const;
   /**
    * \return the maximum number of spatial streams supported by the phy layer
    */
-  uint8_t GetMaxNumberOfTransmitStreams (void);
+  uint8_t GetMaxNumberOfTransmitStreams (void) const;
+  /**
+   * \returns whether HT greenfield should be used for a given destination address.
+   *
+   * \param dest the destination address
+   *
+   * \return whether HT greenfield should be used for a given destination address
+   */
+  bool UseGreenfieldForDestination (Mac48Address dest) const;
 
   /**
    * TracedCallback signature for power change events.
@@ -984,7 +1030,7 @@ protected:
    * \return true if the station supports HT/VHT short guard interval,
    *         false otherwise
    */
-  bool GetShortGuardInterval (const WifiRemoteStation *station) const;
+  bool GetShortGuardIntervalSupported (const WifiRemoteStation *station) const;
   /**
    * Return the HE guard interval duration supported by the station.
    *
@@ -1028,25 +1074,6 @@ protected:
    * \return the number of Ness the station has
    */
   uint8_t GetNess (const WifiRemoteStation *station) const;
-  /**
-   * Return the preamble to be used for the transmission.
-   *
-   * \param mode the mode selected for the transmission
-   * \param dest address of the recipient
-   *
-   * \return the preamble to be used for the transmission
-   */
-  WifiPreamble GetPreambleForTransmission (WifiMode mode, Mac48Address dest);
-  /**
-   * Return the channel width that corresponds to the selected mode (instead of
-   * letting the PHY's default channel width). This is especially useful when using
-   * non-HT modes with HT/VHT/HE capable stations (with default width above 20 MHz).
-   *
-   * \param mode selected WifiMode
-   * \param maxSupportedChannelWidth maximum channel width supported by the PHY layer
-   * \return channel width adapted to the selected mode
-   */
-  static uint16_t GetChannelWidthForTransmission (WifiMode mode, uint16_t maxSupportedChannelWidth);
 
   /**
    * Return the WifiPhy.
@@ -1131,112 +1158,6 @@ private:
    *       to decide which transmission mode to use for the rts.
    */
   virtual WifiTxVector DoGetRtsTxVector (WifiRemoteStation *station) = 0;
-  /**
-   * \param address the address of the recipient of the CTS
-   * \param ctsMode the mode to be used for the CTS
-   *
-   * \return the power level to be used to send the CTS
-   */
-  virtual uint8_t DoGetCtsTxPowerLevel (Mac48Address address, WifiMode ctsMode);
-  /**
-   * \param address the address of the recipient of the ACK
-   * \param ackMode the mode to be used for the ACK
-   *
-   * \return the power level to be used to send the ACK
-   */
-  virtual uint8_t DoGetAckTxPowerLevel (Mac48Address address, WifiMode ackMode);
-  /**
-   * \param address the address of the recipient of the Block ACK
-   * \param blockAckMode the mode to be used for the Block ACK
-   *
-   * \return the power level to be used to send the Block ACK
-   */
-  virtual uint8_t DoGetBlockAckTxPowerLevel (Mac48Address address, WifiMode blockAckMode);
-
-  /**
-   * \param address the address of the recipient
-   * \param ctsMode the mode to be used
-   *
-   * \return the CTS transmit channel width
-   */
-  virtual uint16_t DoGetCtsTxChannelWidth (Mac48Address address, WifiMode ctsMode);
-  /**
-   * \param address the address of the recipient
-   * \param ctsMode the mode to be used
-   *
-   * \return the CTS transmit guard interval
-   */
-  virtual uint16_t DoGetCtsTxGuardInterval (Mac48Address address, WifiMode ctsMode);
-  /**
-   * \param address the address of the recipient
-   * \param ctsMode the mode to be used
-   *
-   * \return the CTS transmit NSS
-   */
-  virtual uint8_t DoGetCtsTxNss (Mac48Address address, WifiMode ctsMode);
-  /**
-   * \param address the address of the recipient
-   * \param ctsMode the mode to be used
-   *
-   * \return the CTS transmit NESS
-   */
-  virtual uint8_t DoGetCtsTxNess (Mac48Address address, WifiMode ctsMode);
-  /**
-   * \param address the address of the recipient
-   * \param ctsMode the mode to be used
-   *
-   * \return the ack transmit channel width
-   */
-  virtual uint16_t DoGetAckTxChannelWidth (Mac48Address address, WifiMode ctsMode);
-  /**
-   * \param address the address of the recipient
-   * \param ackMode the mode to be used
-   *
-   * \return the ack transmit guard interval
-   */
-  virtual uint16_t DoGetAckTxGuardInterval (Mac48Address address, WifiMode ackMode);
-  /**
-   * \param address the address of the recipient
-   * \param ackMode the mode to be used
-   *
-   * \return the ack transmit NSS
-   */
-  virtual uint8_t DoGetAckTxNss (Mac48Address address, WifiMode ackMode);
-  /**
-   * \param address the address of the recipient
-   * \param ackMode the mode to be used
-   *
-   * \return the ack transmit NESS
-   */
-  virtual uint8_t DoGetAckTxNess (Mac48Address address, WifiMode ackMode);
-  /**
-   * \param address the address of the recipient
-   * \param ctsMode the mode to be used
-   *
-   * \return the block ack transmit channel width
-   */
-  virtual uint16_t DoGetBlockAckTxChannelWidth (Mac48Address address, WifiMode ctsMode);
-  /**
-   * \param address the address of the recipient
-   * \param blockAckMode the mode to be used
-   *
-   * \return the block ack transmit guard interval
-   */
-  virtual uint16_t DoGetBlockAckTxGuardInterval (Mac48Address address, WifiMode blockAckMode);
-  /**
-   * \param address the address of the recipient
-   * \param blockAckMode the mode to be used
-   *
-   * \return the block ack transmit NSS
-   */
-  virtual uint8_t DoGetBlockAckTxNss (Mac48Address address, WifiMode blockAckMode);
-  /**
-   * \param address the address of the recipient
-   * \param blockAckMode the mode to be used
-   *
-   * \return the block ack transmit NESS
-   */
-  virtual uint8_t DoGetBlockAckTxNess (Mac48Address address, WifiMode blockAckMode);
 
   /**
    * This method is a pure virtual method that must be implemented by the sub-class.
@@ -1341,28 +1262,6 @@ private:
    */
   WifiRemoteStation* Lookup (Mac48Address address, const WifiMacHeader *header) const;
 
-  /**
-   * Return whether the modulation class of the selected mode for the
-   * control answer frame is allowed.
-   *
-   * \param modClassReq modulation class of the request frame
-   * \param modClassAnswer modulation class of the answer frame
-   *
-   * \return true if the modulation class of the selected mode for the
-   * control answer frame is allowed, false otherwise
-   */
-  bool IsAllowedControlAnswerModulationClass (WifiModulationClass modClassReq, WifiModulationClass modClassAnswer) const;
-
-  /**
-   * Get control answer mode function.
-   *
-   * \param address the address of the station
-   * \param reqMode request mode
-   *
-   * \return control answer mode
-   */
-  WifiMode GetControlAnswerMode (Mac48Address address, WifiMode reqMode);
-
   /**
    * Actually sets the fragmentation threshold, it also checks the validity of
    * the given threshold.
@@ -1386,15 +1285,6 @@ private:
    */
   uint32_t GetNFragments (const WifiMacHeader *header, Ptr<const Packet> packet);
 
-  /**
-   * A vector of WifiRemoteStations
-   */
-  typedef std::vector <WifiRemoteStation *> Stations;
-  /**
-   * A vector of WifiRemoteStationStates
-   */
-  typedef std::vector <WifiRemoteStationState *> StationStates;
-
   /**
    * This is a pointer to the WifiPhy associated with this
    * WifiRemoteStationManager that is set on call to
@@ -1430,9 +1320,6 @@ private:
   WifiMode m_defaultTxMode; //!< The default transmission mode
   WifiMode m_defaultTxMcs;   //!< The default transmission modulation-coding scheme (MCS)
 
-  bool m_htSupported;  //!< Flag if HT capability is supported
-  bool m_vhtSupported; //!< Flag if VHT capability is supported
-  bool m_heSupported;  //!< Flag if HE capability is supported
   bool m_pcfSupported; //!< Flag if PCF capability is supported
   uint32_t m_maxSsrc;  //!< Maximum STA short retry count (SSRC)
   uint32_t m_maxSlrc;  //!< Maximum STA long retry count (SLRC)
@@ -1470,73 +1357,6 @@ private:
   TracedCallback<Mac48Address> m_macTxFinalDataFailed;
 };
 
-/**
- * A struct that holds information about each remote station.
- */
-struct WifiRemoteStationState
-{
-  /**
-   * State of the station
-   */
-  enum
-  {
-    BRAND_NEW,
-    DISASSOC,
-    WAIT_ASSOC_TX_OK,
-    GOT_ASSOC_TX_OK
-  } m_state;
-
-  /**
-   * This member is the list of WifiMode objects that comprise the
-   * OperationalRateSet parameter for this remote station. This list
-   * is constructed through calls to
-   * WifiRemoteStationManager::AddSupportedMode(), and an API that
-   * allows external access to it is available through
-   * WifiRemoteStationManager::GetNSupported() and
-   * WifiRemoteStationManager::GetSupported().
-   */
-  WifiModeList m_operationalRateSet; //!< opertional rate set
-  WifiModeList m_operationalMcsSet; //!< operational MCS set
-  Mac48Address m_address;  //!< Mac48Address of the remote station
-  WifiRemoteStationInfo m_info; //!< remote station info
-
-  uint16_t m_channelWidth;    //!< Channel width (in MHz) supported by the remote station
-  bool m_shortGuardInterval;  //!< Flag if HT/VHT short guard interval is supported by the remote station
-  uint16_t m_guardInterval;   //!< HE Guard interval duration (in nanoseconds) supported by the remote station
-  uint8_t m_streams;          //!< Number of supported streams by the remote station
-  uint8_t m_ness;             //!< Number of streams in beamforming of the remote station
-  bool m_stbc;                //!< Flag if STBC is supported by the remote station
-  bool m_ldpc;                //!< Flag if LDPC is supported by the remote station
-  bool m_aggregation;         //!< Flag if MPDU aggregation is used by the remote station
-  bool m_greenfield;          //!< Flag if greenfield is supported by the remote station
-  bool m_shortPreamble;       //!< Flag if short PLCP preamble is supported by the remote station
-  bool m_shortSlotTime;       //!< Flag if short ERP slot time is supported by the remote station
-  bool m_qosSupported;        //!< Flag if HT is supported by the station
-  bool m_htSupported;         //!< Flag if HT is supported by the station
-  bool m_vhtSupported;        //!< Flag if VHT is supported by the station
-  bool m_heSupported;         //!< Flag if HE is supported by the station
-};
-
-/**
- * \brief hold per-remote-station state.
- *
- * The state in this class is used to keep track
- * of association status if we are in an infrastructure
- * network and to perform the selection of tx parameters
- * on a per-packet basis.
- *
- * This class is typically subclassed and extended by
- * rate control implementations
- */
-struct WifiRemoteStation
-{
-  virtual ~WifiRemoteStation ();
-  WifiRemoteStationState *m_state;  //!< Remote station state
-  uint32_t m_ssrc;                  //!< STA short retry count
-  uint32_t m_slrc;                  //!< STA long retry count
-  uint8_t m_tid;                    //!< traffic ID
-};
-
 } //namespace ns3
 
 #endif /* WIFI_REMOTE_STATION_MANAGER_H */
