@@ -19,8 +19,8 @@
  * Modified by Marco Miozzo <mmiozzo@cttc.es> (add data and ctrl diversity)
  */
 
-#include <ns3/log.h>
-#include <ns3/packet.h>
+#include "ns3/log.h"
+#include "ns3/packet.h"
 #include "wifi-spectrum-signal-parameters.h"
 
 namespace ns3 {
