@@ -24,7 +24,7 @@
 namespace ns3 {
 
 WifiTxVector::WifiTxVector ()
-  : m_preamble (WIFI_PREAMBLE_NONE),
+  : m_preamble (WIFI_PREAMBLE_LONG),
     m_channelWidth (20),
     m_guardInterval (800),
     m_nTx (1),
@@ -32,8 +32,8 @@ WifiTxVector::WifiTxVector ()
     m_ness (0),
     m_aggregation (false),
     m_stbc (false),
-    m_modeInitialized (false),
-    m_txPowerLevelInitialized (false)
+    m_bssColor (0),
+    m_modeInitialized (false)
 {
 }
 
@@ -46,7 +46,8 @@ WifiTxVector::WifiTxVector (WifiMode mode,
                             uint8_t ness,
                             uint16_t channelWidth,
                             bool aggregation,
-                            bool stbc)
+                            bool stbc,
+                            uint8_t bssColor)
   : m_mode (mode),
     m_txPowerLevel (powerLevel),
     m_preamble (preamble),
@@ -57,11 +58,17 @@ WifiTxVector::WifiTxVector (WifiMode mode,
     m_ness (ness),
     m_aggregation (aggregation),
     m_stbc (stbc),
-    m_modeInitialized (true),
-    m_txPowerLevelInitialized (true)
+    m_bssColor (bssColor),
+    m_modeInitialized (true)
 {
 }
 
+bool
+WifiTxVector::GetModeInitialized (void) const
+{
+  return m_modeInitialized;
+}
+
 WifiMode
 WifiTxVector::GetMode (void) const
 {
@@ -75,10 +82,6 @@ WifiTxVector::GetMode (void) const
 uint8_t
 WifiTxVector::GetTxPowerLevel (void) const
 {
-  if (!m_txPowerLevelInitialized)
-    {
-      NS_FATAL_ERROR ("WifiTxVector txPowerLevel must be set before using");
-    }
   return m_txPowerLevel;
 }
 
@@ -141,7 +144,6 @@ void
 WifiTxVector::SetTxPowerLevel (uint8_t powerlevel)
 {
   m_txPowerLevel = powerlevel;
-  m_txPowerLevelInitialized = true;
 }
 
 void
@@ -192,6 +194,18 @@ WifiTxVector::SetStbc (bool stbc)
   m_stbc = stbc;
 }
 
+void
+WifiTxVector::SetBssColor (uint8_t color)
+{
+  m_bssColor = color;
+}
+
+uint8_t
+WifiTxVector::GetBssColor (void) const
+{
+  return m_bssColor;
+}
+
 bool
 WifiTxVector::IsValid (void) const
 {
