@@ -34,6 +34,7 @@
 #include "ns3/pointer.h"
 #include "ns3/rng-seed-manager.h"
 #include "ns3/config.h"
+#include "ns3/error-model.h"
 #include "ns3/packet-socket-server.h"
 #include "ns3/packet-socket-client.h"
 #include "ns3/packet-socket-helper.h"
@@ -43,6 +44,8 @@
 #include "ns3/wifi-phy-tag.h"
 #include "ns3/yans-wifi-phy.h"
 #include "ns3/mgt-headers.h"
+#include "ns3/ht-configuration.h"
+#include "ns3/wifi-phy-header.h"
 
 using namespace ns3;
 
@@ -131,6 +134,7 @@ WifiTest::CreateOne (Vector pos, Ptr<YansWifiChannel> channel)
   Ptr<WifiNetDevice> dev = CreateObject<WifiNetDevice> ();
 
   Ptr<WifiMac> mac = m_mac.Create<WifiMac> ();
+  mac->SetDevice (dev);
   mac->ConfigureStandard (WIFI_PHY_STANDARD_80211a);
   Ptr<ConstantPositionMobilityModel> mobility = CreateObject<ConstantPositionMobilityModel> ();
   Ptr<YansWifiPhy> phy = CreateObject<YansWifiPhy> ();
@@ -280,7 +284,7 @@ InterferenceHelperSequenceTest::InterferenceHelperSequenceTest ()
 void
 InterferenceHelperSequenceTest::SendOnePacket (Ptr<WifiNetDevice> dev)
 {
-  Ptr<Packet> p = Create<Packet> (9999);
+  Ptr<Packet> p = Create<Packet> (1000);
   dev->Send (p, dev->GetBroadcast (), 1);
 }
 
@@ -298,6 +302,7 @@ InterferenceHelperSequenceTest::CreateOne (Vector pos, Ptr<YansWifiChannel> chan
   Ptr<WifiNetDevice> dev = CreateObject<WifiNetDevice> ();
 
   Ptr<WifiMac> mac = m_mac.Create<WifiMac> ();
+  mac->SetDevice (dev);
   mac->ConfigureStandard (WIFI_PHY_STANDARD_80211a);
   Ptr<ConstantPositionMobilityModel> mobility = CreateObject<ConstantPositionMobilityModel> ();
   Ptr<YansWifiPhy> phy = CreateObject<YansWifiPhy> ();
@@ -440,8 +445,9 @@ private:
   /**
    * Notify Phy transmit begin
    * \param p the packet
+   * \param txPowerW the tx power
    */
-  void NotifyPhyTxBegin (Ptr<const Packet> p);
+  void NotifyPhyTxBegin (Ptr<const Packet> p, double txPowerW);
 };
 
 DcfImmediateAccessBroadcastTestCase::DcfImmediateAccessBroadcastTestCase ()
@@ -450,7 +456,7 @@ DcfImmediateAccessBroadcastTestCase::DcfImmediateAccessBroadcastTestCase ()
 }
 
 void
-DcfImmediateAccessBroadcastTestCase::NotifyPhyTxBegin (Ptr<const Packet> p)
+DcfImmediateAccessBroadcastTestCase::NotifyPhyTxBegin (Ptr<const Packet> p, double txPowerW)
 {
   if (m_numSentPackets == 0)
     {
@@ -492,6 +498,7 @@ DcfImmediateAccessBroadcastTestCase::DoRun (void)
   Ptr<Node> txNode = CreateObject<Node> ();
   Ptr<WifiNetDevice> txDev = CreateObject<WifiNetDevice> ();
   Ptr<WifiMac> txMac = m_mac.Create<WifiMac> ();
+  txMac->SetDevice (txDev);
   txMac->ConfigureStandard (WIFI_PHY_STANDARD_80211a);
   //Fix the stream assignment to the Dcf Txop objects (backoffs)
   //The below stream assignment will result in the Txop object
@@ -601,8 +608,6 @@ Bug730TestCase::DoRun (void)
 {
   m_received = 0;
 
-  Config::SetDefault ("ns3::WifiRemoteStationManager::FragmentationThreshold", StringValue ("2304"));
-
   NodeContainer wifiStaNode;
   wifiStaNode.Create (1);
 
@@ -685,6 +690,169 @@ Bug730TestCase::DoRun (void)
   NS_TEST_ASSERT_MSG_EQ (result, true, "packet reception unexpectedly stopped after adapting fragmentation threshold!");
 }
 
+//-----------------------------------------------------------------------------
+/**
+ * Make sure that fragmentation works with QoS stations.
+ *
+ * The scenario considers a TCP transmission between an 802.11n station and an 802.11n
+ * access point.
+ */
+
+class QosFragmentationTestCase : public TestCase
+{
+public:
+  QosFragmentationTestCase ();
+  virtual ~QosFragmentationTestCase ();
+
+  virtual void DoRun (void);
+
+
+private:
+  uint32_t m_received; ///< received packets
+  uint32_t m_fragments; ///< transmitted fragments
+
+  /**
+   * Receive function
+   * \param context the context
+   * \param p the packet
+   * \param adr the address
+   */
+  void Receive (std::string context, Ptr<const Packet> p, const Address &adr);
+
+  /**
+   * Callback invoked when PHY transmits a packet
+   * \param context the context
+   * \param p the packet
+   * \param power the tx power
+   */
+  void Transmit (std::string context, Ptr<const Packet> p, double power);
+};
+
+QosFragmentationTestCase::QosFragmentationTestCase ()
+  : TestCase ("Test case for fragmentation with QoS stations"),
+    m_received (0),
+    m_fragments (0)
+{
+}
+
+QosFragmentationTestCase::~QosFragmentationTestCase ()
+{
+}
+
+void
+QosFragmentationTestCase::Receive (std::string context, Ptr<const Packet> p, const Address &adr)
+{
+  if (p->GetSize () == 1400)
+    {
+      m_received++;
+    }
+}
+
+void
+QosFragmentationTestCase::Transmit (std::string context, Ptr<const Packet> p, double power)
+{
+  WifiMacHeader hdr;
+  p->PeekHeader (hdr);
+  if (hdr.IsQosData ())
+    {
+      NS_TEST_EXPECT_MSG_LT_OR_EQ (p->GetSize (), 400, "Unexpected fragment size");
+      m_fragments++;
+    }
+}
+
+void
+QosFragmentationTestCase::DoRun (void)
+{
+  NodeContainer wifiStaNode;
+  wifiStaNode.Create (1);
+
+  NodeContainer wifiApNode;
+  wifiApNode.Create (1);
+
+  YansWifiChannelHelper channel = YansWifiChannelHelper::Default ();
+  YansWifiPhyHelper phy = YansWifiPhyHelper::Default ();
+  phy.SetChannel (channel.Create ());
+
+  WifiHelper wifi;
+  wifi.SetStandard (WIFI_PHY_STANDARD_80211n_5GHZ);
+  wifi.SetRemoteStationManager ("ns3::ConstantRateWifiManager",
+                                "DataMode", StringValue ("HtMcs7"));
+
+  WifiMacHelper mac;
+  Ssid ssid = Ssid ("ns-3-ssid");
+  mac.SetType ("ns3::StaWifiMac",
+               "Ssid", SsidValue (ssid),
+               "ActiveProbing", BooleanValue (false));
+
+  NetDeviceContainer staDevices;
+  staDevices = wifi.Install (phy, mac, wifiStaNode);
+
+  mac.SetType ("ns3::ApWifiMac",
+               "Ssid", SsidValue (ssid),
+               "BeaconGeneration", BooleanValue (true));
+
+  NetDeviceContainer apDevices;
+  apDevices = wifi.Install (phy, mac, wifiApNode);
+
+  MobilityHelper mobility;
+  Ptr<ListPositionAllocator> positionAlloc = CreateObject<ListPositionAllocator> ();
+
+  positionAlloc->Add (Vector (0.0, 0.0, 0.0));
+  positionAlloc->Add (Vector (1.0, 0.0, 0.0));
+  mobility.SetPositionAllocator (positionAlloc);
+
+  mobility.SetMobilityModel ("ns3::ConstantPositionMobilityModel");
+  mobility.Install (wifiApNode);
+  mobility.Install (wifiStaNode);
+
+  Ptr<WifiNetDevice> ap_device = DynamicCast<WifiNetDevice> (apDevices.Get (0));
+  Ptr<WifiNetDevice> sta_device = DynamicCast<WifiNetDevice> (staDevices.Get (0));
+
+  // set the TXOP limit on BE AC
+  Ptr<RegularWifiMac> sta_mac = DynamicCast<RegularWifiMac> (sta_device->GetMac ());
+  NS_ASSERT (sta_mac);
+  PointerValue ptr;
+  sta_mac->GetAttribute ("BE_Txop", ptr);
+  ptr.Get<QosTxop> ()->SetTxopLimit (MicroSeconds (3008));
+
+  PacketSocketAddress socket;
+  socket.SetSingleDevice (sta_device->GetIfIndex ());
+  socket.SetPhysicalAddress (ap_device->GetAddress ());
+  socket.SetProtocol (1);
+
+  // give packet socket powers to nodes.
+  PacketSocketHelper packetSocket;
+  packetSocket.Install (wifiStaNode);
+  packetSocket.Install (wifiApNode);
+
+  Ptr<PacketSocketClient> client = CreateObject<PacketSocketClient> ();
+  client->SetAttribute ("PacketSize", UintegerValue (1400));
+  client->SetAttribute ("MaxPackets", UintegerValue (1));
+  client->SetRemote (socket);
+  wifiStaNode.Get (0)->AddApplication (client);
+  client->SetStartTime (Seconds (1));
+  client->SetStopTime (Seconds (3.0));
+
+  Ptr<PacketSocketServer> server = CreateObject<PacketSocketServer> ();
+  server->SetLocal (socket);
+  wifiApNode.Get (0)->AddApplication (server);
+  server->SetStartTime (Seconds (0.0));
+  server->SetStopTime (Seconds (4.0));
+
+  Config::Connect ("/NodeList/*/ApplicationList/0/$ns3::PacketSocketServer/Rx", MakeCallback (&QosFragmentationTestCase::Receive, this));
+
+  Config::Set ("/NodeList/0/DeviceList/0/RemoteStationManager/FragmentationThreshold", StringValue ("400"));
+  Config::Connect ("/NodeList/0/DeviceList/0/Phy/PhyTxBegin", MakeCallback (&QosFragmentationTestCase::Transmit, this));
+
+  Simulator::Stop (Seconds (5));
+  Simulator::Run ();
+
+  Simulator::Destroy ();
+
+  NS_TEST_ASSERT_MSG_EQ (m_received, 1, "Unexpected number of received packets");
+  NS_TEST_ASSERT_MSG_EQ (m_fragments, 4, "Unexpected number of transmitted fragments");
+}
+
 /**
  * \ingroup wifi-test
  * \ingroup tests
@@ -895,7 +1063,6 @@ SetChannelFrequencyTest::DoRun ()
     NS_TEST_ASSERT_MSG_EQ (phySta->GetChannelWidth (), 40, "802.11 5GHz configuration");
     NS_TEST_ASSERT_MSG_EQ (phySta->GetFrequency (), 5220, "802.11 5GHz configuration");
   }
-  // modify cases 13 and 14 to avoid Config::SetDefault ()
   {
     // case 13
     WifiHelper wifi;
@@ -1023,7 +1190,6 @@ SetChannelFrequencyTest::DoRun ()
   }
 
   Simulator::Destroy ();
-
 }
 
 //-----------------------------------------------------------------------------
@@ -1170,14 +1336,14 @@ Bug2222TestCase::DoRun (void)
  * to ensure that only 2 {starting frequency, channelWidth, Number of subbands
  * in SpectrumModel, modulation type} tuples are used.
  *
- * See \bugid{2483}
+ * See \bugid{2843}
  */
 
-class Bug2483TestCase : public TestCase
+class Bug2843TestCase : public TestCase
 {
 public:
-  Bug2483TestCase ();
-  virtual ~Bug2483TestCase ();
+  Bug2843TestCase ();
+  virtual ~Bug2843TestCase ();
   virtual void DoRun (void);
 
 private:
@@ -1201,19 +1367,22 @@ private:
    * \param destination address of the destination device
    */
   void SendPacketBurst (uint8_t numPackets, Ptr<NetDevice> sourceDevice, Address& destination) const;
+
+  uint16_t m_channelWidth;
 };
 
-Bug2483TestCase::Bug2483TestCase ()
-  : TestCase ("Test case for Bug 2483")
+Bug2843TestCase::Bug2843TestCase ()
+  : TestCase ("Test case for Bug 2843"),
+    m_channelWidth (20)
 {
 }
 
-Bug2483TestCase::~Bug2483TestCase ()
+Bug2843TestCase::~Bug2843TestCase ()
 {
 }
 
 void
-Bug2483TestCase::StoreDistinctTuple (std::string context,  Ptr<SpectrumSignalParameters> txParams)
+Bug2843TestCase::StoreDistinctTuple (std::string context,  Ptr<SpectrumSignalParameters> txParams)
 {
   // Extract starting frequency and number of subbands
   Ptr<const SpectrumModel> c = txParams->psd->GetSpectrumModel ();
@@ -1229,13 +1398,24 @@ Bug2483TestCase::StoreDistinctTuple (std::string context,  Ptr<SpectrumSignalPar
       NS_FATAL_ERROR ("Received Wi-Fi Signal with no WifiPhyTag");
       return;
     }
-  WifiTxVector txVector = tag.GetWifiTxVector ();
-  uint16_t channelWidth = txVector.GetChannelWidth ();
-  WifiModulationClass modulationClass = txVector.GetMode ().GetModulationClass ();
+
+  WifiModulationClass modulationClass = tag.GetModulation ();
+  WifiPreamble preamble = tag.GetPreambleType ();
+  if ((modulationClass != WIFI_MOD_CLASS_HT) || (preamble != WIFI_PREAMBLE_HT_GF))
+    {
+      LSigHeader sig;
+      packet->RemoveHeader (sig);
+      m_channelWidth = 20;
+    }
+  if (modulationClass == WIFI_MOD_CLASS_VHT)
+    {
+      VhtSigHeader vhtSig;
+      packet->RemoveHeader (vhtSig);
+      m_channelWidth = vhtSig.GetChannelWidth ();
+    }
 
   // Build a tuple and check if seen before (if so store it)
-  FreqWidthSubbandModulationTuple tupleForCurrentTx = std::make_tuple (startingFreq, channelWidth,
-                                                                       numBands, modulationClass);
+  FreqWidthSubbandModulationTuple tupleForCurrentTx = std::make_tuple (startingFreq, m_channelWidth, numBands, modulationClass);
   bool found = false;
   for (std::vector<FreqWidthSubbandModulationTuple>::const_iterator it = m_distinctTuples.begin (); it != m_distinctTuples.end (); it++)
     {
@@ -1251,7 +1431,7 @@ Bug2483TestCase::StoreDistinctTuple (std::string context,  Ptr<SpectrumSignalPar
 }
 
 void
-Bug2483TestCase::SendPacketBurst (uint8_t numPackets, Ptr<NetDevice> sourceDevice,
+Bug2843TestCase::SendPacketBurst (uint8_t numPackets, Ptr<NetDevice> sourceDevice,
                                   Address& destination) const
 {
   for (uint8_t i = 0; i < numPackets; i++)
@@ -1262,11 +1442,8 @@ Bug2483TestCase::SendPacketBurst (uint8_t numPackets, Ptr<NetDevice> sourceDevic
 }
 
 void
-Bug2483TestCase::DoRun (void)
+Bug2843TestCase::DoRun (void)
 {
-  Config::SetDefault ("ns3::WifiRemoteStationManager::RtsCtsThreshold", StringValue ("500")); // so as to force RTS/CTS for data frames
-  Config::SetDefault ("ns3::WifiPhy::CcaMode1Threshold", DoubleValue (-62.0));
-
   uint16_t channelWidth = 40; // at least 40 MHz expected here
 
   NodeContainer wifiStaNode;
@@ -1296,7 +1473,8 @@ Bug2483TestCase::DoRun (void)
   wifi.SetStandard (WIFI_PHY_STANDARD_80211ac);
   wifi.SetRemoteStationManager ("ns3::ConstantRateWifiManager",
                                 "DataMode", StringValue ("VhtMcs8"),
-                                "ControlMode", StringValue ("VhtMcs8"));
+                                "ControlMode", StringValue ("VhtMcs8"),
+                                "RtsCtsThreshold", StringValue ("500")); // so as to force RTS/CTS for data frames
 
   WifiMacHelper mac;
   mac.SetType ("ns3::StaWifiMac");
@@ -1318,10 +1496,10 @@ Bug2483TestCase::DoRun (void)
   mobility.Install (wifiStaNode);
 
   // Send two 5 packet-bursts
-  Simulator::Schedule (Seconds (0.5), &Bug2483TestCase::SendPacketBurst, this, 5, apDevice.Get (0), staDevice.Get (0)->GetAddress ());
-  Simulator::Schedule (Seconds (0.6), &Bug2483TestCase::SendPacketBurst, this, 5, apDevice.Get (0), staDevice.Get (0)->GetAddress ());
+  Simulator::Schedule (Seconds (0.5), &Bug2843TestCase::SendPacketBurst, this, 5, apDevice.Get (0), staDevice.Get (0)->GetAddress ());
+  Simulator::Schedule (Seconds (0.6), &Bug2843TestCase::SendPacketBurst, this, 5, apDevice.Get (0), staDevice.Get (0)->GetAddress ());
 
-  Config::Connect ("/ChannelList/*/$ns3::MultiModelSpectrumChannel/TxSigParams", MakeCallback (&Bug2483TestCase::StoreDistinctTuple, this));
+  Config::Connect ("/ChannelList/*/$ns3::MultiModelSpectrumChannel/TxSigParams", MakeCallback (&Bug2843TestCase::StoreDistinctTuple, this));
 
   Simulator::Stop (Seconds (0.8));
   Simulator::Run ();
@@ -1447,16 +1625,22 @@ Bug2831TestCase::DoRun (void)
 
   Ptr<Node> apNode = CreateObject<Node> ();
   Ptr<WifiNetDevice> apDev = CreateObject<WifiNetDevice> ();
+  Ptr<HtConfiguration> apHtConfiguration = CreateObject<HtConfiguration> ();
+  apDev->SetHtConfiguration (apHtConfiguration);
   ObjectFactory mac;
   mac.SetTypeId ("ns3::ApWifiMac");
   mac.Set ("EnableBeaconJitter", BooleanValue (false));
   Ptr<WifiMac> apMac = mac.Create<WifiMac> ();
+  apMac->SetDevice (apDev);
   apMac->ConfigureStandard (WIFI_PHY_STANDARD_80211ax_5GHZ);
 
   Ptr<Node> staNode = CreateObject<Node> ();
   Ptr<WifiNetDevice> staDev = CreateObject<WifiNetDevice> ();
+  Ptr<HtConfiguration> staHtConfiguration = CreateObject<HtConfiguration> ();
+  staDev->SetHtConfiguration (staHtConfiguration);
   mac.SetTypeId ("ns3::StaWifiMac");
   Ptr<WifiMac> staMac = mac.Create<WifiMac> ();
+  staMac->SetDevice (staDev);
   staMac->ConfigureStandard (WIFI_PHY_STANDARD_80211ax_5GHZ);
 
   Ptr<ConstantPositionMobilityModel> apMobility = CreateObject<ConstantPositionMobilityModel> ();
@@ -1593,7 +1777,7 @@ StaWifiMacScanningTestCase::TurnApOff (Ptr<Node> apNode)
 {
   Ptr<WifiNetDevice> netDevice = DynamicCast<WifiNetDevice> (apNode->GetDevice (0));
   Ptr<WifiPhy> phy = netDevice->GetPhy ();
-  phy->SetOffMode();
+  phy->SetOffMode ();
 }
 
 NodeContainer
@@ -1650,6 +1834,9 @@ void
 StaWifiMacScanningTestCase::DoRun (void)
 {
   {
+    RngSeedManager::SetSeed (1);
+    RngSeedManager::SetRun (1);
+
     NodeContainer nodes = Setup (false, false);
     Ptr<Node> nearestAp = nodes.Get (2);
     Mac48Address nearestApAddr = DynamicCast<WifiNetDevice> (nearestAp->GetDevice (0))->GetMac ()->GetAddress ();
@@ -1664,6 +1851,9 @@ StaWifiMacScanningTestCase::DoRun (void)
   }
   m_associatedApBssid = Mac48Address ();
   {
+    RngSeedManager::SetSeed (1);
+    RngSeedManager::SetRun (1);
+
     NodeContainer nodes = Setup (true, true);
     Ptr<Node> nearestAp = nodes.Get (2);
     Mac48Address nearestApAddr = DynamicCast<WifiNetDevice> (nearestAp->GetDevice (0))->GetMac ()->GetAddress ();
@@ -1676,6 +1866,9 @@ StaWifiMacScanningTestCase::DoRun (void)
   }
   m_associatedApBssid = Mac48Address ();
   {
+    RngSeedManager::SetSeed (1);
+    RngSeedManager::SetRun (1);
+
     NodeContainer nodes = Setup (true, false);
     Ptr<Node> nearestAp = nodes.Get (2);
     Mac48Address secondNearestApAddr = DynamicCast<WifiNetDevice> (nodes.Get (1)->GetDevice (0))->GetMac ()->GetAddress ();
@@ -1690,6 +1883,297 @@ StaWifiMacScanningTestCase::DoRun (void)
   }
 }
 
+//-----------------------------------------------------------------------------
+/**
+ * Make sure that the ADDBA handshake process is protected.
+ *
+ * The scenario considers an access point and a station. It utilizes
+ * ReceiveListErrorModel to drop by force ADDBA request on STA or ADDBA
+ * response on AP. The AP sends 5 packets of each 1000 bytes (thus generating
+ * BA agreement), 2 times during the test at 0.5s and 0.8s. We only drop the
+ * first ADDBA request/response of the first BA negotiation. Therefore, we
+ * expect that the packets still in queue after the failed BA agreement will be
+ * sent with normal MPDU, and packets queued after that should be sent with
+ * A-MPDU.
+ *
+ * This test consider 2 cases:
+ *
+ *   1. ADDBA request packets are blocked on receive at STA, triggering
+ *      transmission failure at AP
+ *   2. ADDBA response packets are blocked on receive at AP, STA stops
+ *      retransmission of ADDBA response
+ *
+ * See \bugid{2470}
+ */
+
+class Bug2470TestCase : public TestCase
+{
+public:
+  Bug2470TestCase ();
+  virtual ~Bug2470TestCase ();
+  virtual void DoRun (void);
+
+private:
+  /**
+   * Callback when ADDBA state changed
+   * \param context node context
+   * \param t the time the state changed
+   * \param recipient the MAC address of the recipient
+   * \param tid the TID
+   * \param state the state
+   */
+  void AddbaStateChangedCallback (std::string context, Time t, Mac48Address recipient, uint8_t tid, OriginatorBlockAckAgreement::State state);
+  /**
+   * Callback when packet is received
+   * \param context node context
+   * \param p the received packet
+   * \param channelFreqMhz the channel frequency in MHz
+   * \param txVector the TX vector
+   * \param aMpdu the A-MPDU info
+   * \param signalNoise the signal noise in dBm
+   */
+  void RxCallback (std::string context, Ptr<const Packet> p, uint16_t channelFreqMhz, WifiTxVector txVector, MpduInfo aMpdu, SignalNoiseDbm signalNoise);
+  /**
+   * Callback when packet is dropped
+   * \param context node context
+   * \param p the dropped packet
+   * \param reason the reason
+   */
+  void RxDropCallback (std::string context, Ptr<const Packet> p, WifiPhyRxfailureReason reason);
+  /**
+   * Triggers the arrival of a burst of 1000 Byte-long packets in the source device
+   * \param numPackets number of packets in burst
+   * \param sourceDevice pointer to the source NetDevice
+   * \param destination address of the destination device
+   */
+  void SendPacketBurst (uint32_t numPackets, Ptr<NetDevice> sourceDevice, Address& destination) const;
+  /**
+   * Run subtest for this test suite
+   * \param apErrorModel ErrorModel used for AP
+   * \param staErrorModel ErrorModel used for STA
+   */
+  void RunSubtest (PointerValue apErrorModel, PointerValue staErrorModel);
+
+  uint8_t m_receivedNormalMpduCount; ///< Count received normal MPDU packets on STA
+  uint8_t m_receivedAmpduCount;      ///< Count received A-MPDU packets on STA
+  uint8_t m_droppedActionCount;      ///< Count dropped ADDBA request/response
+  uint8_t m_addbaEstablishedCount;   ///< Count number of times ADDBA state machine is in established state
+  uint8_t m_addbaPendingCount;       ///< Count number of times ADDBA state machine is in pending state
+  uint8_t m_addbaRejectedCount;      ///< Count number of times ADDBA state machine is in rejected state
+  uint8_t m_addbaNoReplyCount;       ///< Count number of times ADDBA state machine is in no_reply state
+  uint8_t m_addbaResetCount;         ///< Count number of times ADDBA state machine is in reset state
+};
+
+Bug2470TestCase::Bug2470TestCase ()
+  : TestCase ("Test case for Bug 2470"),
+    m_receivedNormalMpduCount (0),
+    m_receivedAmpduCount (0),
+    m_droppedActionCount (0),
+    m_addbaEstablishedCount (0),
+    m_addbaPendingCount (0),
+    m_addbaRejectedCount (0),
+    m_addbaNoReplyCount (0),
+    m_addbaResetCount (0)
+{
+}
+
+Bug2470TestCase::~Bug2470TestCase ()
+{
+}
+
+void
+Bug2470TestCase::AddbaStateChangedCallback (std::string context, Time t, Mac48Address recipient, uint8_t tid, OriginatorBlockAckAgreement::State state)
+{
+  switch (state)
+    {
+    case OriginatorBlockAckAgreement::ESTABLISHED:
+      m_addbaEstablishedCount++;
+      break;
+    case OriginatorBlockAckAgreement::PENDING:
+      m_addbaPendingCount++;
+      break;
+    case OriginatorBlockAckAgreement::REJECTED:
+      m_addbaRejectedCount++;
+      break;
+    case OriginatorBlockAckAgreement::NO_REPLY:
+      m_addbaNoReplyCount++;
+      break;
+    case OriginatorBlockAckAgreement::RESET:
+      m_addbaResetCount++;
+      break;
+    }
+}
+
+void
+Bug2470TestCase::RxCallback (std::string context, Ptr<const Packet> p, uint16_t channelFreqMhz, WifiTxVector txVector, MpduInfo aMpdu, SignalNoiseDbm signalNoise)
+{
+  Ptr<Packet> packet = p->Copy ();
+  if (aMpdu.type != MpduType::NORMAL_MPDU)
+    {
+      m_receivedAmpduCount++;
+    }
+  else
+    {
+      WifiMacHeader hdr;
+      packet->RemoveHeader (hdr);
+      if (hdr.IsData ())
+        {
+          m_receivedNormalMpduCount++;
+        }
+    }
+}
+
+void
+Bug2470TestCase::RxDropCallback (std::string context, Ptr<const Packet> p, WifiPhyRxfailureReason reason)
+{
+  Ptr<Packet> packet = p->Copy ();
+  WifiMacHeader hdr;
+  packet->RemoveHeader (hdr);
+  if (hdr.IsAction ())
+    {
+      m_droppedActionCount++;
+    }
+}
+
+void
+Bug2470TestCase::SendPacketBurst (uint32_t numPackets, Ptr<NetDevice> sourceDevice,
+                                  Address& destination) const
+{
+  for (uint32_t i = 0; i < numPackets; i++)
+    {
+      Ptr<Packet> pkt = Create<Packet> (1000); // 1000 dummy bytes of data
+      sourceDevice->Send (pkt, destination, 0);
+    }
+}
+
+void
+Bug2470TestCase::RunSubtest (PointerValue apErrorModel, PointerValue staErrorModel)
+{
+  RngSeedManager::SetSeed (1);
+  RngSeedManager::SetRun (1);
+  int64_t streamNumber = 200;
+
+  NodeContainer wifiApNode, wifiStaNode;
+  wifiApNode.Create (1);
+  wifiStaNode.Create (1);
+
+  YansWifiPhyHelper phy = YansWifiPhyHelper::Default ();
+  YansWifiChannelHelper channel = YansWifiChannelHelper::Default ();
+  phy.SetChannel (channel.Create ());
+
+  WifiHelper wifi;
+  wifi.SetStandard (WIFI_PHY_STANDARD_80211n_5GHZ);
+  wifi.SetRemoteStationManager ("ns3::ConstantRateWifiManager",
+                                "DataMode", StringValue ("HtMcs7"),
+                                "ControlMode", StringValue ("HtMcs7"));
+
+  WifiMacHelper mac;
+  NetDeviceContainer apDevice;
+  phy.Set ("PostReceptionErrorModel", apErrorModel);
+  mac.SetType ("ns3::ApWifiMac", "EnableBeaconJitter", BooleanValue (false));
+  apDevice = wifi.Install (phy, mac, wifiApNode);
+
+  NetDeviceContainer staDevice;
+  phy.Set ("PostReceptionErrorModel", staErrorModel);
+  mac.SetType ("ns3::StaWifiMac");
+  staDevice = wifi.Install (phy, mac, wifiStaNode);
+
+  // Assign fixed streams to random variables in use
+  wifi.AssignStreams (apDevice, streamNumber);
+  wifi.AssignStreams (staDevice, streamNumber);
+
+  MobilityHelper mobility;
+  Ptr<ListPositionAllocator> positionAlloc = CreateObject<ListPositionAllocator> ();
+  positionAlloc->Add (Vector (0.0, 0.0, 0.0));
+  positionAlloc->Add (Vector (1.0, 0.0, 0.0));
+  mobility.SetPositionAllocator (positionAlloc);
+
+  mobility.SetMobilityModel ("ns3::ConstantPositionMobilityModel");
+  mobility.Install (wifiApNode);
+  mobility.Install (wifiStaNode);
+
+  Config::Connect ("/NodeList/*/DeviceList/*/$ns3::WifiNetDevice/Phy/$ns3::WifiPhy/MonitorSnifferRx", MakeCallback (&Bug2470TestCase::RxCallback, this));
+  Config::Connect ("/NodeList/*/DeviceList/*/$ns3::WifiNetDevice/Phy/$ns3::WifiPhy/PhyRxDrop", MakeCallback (&Bug2470TestCase::RxDropCallback, this));
+  Config::Connect ("/NodeList/*/DeviceList/*/$ns3::WifiNetDevice/Mac/$ns3::RegularWifiMac/BE_Txop/BlockAckManager/AgreementState", MakeCallback (&Bug2470TestCase::AddbaStateChangedCallback, this));
+
+  Simulator::Schedule (Seconds (0.5), &Bug2470TestCase::SendPacketBurst, this, 5, apDevice.Get (0), staDevice.Get (0)->GetAddress ());
+  Simulator::Schedule (Seconds (0.8), &Bug2470TestCase::SendPacketBurst, this, 5, apDevice.Get (0), staDevice.Get (0)->GetAddress ());
+
+  Simulator::Stop (Seconds (1.0));
+  Simulator::Run ();
+  Simulator::Destroy ();
+}
+
+void
+Bug2470TestCase::DoRun (void)
+{
+  // Create ReceiveListErrorModel to corrupt ADDBA req packet. We use ReceiveListErrorModel
+  // instead of ListErrorModel since packet UID is incremented between simulations. But
+  // problem may occur because of random stream, therefore we suppress usage of RNG as
+  // much as possible (i.e., removing beacon jitter).
+  Ptr<ReceiveListErrorModel> staPem = CreateObject<ReceiveListErrorModel> ();
+  std::list<uint32_t> blackList;
+  // Block ADDBA request 6 times (== maximum number of MAC frame transmissions in the ADDBA response timeout interval)
+  blackList.push_back (8);
+  blackList.push_back (9);
+  blackList.push_back (10);
+  blackList.push_back (11);
+  blackList.push_back (12);
+  blackList.push_back (13);
+  staPem->SetList (blackList);
+
+  {
+    RunSubtest (PointerValue (), PointerValue (staPem));
+    NS_TEST_ASSERT_MSG_EQ (m_droppedActionCount, 6, "ADDBA request packet is not dropped correctly");
+    // There are two sets of 5 packets to be transmitted. The first 5 packets should be sent by normal
+    // MPDU because of failed ADDBA handshake.For the second set, the first packet should be sent by
+    // normal MPDU, and the rest with A-MPDU. In total we expect to receive 2 normal MPDU packets and
+    // 8 A-MPDU packets.
+    NS_TEST_ASSERT_MSG_EQ (m_receivedNormalMpduCount, 2, "Receiving incorrect number of normal MPDU packet on subtest 1");
+    NS_TEST_ASSERT_MSG_EQ (m_receivedAmpduCount, 8, "Receiving incorrect number of A-MPDU packet on subtest 1");
+
+    NS_TEST_ASSERT_MSG_EQ (m_addbaEstablishedCount, 1, "Incorrect number of times the ADDBA state machine was in established state on subtest 1");
+    NS_TEST_ASSERT_MSG_EQ (m_addbaPendingCount, 1, "Incorrect number of times the ADDBA state machine was in pending state on subtest 1");
+    NS_TEST_ASSERT_MSG_EQ (m_addbaRejectedCount, 0, "Incorrect number of times the ADDBA state machine was in rejected state on subtest 1");
+    NS_TEST_ASSERT_MSG_EQ (m_addbaNoReplyCount, 0, "Incorrect number of times the ADDBA state machine was in no_reply state on subtest 1");
+    NS_TEST_ASSERT_MSG_EQ (m_addbaResetCount, 0, "Incorrect number of times the ADDBA state machine was in reset state on subtest 1");
+  }
+
+  m_receivedNormalMpduCount = 0;
+  m_receivedAmpduCount = 0;
+  m_droppedActionCount = 0;
+  m_addbaEstablishedCount = 0;
+  m_addbaPendingCount = 0;
+  m_addbaRejectedCount = 0;
+  m_addbaNoReplyCount = 0;
+  m_addbaResetCount = 0;
+
+  Ptr<ReceiveListErrorModel> apPem = CreateObject<ReceiveListErrorModel> ();
+  blackList.clear ();
+  // Block ADDBA request 3 times (== maximum number of MAC frame transmissions in the ADDBA response timeout interval)
+  blackList.push_back (4);
+  blackList.push_back (5);
+  blackList.push_back (6);
+  apPem->SetList (blackList);
+
+  {
+    RunSubtest (PointerValue (apPem), PointerValue ());
+    NS_TEST_ASSERT_MSG_EQ (m_droppedActionCount, 3, "ADDBA response packet is not dropped correctly");
+    // Similar to subtest 1, we also expect to receive 6 normal MPDU packets and 4 A-MPDU packets.
+    NS_TEST_ASSERT_MSG_EQ (m_receivedNormalMpduCount, 6, "Receiving incorrect number of normal MPDU packet on subtest 2");
+    NS_TEST_ASSERT_MSG_EQ (m_receivedAmpduCount, 4, "Receiving incorrect number of A-MPDU packet on subtest 2");
+
+    NS_TEST_ASSERT_MSG_EQ (m_addbaEstablishedCount, 1, "Incorrect number of times the ADDBA state machine was in established state on subtest 2");
+    NS_TEST_ASSERT_MSG_EQ (m_addbaPendingCount, 1, "Incorrect number of times the ADDBA state machine was in pending state on subtest 2");
+    NS_TEST_ASSERT_MSG_EQ (m_addbaRejectedCount, 0, "Incorrect number of times the ADDBA state machine was in rejected state on subtest 2");
+    NS_TEST_ASSERT_MSG_EQ (m_addbaNoReplyCount, 1, "Incorrect number of times the ADDBA state machine was in no_reply state on subtest 2");
+    NS_TEST_ASSERT_MSG_EQ (m_addbaResetCount, 0, "Incorrect number of times the ADDBA state machine was in reset state on subtest 2");
+  }
+
+  // TODO: In the second test set, it does not go to reset state since ADDBA response is received after timeout (NO_REPLY)
+  // but before it does not enter RESET state. More tests should be written to verify all possible scenarios.
+}
+
 /**
  * \ingroup wifi-test
  * \ingroup tests
@@ -1710,11 +2194,13 @@ WifiTestSuite::WifiTestSuite ()
   AddTestCase (new InterferenceHelperSequenceTest, TestCase::QUICK); //Bug 991
   AddTestCase (new DcfImmediateAccessBroadcastTestCase, TestCase::QUICK);
   AddTestCase (new Bug730TestCase, TestCase::QUICK); //Bug 730
+  AddTestCase (new QosFragmentationTestCase, TestCase::QUICK);
   AddTestCase (new SetChannelFrequencyTest, TestCase::QUICK);
   AddTestCase (new Bug2222TestCase, TestCase::QUICK); //Bug 2222
-  AddTestCase (new Bug2483TestCase, TestCase::QUICK); //Bug 2483
+  AddTestCase (new Bug2843TestCase, TestCase::QUICK); //Bug 2843
   AddTestCase (new Bug2831TestCase, TestCase::QUICK); //Bug 2831
   AddTestCase (new StaWifiMacScanningTestCase, TestCase::QUICK); //Bug 2399
+  AddTestCase (new Bug2470TestCase, TestCase::QUICK); //Bug 2470
 }
 
 static WifiTestSuite g_wifiTestSuite; ///< the test suite
