@@ -893,7 +893,9 @@ PrintAttributeImplementations (std::ostream & os)
                           "EdcaParameterSet",
                                             true,  "edca-parameter-set.h"},
       { "ErpInformation", "ErpInformation", true,  "erp-information.h"  },
+      { "ExtendedCapabilities", "ExtendedCapabilities", true,  "extended-capabilities.h"  },
       { "HeCapabilities", "HeCapabilities", true,  "he-capabilities.h"  },
+      { "VhtCapabilities","VhtCapabilities",true,  "vht-capabilities.h" },
       { "HtCapabilities", "HtCapabilities", true,  "ht-capabilities.h"  },
       { "IeMeshId",       "IeMeshId",       true,  "ie-dot11s-id.h"     },
       { "Ipv4Address",    "Ipv4Address",    true,  "ipv4-address.h"     },
@@ -914,8 +916,9 @@ PrintAttributeImplementations (std::ostream & os)
       // { "ValueClassTest", "ValueClassTest", false, "" /* outside ns3 */ },
       { "Vector2D",       "Vector2D",       true,  "vector.h"           },
       { "Vector3D",       "Vector3D",       true,  "vector.h"           },
-      { "VhtCapabilities","VhtCapabilities",true,  "vht-capabilities.h" },
+      { "HeOperation",    "HeOperation",    true,  "he-operation.h"    },
       { "VhtOperation",   "VhtOperation",   true,  "vht-operation.h"    },
+      { "HtOperation",    "HtOperation",    true,  "ht-operation.h"  },
       { "Waypoint",       "Waypoint",       true,  "waypoint.h"         },
       { "WifiMode",       "WifiMode",       true,  "wifi-mode.h"        },
       
